@@ -38,6 +38,8 @@
 
 #include "const/resources/skill.h"
 
+#include "fs/files.h"
+
 #include "gui/gui.h"
 #include "gui/popupmanager.h"
 #include "gui/sdlinput.h"
@@ -82,17 +84,18 @@
 #include "net/buysellhandler.h"
 #include "net/chathandler.h"
 #include "net/download.h"
+#include "net/homunculushandler.h"
 #include "net/gamehandler.h"
 #include "net/inventoryhandler.h"
 #include "net/ipc.h"
 #include "net/mercenaryhandler.h"
 #include "net/net.h"
-#include "net/vendinghandler.h"
 #include "net/npchandler.h"
 #include "net/playerhandler.h"
 #include "net/serverfeatures.h"
 #include "net/uploadcharinfo.h"
 #include "net/tradehandler.h"
+#include "net/vendinghandler.h"
 
 #include "resources/iteminfo.h"
 #include "resources/memorymanager.h"
@@ -102,15 +105,18 @@
 #include "utils/chatutils.h"
 #include "utils/delete2.h"
 #include "utils/gettext.h"
-#include "utils/files.h"
-#include "utils/timer.h"
 #include "utils/mathutils.h"
+#include "utils/parameters.h"
+#include "utils/timer.h"
 
+PRAGMA48(GCC diagnostic push)
+PRAGMA48(GCC diagnostic ignored "-Wshadow")
 #ifdef ANDROID
 #ifndef USE_SDL2
 #include <SDL_screenkeyboard.h>
 #endif  // USE_OPENGL
 #endif  // ANDROID
+PRAGMA48(GCC diagnostic pop)
 
 #include <sstream>
 
@@ -138,7 +144,7 @@ static int uploadUpdate(void *ptr,
         return 0;
 
     UploadChatInfo *const info = reinterpret_cast<UploadChatInfo*>(ptr);
-    if (!info)
+    if (info == nullptr)
         return 0;
 
     if (status == DownloadStatus::Complete)
@@ -151,7 +157,8 @@ static int uploadUpdate(void *ptr,
                 str = str.substr(0, sz - 1);
             str.append(info->addStr);
             ChatTab *const tab = info->tab;
-            if (chatWindow && (!tab || chatWindow->isTabPresent(tab)))
+            if (chatWindow != nullptr &&
+                (tab == nullptr || chatWindow->isTabPresent(tab)))
             {
                 str = strprintf("%s [@@%s |%s@@]",
                     info->text.c_str(), str.c_str(), str.c_str());
@@ -198,7 +205,7 @@ static void uploadFile(const std::string &str,
 
 static Being *findBeing(const std::string &name, const bool npc)
 {
-    if (!localPlayer || !actorManager)
+    if ((localPlayer == nullptr) || (actorManager == nullptr))
         return nullptr;
 
     Being *being = nullptr;
@@ -212,11 +219,11 @@ static Being *findBeing(const std::string &name, const bool npc)
         being = actorManager->findBeingByName(
             name, ActorType::Unknown);
     }
-    if (!being && npc)
+    if ((being == nullptr) && npc)
     {
         being = actorManager->findNearestLivingBeing(
             localPlayer, 1, ActorType::Npc, AllowSort_true);
-        if (being)
+        if (being != nullptr)
         {
             if (abs(being->getTileX() - localPlayer->getTileX()) > 1
                 || abs(being->getTileY() - localPlayer->getTileY()) > 1)
@@ -225,11 +232,11 @@ static Being *findBeing(const std::string &name, const bool npc)
             }
         }
     }
-    if (!being && npc)
+    if ((being == nullptr) && npc)
     {
         being = actorManager->findNearestLivingBeing(
             localPlayer, 1, ActorType::Player, AllowSort_true);
-        if (being)
+        if (being != nullptr)
         {
             if (abs(being->getTileX() - localPlayer->getTileX()) > 1
                 || abs(being->getTileY() - localPlayer->getTileY()) > 1)
@@ -265,7 +272,7 @@ static Item *getItemByInvIndex(const InputEvent &event,
         default:
             break;
     }
-    if (inv)
+    if (inv != nullptr)
         return inv->getItem(index);
     return nullptr;
 }
@@ -276,7 +283,7 @@ static int getAmountFromEvent(const InputEvent &event,
 {
     Item *const item = getItemByInvIndex(event, invType);
     item0 = item;
-    if (!item)
+    if (item == nullptr)
         return 0;
 
     std::string str = event.args;
@@ -315,9 +322,9 @@ impHandler(emote)
     const int emotion = 1 + (event.action - InputAction::EMOTE_1);
     if (emotion > 0)
     {
-        if (emoteShortcut)
+        if (emoteShortcut != nullptr)
             emoteShortcut->useEmotePlayer(emotion);
-        if (Game::instance())
+        if (Game::instance() != nullptr)
             Game::instance()->setValidSpeed();
         return true;
     }
@@ -330,10 +337,10 @@ impHandler(outfit)
     if (inputManager.isActionActive(InputAction::WEAR_OUTFIT))
     {
         const int num = event.action - InputAction::OUTFIT_1;
-        if (outfitWindow && num >= 0)
+        if ((outfitWindow != nullptr) && num >= 0)
         {
             outfitWindow->wearOutfit(num);
-            if (Game::instance())
+            if (Game::instance() != nullptr)
                 Game::instance()->setValidSpeed();
             return true;
         }
@@ -341,10 +348,10 @@ impHandler(outfit)
     else if (inputManager.isActionActive(InputAction::COPY_OUTFIT))
     {
         const int num = event.action - InputAction::OUTFIT_1;
-        if (outfitWindow && num >= 0)
+        if ((outfitWindow != nullptr) && num >= 0)
         {
             outfitWindow->copyOutfit(num);
-            if (Game::instance())
+            if (Game::instance() != nullptr)
                 Game::instance()->setValidSpeed();
             return true;
         }
@@ -355,7 +362,7 @@ impHandler(outfit)
 
 impHandler0(mouseClick)
 {
-    if (!guiInput || !gui)
+    if ((guiInput == nullptr) || (gui == nullptr))
         return false;
 
     int mouseX, mouseY;
@@ -367,13 +374,13 @@ impHandler0(mouseClick)
 impHandler0(ok)
 {
     // Close the Browser if opened
-    if (helpWindow && helpWindow->isWindowVisible())
+    if ((helpWindow != nullptr) && helpWindow->isWindowVisible())
     {
         helpWindow->setVisible(Visible_false);
         return true;
     }
     // Close the config window, cancelling changes if opened
-    else if (setupWindow && setupWindow->isWindowVisible())
+    else if ((setupWindow != nullptr) && setupWindow->isWindowVisible())
     {
         setupWindow->action(ActionEvent(nullptr, "cancel"));
         return true;
@@ -392,12 +399,12 @@ impHandler0(ok)
 
 impHandler(shortcut)
 {
-    if (itemShortcutWindow)
+    if (itemShortcutWindow != nullptr)
     {
         const int num = itemShortcutWindow->getTabIndex();
         if (num >= 0 && num < CAST_S32(SHORTCUT_TABS))
         {
-            if (itemShortcut[num])
+            if (itemShortcut[num] != nullptr)
             {
                 itemShortcut[num]->useItem(event.action
                     - InputAction::SHORTCUT_1);
@@ -410,14 +417,14 @@ impHandler(shortcut)
 
 impHandler0(quit)
 {
-    if (!Game::instance())
+    if (Game::instance() == nullptr)
         return false;
-    if (popupManager && popupManager->isPopupMenuVisible())
+    if ((popupManager != nullptr) && popupManager->isPopupMenuVisible())
     {
         popupManager->closePopupMenu();
         return true;
     }
-    else if (!quitDialog)
+    else if (quitDialog == nullptr)
     {
         CREATEWIDGETV(quitDialog, QuitDialog,
             &quitDialog);
@@ -429,7 +436,7 @@ impHandler0(quit)
 
 impHandler0(dropItem0)
 {
-    if (dropShortcut)
+    if (dropShortcut != nullptr)
     {
         dropShortcut->dropFirst();
         return true;
@@ -439,7 +446,7 @@ impHandler0(dropItem0)
 
 impHandler0(dropItem)
 {
-    if (dropShortcut)
+    if (dropShortcut != nullptr)
     {
         dropShortcut->dropItems();
         return true;
@@ -450,14 +457,14 @@ impHandler0(dropItem)
 impHandler(dropItemId)
 {
     const Inventory *const inv = PlayerInfo::getInventory();
-    if (!inv)
+    if (inv == nullptr)
         return false;
 
     // +++ ignoring item color for now
     Item *const item = inv->findItem(atoi(event.args.c_str()),
         ItemColor_one);
 
-    if (item && !PlayerInfo::isItemProtected(item->getId()))
+    if ((item != nullptr) && !PlayerInfo::isItemProtected(item->getId()))
     {
         ItemAmountWindow::showWindow(ItemAmountWindowUsage::ItemDrop,
             inventoryWindow, item);
@@ -468,7 +475,7 @@ impHandler(dropItemId)
 impHandler(dropItemInv)
 {
     Item *const item = getItemByInvIndex(event, InventoryType::Inventory);
-    if (item && !PlayerInfo::isItemProtected(item->getId()))
+    if ((item != nullptr) && !PlayerInfo::isItemProtected(item->getId()))
     {
         ItemAmountWindow::showWindow(ItemAmountWindowUsage::ItemDrop,
             inventoryWindow, item);
@@ -479,14 +486,14 @@ impHandler(dropItemInv)
 impHandler(dropItemIdAll)
 {
     const Inventory *const inv = PlayerInfo::getInventory();
-    if (!inv)
+    if (inv == nullptr)
         return false;
 
     // +++ ignoring item color for now
     Item *const item = inv->findItem(atoi(event.args.c_str()),
         ItemColor_one);
 
-    if (item && !PlayerInfo::isItemProtected(item->getId()))
+    if ((item != nullptr) && !PlayerInfo::isItemProtected(item->getId()))
         PlayerInfo::dropItem(item, item->getQuantity(), Sfx_true);
     return true;
 }
@@ -494,7 +501,7 @@ impHandler(dropItemIdAll)
 impHandler(dropItemInvAll)
 {
     Item *const item = getItemByInvIndex(event, InventoryType::Inventory);
-    if (item && !PlayerInfo::isItemProtected(item->getId()))
+    if ((item != nullptr) && !PlayerInfo::isItemProtected(item->getId()))
         PlayerInfo::dropItem(item, item->getQuantity(), Sfx_true);
     return true;
 }
@@ -504,7 +511,8 @@ impHandler(heal)
 {
     if (Net::getNetworkType() != ServerType::TMWATHENA)
         return false;
-    if (actorManager && localPlayer)
+    if (actorManager != nullptr &&
+        localPlayer != nullptr)
     {
         std::string args = event.args;
 
@@ -515,14 +523,14 @@ impHandler(heal)
             {
                 being = actorManager->findBeing(fromInt(atoi(
                     args.substr(1).c_str()), BeingId));
-                if (being && being->getType() == ActorType::Monster)
+                if (being != nullptr && being->getType() == ActorType::Monster)
                     being = nullptr;
             }
             else
             {
                 being = actorManager->findBeingByName(args, ActorType::Player);
             }
-            if (being)
+            if (being != nullptr)
                 actorManager->heal(being);
         }
         else
@@ -530,7 +538,8 @@ impHandler(heal)
             Being *target = localPlayer->getTarget();
             if (inputManager.isActionActive(InputAction::STOP_ATTACK))
             {
-                if (!target || target->getType() != ActorType::Player)
+                if (target == nullptr ||
+                    target->getType() != ActorType::Player)
                 {
                     target = actorManager->findNearestLivingBeing(
                         localPlayer, 10, ActorType::Player, AllowSort_true);
@@ -538,13 +547,13 @@ impHandler(heal)
             }
             else
             {
-                if (!target)
+                if (target == nullptr)
                     target = localPlayer;
             }
             actorManager->heal(target);
         }
 
-        if (Game::instance())
+        if (Game::instance() != nullptr)
             Game::instance()->setValidSpeed();
         return true;
     }
@@ -563,7 +572,7 @@ impHandler0(healmd)
 #ifdef TMWA_SUPPORT
     if (Net::getNetworkType() != ServerType::TMWATHENA)
         return false;
-    if (actorManager)
+    if (actorManager != nullptr)
     {
         const int matk = PlayerInfo::getStatEffective(Attributes::PLAYER_MATK);
         int maxHealingRadius;
@@ -580,10 +589,10 @@ impHandler0(healmd)
         }
 
         Being *target = actorManager->findMostDamagedPlayer(maxHealingRadius);
-        if (target)
+        if (target != nullptr)
             actorManager->heal(target);
 
-        if (Game::instance())
+        if (Game::instance() != nullptr)
             Game::instance()->setValidSpeed();
         return true;
     }
@@ -597,9 +606,9 @@ impHandler0(itenplz)
 #ifdef TMWA_SUPPORT
     if (Net::getNetworkType() != ServerType::TMWATHENA)
         return false;
-    if (actorManager)
+    if (actorManager != nullptr)
     {
-        if (playerHandler &&
+        if (playerHandler != nullptr &&
             playerHandler->canUseMagic() &&
             PlayerInfo::getAttribute(Attributes::PLAYER_MP) >= 3)
         {
@@ -614,7 +623,7 @@ impHandler0(itenplz)
 
 impHandler0(setHome)
 {
-    if (localPlayer)
+    if (localPlayer != nullptr)
     {
         localPlayer->setHome();
         return true;
@@ -627,7 +636,7 @@ impHandler0(magicAttack)
 #ifdef TMWA_SUPPORT
     if (Net::getNetworkType() != ServerType::TMWATHENA)
         return false;
-    if (localPlayer)
+    if (localPlayer != nullptr)
     {
         localPlayer->magicAttack();
         return true;
@@ -639,7 +648,7 @@ impHandler0(magicAttack)
 
 impHandler0(copyEquippedToOutfit)
 {
-    if (outfitWindow)
+    if (outfitWindow != nullptr)
     {
         outfitWindow->copyFromEquiped();
         return true;
@@ -649,7 +658,7 @@ impHandler0(copyEquippedToOutfit)
 
 impHandler(pickup)
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return false;
 
     const std::string args = event.args;
@@ -661,7 +670,7 @@ impHandler(pickup)
     {
         FloorItem *const item = actorManager->findItem(fromInt(
             atoi(args.c_str()), BeingId));
-        if (item)
+        if (item != nullptr)
             localPlayer->pickUp(item);
     }
     return true;
@@ -677,7 +686,7 @@ static void doSit()
 
 impHandler0(sit)
 {
-    if (localPlayer)
+    if (localPlayer != nullptr)
     {
         doSit();
         return true;
@@ -685,9 +694,9 @@ impHandler0(sit)
     return false;
 }
 
-impHandler0(screenshot)
+impHandler(screenshot)
 {
-    Game::createScreenshot();
+    Game::createScreenshot(event.args);
     return true;
 }
 
@@ -698,19 +707,19 @@ impHandler0(ignoreInput)
 
 impHandler(buy)
 {
-    if (!serverFeatures)
+    if (serverFeatures == nullptr)
         return false;
     const std::string args = event.args;
     Being *being = findBeing(args, false);
-    if (!being && !serverFeatures->haveVending())
+    if ((being == nullptr) && Net::getNetworkType() == ServerType::TMWATHENA)
     {
-        if (whoIsOnline)
+        if (whoIsOnline != nullptr)
         {
             const std::set<std::string> &players =
                 whoIsOnline->getOnlineNicks();
             if (players.find(args) != players.end())
             {
-                if (buySellHandler)
+                if (buySellHandler != nullptr)
                     buySellHandler->requestSellList(args);
                 return true;
             }
@@ -718,24 +727,29 @@ impHandler(buy)
         return false;
     }
 
-    if (!being)
+    if (being == nullptr)
         being = findBeing(args, true);
 
-    if (!being)
+    if (being == nullptr)
         return false;
 
     if (being->getType() == ActorType::Npc)
     {
-        if (npcHandler)
-            npcHandler->buy(being->getId());
+        if (npcHandler != nullptr)
+            npcHandler->buy(being);
         return true;
     }
     else if (being->getType() == ActorType::Player)
     {
-        if (vendingHandler && serverFeatures->haveVending())
+        if (vendingHandler != nullptr &&
+            Net::getNetworkType() != ServerType::TMWATHENA)
+        {
             vendingHandler->open(being);
-        else if (buySellHandler)
+        }
+        else if (buySellHandler != nullptr)
+        {
             buySellHandler->requestSellList(being->getName());
+        }
         return true;
     }
     return false;
@@ -743,20 +757,21 @@ impHandler(buy)
 
 impHandler(sell)
 {
-    if (!serverFeatures)
+    if (serverFeatures == nullptr)
         return false;
 
     const std::string args = event.args;
     Being *being = findBeing(args, false);
-    if (!being && !serverFeatures->haveVending())
+    if (being == nullptr &&
+        Net::getNetworkType() == ServerType::TMWATHENA)
     {
-        if (whoIsOnline)
+        if (whoIsOnline != nullptr)
         {
             const std::set<std::string> &players =
                 whoIsOnline->getOnlineNicks();
             if (players.find(args) != players.end())
             {
-                if (buySellHandler)
+                if (buySellHandler != nullptr)
                     buySellHandler->requestBuyList(args);
                 return true;
             }
@@ -764,24 +779,29 @@ impHandler(sell)
         return false;
     }
 
-    if (!being)
+    if (being == nullptr)
         being = findBeing(args, true);
 
-    if (!being)
+    if (being == nullptr)
         return false;
 
     if (being->getType() == ActorType::Npc)
     {
-        if (npcHandler)
+        if (npcHandler != nullptr)
             npcHandler->sell(being->getId());
         return true;
     }
     else if (being->getType() == ActorType::Player)
     {
-        if (buyingStoreHandler && serverFeatures->haveVending())
+        if ((buyingStoreHandler != nullptr) &&
+            Net::getNetworkType() != ServerType::TMWATHENA)
+        {
             buyingStoreHandler->open(being);
-        else if (buySellHandler)
+        }
+        else if (buySellHandler != nullptr)
+        {
             buySellHandler->requestBuyList(being->getName());
+        }
         return true;
     }
     return false;
@@ -790,7 +810,7 @@ impHandler(sell)
 impHandler(talk)
 {
     Being *being = findBeing(event.args, true);
-    if (!being)
+    if (being == nullptr)
         return false;
 
     if (being->canTalk())
@@ -807,7 +827,7 @@ impHandler(talk)
 
 impHandler0(stopAttack)
 {
-    if (localPlayer)
+    if (localPlayer != nullptr)
     {
         localPlayer->stopAttack();
         // not consume if target attack key pressed
@@ -820,7 +840,7 @@ impHandler0(stopAttack)
 
 impHandler0(untarget)
 {
-    if (localPlayer)
+    if (localPlayer != nullptr)
     {
         localPlayer->untarget();
         return true;
@@ -830,7 +850,7 @@ impHandler0(untarget)
 
 impHandler(attack)
 {
-    if (!localPlayer || !actorManager)
+    if ((localPlayer == nullptr) || (actorManager == nullptr))
         return false;
 
     Being *target = nullptr;
@@ -845,22 +865,25 @@ impHandler(attack)
         {
             target = actorManager->findBeing(fromInt(atoi(
                 args.substr(1).c_str()), BeingId));
-            if (target && target->getType() != ActorType::Monster)
+            if (target != nullptr &&
+                target->getType() != ActorType::Monster)
+            {
                 target = nullptr;
+            }
         }
     }
-    if (!target)
+    if (target == nullptr)
         target = localPlayer->getTarget();
     else
         localPlayer->setTarget(target);
-    if (target)
+    if (target != nullptr)
         localPlayer->attack(target, true);
     return true;
 }
 
 impHandler(targetAttack)
 {
-    if (localPlayer && actorManager)
+    if ((localPlayer != nullptr) && (actorManager != nullptr))
     {
         Being *target = nullptr;
         std::string args = event.args;
@@ -877,15 +900,18 @@ impHandler(targetAttack)
             {
                 target = actorManager->findBeing(fromInt(atoi(
                     args.substr(1).c_str()), BeingId));
-                if (target && target->getType() != ActorType::Monster)
+                if (target != nullptr &&
+                    target->getType() != ActorType::Monster)
+                {
                     target = nullptr;
+                }
             }
         }
 
-        if (!target && !settings.targetingType)
+        if ((target == nullptr) && (settings.targetingType == 0u))
             target = localPlayer->getTarget();
 
-        if (!target)
+        if (target == nullptr)
         {
             target = actorManager->findNearestLivingBeing(
                 localPlayer, 90, ActorType::Monster, AllowSort_true);
@@ -899,11 +925,11 @@ impHandler(targetAttack)
 
 impHandler0(attackHuman)
 {
-    if (!actorManager || !localPlayer)
+    if ((actorManager == nullptr) || (localPlayer == nullptr))
         return false;
 
     Being *const target = actorManager->findNearestPvpPlayer();
-    if (target)
+    if (target != nullptr)
     {
         localPlayer->setTarget(target);
         localPlayer->attack2(target, true);
@@ -920,13 +946,13 @@ impHandler0(safeVideoMode)
 
 impHandler0(stopSit)
 {
-    if (localPlayer)
+    if (localPlayer != nullptr)
     {
         localPlayer->stopAttack();
         // not consume if target attack key pressed
         if (inputManager.isActionActive(InputAction::TARGET_ATTACK))
             return false;
-        if (!localPlayer->getTarget())
+        if (localPlayer->getTarget() == nullptr)
         {
             doSit();
             return true;
@@ -958,7 +984,7 @@ impHandler0(showKeyboard)
 
 impHandler0(showWindows)
 {
-    if (popupMenu)
+    if (popupMenu != nullptr)
     {
         popupMenu->showWindowsPopup();
         return true;
@@ -969,12 +995,12 @@ impHandler0(showWindows)
 impHandler0(openTrade)
 {
     const Being *const being = localPlayer->getTarget();
-    if (being && being->getType() == ActorType::Player)
+    if ((being != nullptr) && being->getType() == ActorType::Player)
     {
-        if (tradeHandler)
+        if (tradeHandler != nullptr)
             tradeHandler->request(being);
         tradePartnerName = being->getName();
-        if (tradeWindow)
+        if (tradeWindow != nullptr)
             tradeWindow->clear();
         return true;
     }
@@ -983,10 +1009,10 @@ impHandler0(openTrade)
 
 impHandler0(ipcToggle)
 {
-    if (ipc)
+    if (ipc != nullptr)
     {
         IPC::stop();
-        if (!ipc)
+        if (ipc == nullptr)
         {
             debugChatTab->chatLog("IPC service stopped.",
                 ChatMsgType::BY_SERVER);
@@ -1000,7 +1026,7 @@ impHandler0(ipcToggle)
     else
     {
         IPC::start();
-        if (ipc)
+        if (ipc != nullptr)
         {
             debugChatTab->chatLog(
                 strprintf("IPC service available on port %d", ipc->getPort()),
@@ -1018,7 +1044,7 @@ impHandler0(ipcToggle)
 impHandler(where)
 {
     ChatTab *const tab = event.tab != nullptr ? event.tab : debugChatTab;
-    if (!tab)
+    if (tab == nullptr)
         return false;
     std::ostringstream where;
     where << Game::instance()->getCurrentMapName() << ", coordinates: "
@@ -1030,16 +1056,16 @@ impHandler(where)
 
 impHandler0(who)
 {
-    if (chatHandler)
+    if (chatHandler != nullptr)
         chatHandler->who();
     return true;
 }
 
 impHandler0(cleanGraphics)
 {
-    resourceManager->clearCache();
+    ResourceManager::clearCache();
 
-    if (debugChatTab)
+    if (debugChatTab != nullptr)
     {
         // TRANSLATORS: clear graphics command message
         debugChatTab->chatLog(_("Cache cleaned"),
@@ -1050,9 +1076,9 @@ impHandler0(cleanGraphics)
 
 impHandler0(cleanFonts)
 {
-    if (gui)
+    if (gui != nullptr)
         gui->clearFonts();
-    if (debugChatTab)
+    if (debugChatTab != nullptr)
     {
         // TRANSLATORS: clear fonts cache message
         debugChatTab->chatLog(_("Cache cleaned"),
@@ -1063,19 +1089,19 @@ impHandler0(cleanFonts)
 
 impHandler(trade)
 {
-    if (!actorManager)
+    if (actorManager == nullptr)
         return false;
 
     const Being *being = actorManager->findBeingByName(
         event.args, ActorType::Player);
-    if (!being)
+    if (being == nullptr)
         being = localPlayer->getTarget();
-    if (being)
+    if (being != nullptr)
     {
-        if (tradeHandler)
+        if (tradeHandler != nullptr)
             tradeHandler->request(being);
         tradePartnerName = being->getName();
-        if (tradeWindow)
+        if (tradeWindow != nullptr)
             tradeWindow->clear();
     }
     return true;
@@ -1083,7 +1109,7 @@ impHandler(trade)
 
 impHandler0(priceLoad)
 {
-    if (shopWindow)
+    if (shopWindow != nullptr)
     {
         shopWindow->loadList();
         return true;
@@ -1093,7 +1119,7 @@ impHandler0(priceLoad)
 
 impHandler0(priceSave)
 {
-    if (shopWindow)
+    if (shopWindow != nullptr)
     {
         shopWindow->saveList();
         return true;
@@ -1103,7 +1129,7 @@ impHandler0(priceSave)
 
 impHandler0(cacheInfo)
 {
-    if (!chatWindow || !debugChatTab)
+    if ((chatWindow == nullptr) || (debugChatTab == nullptr))
         return false;
 
 /*
@@ -1149,44 +1175,59 @@ impHandler0(cacheInfo)
 
 impHandler0(disconnect)
 {
-    if (gameHandler)
+    if (gameHandler != nullptr)
         gameHandler->disconnect2();
     return true;
 }
 
 impHandler(undress)
 {
-    if (!actorManager || !localPlayer)
+    if ((actorManager == nullptr) || (localPlayer == nullptr))
         return false;
 
     const std::string args = event.args;
-
+    StringVect pars;
+    if (!splitParameters(pars, args, " ,", '\"'))
+        return false;
     Being *target = nullptr;
-    if (!args.empty())
+    const size_t sz = pars.size();
+    if (sz == 0)
     {
-        if (args[0] == ':')
+        target = localPlayer->getTarget();
+    }
+    else
+    {
+        if (pars[0][0] == ':')
         {
             target = actorManager->findBeing(fromInt(atoi(
-                args.substr(1).c_str()), BeingId));
-            if (target && target->getType() == ActorType::Monster)
+                pars[0].substr(1).c_str()), BeingId));
+            if ((target != nullptr) && target->getType() == ActorType::Monster)
                 target = nullptr;
         }
         else
         {
-            target = actorManager->findNearestByName(event.args);
+            target = actorManager->findNearestByName(args);
         }
     }
 
-    if (!target)
-        target = localPlayer->getTarget();
-    if (target && beingHandler)
-        beingHandler->undress(target);
+    if (sz == 2)
+    {
+        const int itemId = atoi(pars[1].c_str());
+        if (target != nullptr)
+            target->undressItemById(itemId);
+    }
+    else
+    {
+        if ((target != nullptr) && (beingHandler != nullptr))
+            beingHandler->undress(target);
+    }
+
     return true;
 }
 
 impHandler0(dirs)
 {
-    if (!debugChatTab)
+    if (debugChatTab == nullptr)
         return false;
 
     debugChatTab->chatLog("config directory: "
@@ -1206,7 +1247,7 @@ impHandler0(dirs)
 
 impHandler0(uptime)
 {
-    if (!debugChatTab)
+    if (debugChatTab == nullptr)
         return false;
 
     if (cur_time < start_time)
@@ -1239,7 +1280,7 @@ static void showRes(std::string str, ResourceManager::Resources *res)
     const ResourceManager::ResourceIterator iter_end = res->end();
     while (iter != iter_end)
     {
-        if (iter->second && iter->second->getRefCount())
+        if (iter->second && iter->second->mRefCount)
         {
             char type = ' ';
             char isNew = 'N';
@@ -1248,9 +1289,9 @@ static void showRes(std::string str, ResourceManager::Resources *res)
             else
                 iter->second->setDumped(true);
 
-            SubImage *const subImage = dynamic_cast<SubImage *const>(
+            SubImage *const subImage = dynamic_cast<SubImage *>(
                 iter->second);
-            Image *const image = dynamic_cast<Image *const>(iter->second);
+            Image *const image = dynamic_cast<Image *>(iter->second);
             int id = 0;
             if (subImage)
                 type = 'S';
@@ -1260,7 +1301,7 @@ static void showRes(std::string str, ResourceManager::Resources *res)
                 id = image->getGLImage();
             logger->log("Resource %c%c: %s (%d) id=%d", type,
                 isNew, iter->second->getIdPath().c_str(),
-                iter->second->getRefCount(), id);
+                iter->second->mRefCount, id);
         }
         ++ iter;
     }
@@ -1273,20 +1314,20 @@ impHandler(dump)
 
     if (!event.args.empty())
     {
-        ResourceManager::Resources *res = resourceManager->getResources();
+        ResourceManager::Resources *res = ResourceManager::getResources();
         // TRANSLATORS: dump command
         showRes(_("Resource images:"), res);
-        res = resourceManager->getOrphanedResources();
+        res = ResourceManager::getOrphanedResources();
         // TRANSLATORS: dump command
         showRes(_("Resource orphaned images:"), res);
     }
     else
     {
-        ResourceManager::Resources *res = resourceManager->getResources();
+        ResourceManager::Resources *res = ResourceManager::getResources();
         // TRANSLATORS: dump command
         debugChatTab->chatLog(_("Resource images:") + toString(res->size()),
             ChatMsgType::BY_SERVER);
-        res = resourceManager->getOrphanedResources();
+        res = ResourceManager::getOrphanedResources();
         // TRANSLATORS: dump command
         debugChatTab->chatLog(_("Resource orphaned images:")
             + toString(res->size()),
@@ -1311,14 +1352,14 @@ impHandler0(dump)
 
 impHandler0(serverIgnoreAll)
 {
-    if (chatHandler)
+    if (chatHandler != nullptr)
         chatHandler->ignoreAll();
     return true;
 }
 
 impHandler0(serverUnIgnoreAll)
 {
-    if (chatHandler)
+    if (chatHandler != nullptr)
         chatHandler->unIgnoreAll();
     return true;
 }
@@ -1379,10 +1420,10 @@ impHandler(dumpGraphics)
 impHandler0(dumpEnvironment)
 {
     logger->log1("Start environment variables");
-    for (char **env = environ; *env; ++ env)
+    for (char **env = environ; *env != nullptr; ++ env)
         logger->log1(*env);
     logger->log1("End environment variables");
-    if (debugChatTab)
+    if (debugChatTab != nullptr)
     {
         // TRANSLATORS: dump environment command
         debugChatTab->chatLog(_("Environment variables dumped"),
@@ -1486,7 +1527,7 @@ impHandler0(createItems)
     FOR_EACH (ItemDB::ItemInfos::const_iterator, it, items)
     {
         const ItemInfo *const info = (*it).second;
-        if (!info)
+        if (info == nullptr)
             continue;
         const int id = info->getId();
         if (id <= 500)
@@ -1507,7 +1548,7 @@ impHandler(createItem)
     int id = 0;
     int amount = 0;
 
-    if (!adminHandler)
+    if (adminHandler == nullptr)
         return false;
 
     if (parse2Int(event.args, id, amount))
@@ -1549,11 +1590,32 @@ impHandler(uploadLog)
 
 impHandler0(mercenaryFire)
 {
-    if (mercenaryHandler)
+    if (mercenaryHandler != nullptr)
         mercenaryHandler->fire();
     return true;
 }
 
+impHandler0(mercenaryToMaster)
+{
+    if (mercenaryHandler != nullptr)
+        mercenaryHandler->moveToMaster();
+    return true;
+}
+
+impHandler0(homunculusToMaster)
+{
+    if (homunculusHandler != nullptr)
+        homunculusHandler->moveToMaster();
+    return true;
+}
+
+impHandler0(homunculusFeed)
+{
+    if (homunculusHandler != nullptr)
+        homunculusHandler->feed();
+    return true;
+}
+
 impHandler(useItem)
 {
     const int itemId = atoi(event.args.c_str());
@@ -1561,7 +1623,7 @@ impHandler(useItem)
     if (itemId < SPELL_MIN_ID)
     {
         const Inventory *const inv = PlayerInfo::getInventory();
-        if (inv)
+        if (inv != nullptr)
         {
             // +++ ignoring item color for now
             const Item *const item = inv->findItem(itemId,
@@ -1569,11 +1631,11 @@ impHandler(useItem)
             PlayerInfo::useEquipItem(item, Sfx_true);
         }
     }
-    else if (itemId < SKILL_MIN_ID && spellManager)
+    else if (itemId < SKILL_MIN_ID && (spellManager != nullptr))
     {
         spellManager->useItem(itemId);
     }
-    else if (skillDialog)
+    else if (skillDialog != nullptr)
     {
         // +++ probably need get data parameter from args
         skillDialog->useItem(itemId,
@@ -1596,11 +1658,11 @@ impHandler(invToStorage)
     Item *item = nullptr;
     const int amount = getAmountFromEvent(event, item,
         InventoryType::Inventory);
-    if (!item)
+    if (item == nullptr)
         return true;
-    if (amount)
+    if (amount != 0)
     {
-        if (inventoryHandler)
+        if (inventoryHandler != nullptr)
         {
             inventoryHandler->moveItem2(InventoryType::Inventory,
                 item->getInvIndex(),
@@ -1621,12 +1683,12 @@ impHandler(tradeAdd)
     Item *item = nullptr;
     const int amount = getAmountFromEvent(event, item,
         InventoryType::Inventory);
-    if (!item || PlayerInfo::isItemProtected(item->getId()))
+    if ((item == nullptr) || PlayerInfo::isItemProtected(item->getId()))
         return true;
 
-    if (amount)
+    if (amount != 0)
     {
-        if (tradeWindow)
+        if (tradeWindow != nullptr)
             tradeWindow->tradeItem(item, amount, true);
     }
     else
@@ -1641,9 +1703,9 @@ impHandler(storageToInv)
 {
     Item *item = nullptr;
     const int amount = getAmountFromEvent(event, item, InventoryType::Storage);
-    if (amount)
+    if (amount != 0)
     {
-        if (inventoryHandler && item)
+        if ((inventoryHandler != nullptr) && (item != nullptr))
         {
             inventoryHandler->moveItem2(InventoryType::Storage,
                 item->getInvIndex(),
@@ -1677,7 +1739,7 @@ impHandler(unprotectItem)
 
 impHandler(kick)
 {
-    if (!localPlayer || !actorManager)
+    if ((localPlayer == nullptr) || (actorManager == nullptr))
         return false;
 
     Being *target = nullptr;
@@ -1694,23 +1756,23 @@ impHandler(kick)
                 args.substr(1).c_str()), BeingId));
         }
     }
-    if (!target)
+    if (target == nullptr)
         target = localPlayer->getTarget();
-    if (target && adminHandler)
+    if ((target != nullptr) && (adminHandler != nullptr))
         adminHandler->kick(target->getId());
     return true;
 }
 
 impHandler0(clearDrop)
 {
-    if (dropShortcut)
+    if (dropShortcut != nullptr)
         dropShortcut->clear();
     return true;
 }
 
 impHandler0(testInfo)
 {
-    if (actorManager)
+    if (actorManager != nullptr)
     {
         logger->log("actors count: %d", CAST_S32(
             actorManager->size()));
@@ -1724,7 +1786,7 @@ impHandler(craftKey)
     const int slot = (event.action - InputAction::CRAFT_1);
     if (slot >= 0 && slot < 9)
     {
-        if (inventoryWindow)
+        if (inventoryWindow != nullptr)
             inventoryWindow->moveItemToCraft(slot);
         return true;
     }
@@ -1739,7 +1801,7 @@ impHandler0(resetGameModifiers)
 
 impHandler(barToChat)
 {
-    if (chatWindow)
+    if (chatWindow != nullptr)
     {
         chatWindow->addInputText(event.args);
         return true;
@@ -1749,13 +1811,13 @@ impHandler(barToChat)
 
 impHandler(seen)
 {
-    if (!actorManager)
+    if (actorManager == nullptr)
         return false;
 
     ChatTab *tab = event.tab;
-    if (!tab)
+    if (tab == nullptr)
         tab = localChatTab;
-    if (!tab)
+    if (tab == nullptr)
         return false;
 
     if (config.getBoolValue("enableIdCollecting") == false)
@@ -1803,7 +1865,7 @@ impHandler(seen)
 
 impHandler(dumpMemoryUsage)
 {
-    if (event.tab)
+    if (event.tab != nullptr)
         memoryManager.printAllMemory(event.tab);
     else
         memoryManager.printAllMemory(localChatTab);
