@@ -73,6 +73,7 @@
 
 #include "utils/booleanoptions.h"
 #include "utils/chatutils.h"
+#include "utils/copynpaste.h"
 #include "utils/gmfunctions.h"
 #include "utils/parameters.h"
 #include "utils/process.h"
@@ -87,18 +88,18 @@ static std::string getNick(const InputEvent &event)
     std::string args = event.args;
     if (args.empty())
     {
-        if (!event.tab || event.tab->getType() != ChatTabType::WHISPER)
+        if (event.tab == nullptr ||
+            event.tab->getType() != ChatTabType::WHISPER)
+        {
             return std::string();
+        }
 
-        WhisperTab *const whisper = static_cast<WhisperTab* const>(event.tab);
+        WhisperTab *const whisper = static_cast<WhisperTab *>(event.tab);
         if (whisper->getNick().empty())
         {
-            if (event.tab)
-            {
-                // TRANSLATORS: change relation
-                event.tab->chatLog(_("Please specify a name."),
-                    ChatMsgType::BY_SERVER);
-            }
+            // TRANSLATORS: change relation
+            event.tab->chatLog(_("Please specify a name."),
+                ChatMsgType::BY_SERVER);
             return std::string();
         }
         args = whisper->getNick();
@@ -111,9 +112,9 @@ static void reportRelation(const InputEvent &event,
                            const std::string &str1,
                            const std::string &str2)
 {
-    if (event.tab)
+    if (event.tab != nullptr)
     {
-        if (player_relations.getRelation(event.args) == rel)
+        if (playerRelations.getRelation(event.args) == rel)
         {
             // TRANSLATORS: unignore command
             event.tab->chatLog(str1, ChatMsgType::BY_SERVER);
@@ -134,9 +135,9 @@ static void changeRelation(const InputEvent &event,
     if (args.empty())
         return;
 
-    if (player_relations.getRelation(args) == relation)
+    if (playerRelations.getRelation(args) == relation)
     {
-        if (event.tab)
+        if (event.tab != nullptr)
         {
             // TRANSLATORS: change relation
             event.tab->chatLog(strprintf(_("Player already %s!"),
@@ -146,7 +147,7 @@ static void changeRelation(const InputEvent &event,
     }
     else
     {
-        player_relations.setRelation(args, relation);
+        playerRelations.setRelation(args, relation);
     }
 
     reportRelation(event,
@@ -159,7 +160,7 @@ static void changeRelation(const InputEvent &event,
 
 impHandler(chatAnnounce)
 {
-    if (adminHandler)
+    if (adminHandler != nullptr)
     {
         adminHandler->announce(event.args);
         return true;
@@ -179,14 +180,14 @@ impHandler(chatUnignore)
     if (args.empty())
         return false;
 
-    const RelationT rel = player_relations.getRelation(args);
+    const RelationT rel = playerRelations.getRelation(args);
     if (rel != Relation::NEUTRAL && rel != Relation::FRIEND)
     {
-        player_relations.setRelation(args, Relation::NEUTRAL);
+        playerRelations.setRelation(args, Relation::NEUTRAL);
     }
     else
     {
-        if (event.tab)
+        if (event.tab != nullptr)
         {
             // TRANSLATORS: unignore command
             event.tab->chatLog(_("Player wasn't ignored!"),
@@ -210,9 +211,9 @@ impHandler(chatErase)
     if (args.empty())
         return false;
 
-    if (player_relations.getRelation(args) == Relation::ERASED)
+    if (playerRelations.getRelation(args) == Relation::ERASED)
     {
-        if (event.tab)
+        if (event.tab != nullptr)
         {
             // TRANSLATORS: erase command
             event.tab->chatLog(_("Player already erased!"),
@@ -222,7 +223,7 @@ impHandler(chatErase)
     }
     else
     {
-        player_relations.setRelation(args, Relation::ERASED);
+        playerRelations.setRelation(args, Relation::ERASED);
     }
 
     reportRelation(event,
@@ -271,13 +272,13 @@ impHandler(chatEnemy)
 
 impHandler(chatNuke)
 {
-    if (!actorManager)
+    if (actorManager == nullptr)
         return false;
 
     const std::string nick = getNick(event);
     Being *const being = actorManager->findBeingByName(
         nick, ActorType::Player);
-    if (!being)
+    if (being == nullptr)
         return true;
 
     actorManager->addBlock(being->getId());
@@ -287,7 +288,7 @@ impHandler(chatNuke)
 
 impHandler(chatAdd)
 {
-    if (!chatWindow)
+    if (chatWindow == nullptr)
         return false;
 
     if (event.args.empty())
@@ -313,7 +314,7 @@ impHandler(chatAdd)
     const FloorItem *const floorItem = actorManager->findItem(
         fromInt(id, BeingId));
 
-    if (floorItem)
+    if (floorItem != nullptr)
     {
         str[0] =  floorItem->getItemId();
         const std::string names = ItemDB::getNamesStr(str);
@@ -324,7 +325,7 @@ impHandler(chatAdd)
 
 impHandler0(present)
 {
-    if (chatWindow)
+    if (chatWindow != nullptr)
     {
         chatWindow->doPresent();
         return true;
@@ -334,7 +335,7 @@ impHandler0(present)
 
 impHandler0(printAll)
 {
-    if (actorManager)
+    if (actorManager != nullptr)
     {
         actorManager->printAllToChat();
         return true;
@@ -347,7 +348,7 @@ impHandler(move)
     int x = 0;
     int y = 0;
 
-    if (localPlayer && parse2Int(event.args, x, y))
+    if ((localPlayer != nullptr) && parse2Int(event.args, x, y))
     {
         localPlayer->setDestination(x, y);
         return true;
@@ -357,18 +358,18 @@ impHandler(move)
 
 impHandler(setTarget)
 {
-    if (!actorManager || !localPlayer)
+    if ((actorManager == nullptr) || (localPlayer == nullptr))
         return false;
 
     Being *const target = actorManager->findNearestByName(event.args);
-    if (target)
+    if (target != nullptr)
         localPlayer->setTarget(target);
     return true;
 }
 
 impHandler(commandOutfit)
 {
-    if (outfitWindow)
+    if (outfitWindow != nullptr)
     {
         if (!event.args.empty())
         {
@@ -399,7 +400,7 @@ impHandler(commandOutfit)
 
 impHandler(commandEmote)
 {
-    if (localPlayer)
+    if (localPlayer != nullptr)
     {
         localPlayer->emote(CAST_U8(atoi(event.args.c_str())));
         return true;
@@ -409,7 +410,7 @@ impHandler(commandEmote)
 
 impHandler(awayMessage)
 {
-    if (localPlayer)
+    if (localPlayer != nullptr)
     {
         localPlayer->setAway(event.args);
         return true;
@@ -419,7 +420,7 @@ impHandler(awayMessage)
 
 impHandler(pseudoAway)
 {
-    if (localPlayer)
+    if (localPlayer != nullptr)
     {
         localPlayer->setPseudoAway(event.args);
         localPlayer->updateStatus();
@@ -430,7 +431,7 @@ impHandler(pseudoAway)
 
 impHandler(follow)
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return false;
 
     if (!features.getBoolValue("allowFollow"))
@@ -440,7 +441,8 @@ impHandler(follow)
     {
         localPlayer->setFollow(event.args);
     }
-    else if (event.tab && event.tab->getType() == ChatTabType::WHISPER)
+    else if (event.tab != nullptr &&
+             event.tab->getType() == ChatTabType::WHISPER)
     {
         localPlayer->setFollow(static_cast<WhisperTab*>(event.tab)->getNick());
     }
@@ -455,7 +457,7 @@ impHandler(follow)
 
 impHandler(navigate)
 {
-    if (!localPlayer ||
+    if ((localPlayer == nullptr) ||
         !localPlayer->canMove())
     {
         return false;
@@ -473,7 +475,7 @@ impHandler(navigate)
 
 impHandler(navigateTo)
 {
-    if (!localPlayer ||
+    if ((localPlayer == nullptr) ||
         !localPlayer->canMove())
     {
         return false;
@@ -484,20 +486,24 @@ impHandler(navigateTo)
         return true;
 
     Being *const being = actorManager->findBeingByName(args);
-    if (being)
+    if (being != nullptr)
     {
         localPlayer->navigateTo(being->getTileX(), being->getTileY());
     }
     else if (localPlayer->isInParty())
     {
         const Party *const party = localPlayer->getParty();
-        if (party)
+        if (party != nullptr)
         {
             const PartyMember *const m = party->getMember(args);
             const PartyMember *const o = party->getMember(
                 localPlayer->getName());
-            if (m && o && m->getMap() == o->getMap())
+            if (m != nullptr &&
+                o != nullptr &&
+                m->getMap() == o->getMap())
+            {
                 localPlayer->navigateTo(m->getX(), m->getY());
+            }
         }
     }
     return true;
@@ -508,7 +514,7 @@ impHandler(moveCamera)
     int x = 0;
     int y = 0;
 
-    if (!viewport)
+    if (viewport == nullptr)
         return false;
 
     if (parse2Int(event.args, x, y))
@@ -518,7 +524,7 @@ impHandler(moveCamera)
 
 impHandler0(restoreCamera)
 {
-    if (!viewport)
+    if (viewport == nullptr)
         return false;
 
     viewport->returnCamera();
@@ -527,14 +533,15 @@ impHandler0(restoreCamera)
 
 impHandler(imitation)
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return false;
 
     if (!event.args.empty())
     {
         localPlayer->setImitate(event.args);
     }
-    else if (event.tab && event.tab->getType() == ChatTabType::WHISPER)
+    else if (event.tab != nullptr &&
+             event.tab->getType() == ChatTabType::WHISPER)
     {
         localPlayer->setImitate(static_cast<WhisperTab*>(
             event.tab)->getNick());
@@ -570,20 +577,18 @@ impHandler(sendMail)
 
 impHandler(info)
 {
-    if (!event.tab ||
-        !localPlayer ||
-        !serverFeatures ||
-        !serverFeatures->haveNativeGuilds())
+    if (event.tab == nullptr ||
+        localPlayer == nullptr ||
+        Net::getNetworkType() == ServerType::TMWATHENA)
     {
         return false;
     }
 
-    if (event.tab &&
-        guildHandler &&
+    if (guildHandler != nullptr &&
         event.tab->getType() == ChatTabType::GUILD)
     {
         const Guild *const guild = localPlayer->getGuild();
-        if (guild)
+        if (guild != nullptr)
             guildHandler->info();
     }
     return true;
@@ -591,7 +596,7 @@ impHandler(info)
 
 impHandler(wait)
 {
-    if (localPlayer)
+    if (localPlayer != nullptr)
     {
         localPlayer->waitFor(event.args);
         return true;
@@ -601,7 +606,7 @@ impHandler(wait)
 
 impHandler(addPriorityAttack)
 {
-    if (!actorManager ||
+    if ((actorManager == nullptr) ||
         actorManager->isInPriorityAttackList(event.args))
     {
         return false;
@@ -610,27 +615,27 @@ impHandler(addPriorityAttack)
     actorManager->removeAttackMob(event.args);
     actorManager->addPriorityAttackMob(event.args);
 
-    if (socialWindow)
+    if (socialWindow != nullptr)
         socialWindow->updateAttackFilter();
     return true;
 }
 
 impHandler(addAttack)
 {
-    if (!actorManager)
+    if (actorManager == nullptr)
         return false;
 
     actorManager->removeAttackMob(event.args);
     actorManager->addAttackMob(event.args);
 
-    if (socialWindow)
+    if (socialWindow != nullptr)
         socialWindow->updateAttackFilter();
     return true;
 }
 
 impHandler(removeAttack)
 {
-    if (!actorManager)
+    if (actorManager == nullptr)
         return false;
 
     if (event.args.empty())
@@ -652,20 +657,20 @@ impHandler(removeAttack)
     }
 
 
-    if (socialWindow)
+    if (socialWindow != nullptr)
         socialWindow->updateAttackFilter();
     return true;
 }
 
 impHandler(addIgnoreAttack)
 {
-    if (!actorManager)
+    if (actorManager == nullptr)
         return false;
 
     actorManager->removeAttackMob(event.args);
     actorManager->addIgnoreAttackMob(event.args);
 
-    if (socialWindow)
+    if (socialWindow != nullptr)
         socialWindow->updateAttackFilter();
     return true;
 }
@@ -678,7 +683,7 @@ impHandler(setDrop)
 
 impHandler(url)
 {
-    if (event.tab)
+    if (event.tab != nullptr)
     {
         std::string url1 = event.args;
         if (!strStartWith(url1, "http") && !strStartWith(url1, "?"))
@@ -720,10 +725,10 @@ impHandler(execute)
 
 impHandler(enableHighlight)
 {
-    if (event.tab)
+    if (event.tab != nullptr)
     {
         event.tab->setAllowHighlight(true);
-        if (chatWindow)
+        if (chatWindow != nullptr)
         {
             chatWindow->saveState();
             return true;
@@ -734,10 +739,10 @@ impHandler(enableHighlight)
 
 impHandler(disableHighlight)
 {
-    if (event.tab)
+    if (event.tab != nullptr)
     {
         event.tab->setAllowHighlight(false);
-        if (chatWindow)
+        if (chatWindow != nullptr)
         {
             chatWindow->saveState();
             return true;
@@ -748,10 +753,10 @@ impHandler(disableHighlight)
 
 impHandler(dontRemoveName)
 {
-    if (event.tab)
+    if (event.tab != nullptr)
     {
         event.tab->setRemoveNames(false);
-        if (chatWindow)
+        if (chatWindow != nullptr)
         {
             chatWindow->saveState();
             return true;
@@ -762,10 +767,10 @@ impHandler(dontRemoveName)
 
 impHandler(removeName)
 {
-    if (event.tab)
+    if (event.tab != nullptr)
     {
         event.tab->setRemoveNames(true);
-        if (chatWindow)
+        if (chatWindow != nullptr)
         {
             chatWindow->saveState();
             return true;
@@ -776,10 +781,10 @@ impHandler(removeName)
 
 impHandler(disableAway)
 {
-    if (event.tab)
+    if (event.tab != nullptr)
     {
         event.tab->setNoAway(true);
-        if (chatWindow)
+        if (chatWindow != nullptr)
         {
             chatWindow->saveState();
             return true;
@@ -790,10 +795,10 @@ impHandler(disableAway)
 
 impHandler(enableAway)
 {
-    if (event.tab)
+    if (event.tab != nullptr)
     {
         event.tab->setNoAway(false);
-        if (chatWindow)
+        if (chatWindow != nullptr)
         {
             chatWindow->saveState();
             return true;
@@ -804,7 +809,7 @@ impHandler(enableAway)
 
 impHandler(testParticle)
 {
-    if (localPlayer)
+    if (localPlayer != nullptr)
     {
         localPlayer->setTestParticle(event.args);
         return true;
@@ -814,7 +819,7 @@ impHandler(testParticle)
 
 impHandler(talkRaw)
 {
-    if (chatHandler)
+    if (chatHandler != nullptr)
     {
         chatHandler->talkRaw(event.args);
         return true;
@@ -824,7 +829,7 @@ impHandler(talkRaw)
 
 impHandler(gm)
 {
-    if (chatHandler)
+    if (chatHandler != nullptr)
     {
         Gm::runCommand("wgm", event.args);
         return true;
@@ -834,7 +839,7 @@ impHandler(gm)
 
 impHandler(hack)
 {
-    if (chatHandler)
+    if (chatHandler != nullptr)
     {
         chatHandler->sendRaw(event.args);
         return true;
@@ -844,7 +849,7 @@ impHandler(hack)
 
 impHandler(debugSpawn)
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return false;
     int cnt = atoi(event.args.c_str());
     if (cnt < 1)
@@ -874,7 +879,7 @@ impHandler(serverIgnoreWhisper)
     if (args.empty())
         return false;
 
-    if (chatHandler)
+    if (chatHandler != nullptr)
     {
         chatHandler->ignore(args);
         return true;
@@ -888,7 +893,7 @@ impHandler(serverUnIgnoreWhisper)
     if (args.empty())
         return false;
 
-    if (chatHandler)
+    if (chatHandler != nullptr)
     {
         chatHandler->unIgnore(args);
         return true;
@@ -902,7 +907,7 @@ impHandler(setHomunculusName)
     if (args.empty())
     {
         const HomunculusInfo *const info = PlayerInfo::getHomunculus();
-        if (info)
+        if (info != nullptr)
         {
             // TRANSLATORS: dialog header
             inputActionReplayListener.openDialog(_("Rename your homun"),
@@ -912,7 +917,7 @@ impHandler(setHomunculusName)
         return false;
     }
 
-    if (homunculusHandler)
+    if (homunculusHandler != nullptr)
     {
         homunculusHandler->setName(args);
         return true;
@@ -922,7 +927,7 @@ impHandler(setHomunculusName)
 
 impHandler0(fireHomunculus)
 {
-    if (homunculusHandler)
+    if (homunculusHandler != nullptr)
     {
         homunculusHandler->fire();
         return true;
@@ -932,7 +937,7 @@ impHandler0(fireHomunculus)
 
 impHandler0(leaveParty)
 {
-    if (partyHandler)
+    if (partyHandler != nullptr)
     {
         partyHandler->leave();
         return true;
@@ -942,10 +947,10 @@ impHandler0(leaveParty)
 
 impHandler0(leaveGuild)
 {
-    if (guildHandler && localPlayer)
+    if ((guildHandler != nullptr) && (localPlayer != nullptr))
     {
         const Guild *const guild = localPlayer->getGuild();
-        if (guild)
+        if (guild != nullptr)
             guildHandler->leave(guild->getId());
         return true;
     }
@@ -957,8 +962,8 @@ impHandler(warp)
     int x = 0;
     int y = 0;
 
-    if (adminHandler &&
-        Game::instance() &&
+    if ((adminHandler != nullptr) &&
+        (Game::instance() != nullptr) &&
         parse2Int(event.args, x, y))
     {
         adminHandler->warp(Game::instance()->getCurrentMapName(),
@@ -970,13 +975,13 @@ impHandler(warp)
 
 impHandler(homunTalk)
 {
-    if (!serverFeatures || !serverFeatures->haveTalkPet())
+    if ((serverFeatures == nullptr) || !serverFeatures->haveTalkPet())
         return false;
 
     std::string args = event.args;
     if (findCutFirst(args, "/me "))
         args = textToMe(args);
-    if (homunculusHandler)
+    if (homunculusHandler != nullptr)
     {
         homunculusHandler->talk(args);
         return true;
@@ -986,17 +991,17 @@ impHandler(homunTalk)
 
 impHandler(homunEmote)
 {
-    if (!serverFeatures || !serverFeatures->haveTalkPet())
+    if ((serverFeatures == nullptr) || !serverFeatures->haveTalkPet())
         return false;
 
-    if (homunculusHandler &&
+    if ((homunculusHandler != nullptr) &&
         event.action >= InputAction::HOMUN_EMOTE_1 &&
         event.action <= InputAction::HOMUN_EMOTE_48)
     {
         const int emotion = event.action - InputAction::HOMUN_EMOTE_1;
-        if (emoteShortcut)
+        if (emoteShortcut != nullptr)
             homunculusHandler->emote(emoteShortcut->getEmote(emotion));
-        if (Game::instance())
+        if (Game::instance() != nullptr)
             Game::instance()->setValidSpeed();
         return true;
     }
@@ -1006,10 +1011,10 @@ impHandler(homunEmote)
 
 impHandler(commandHomunEmote)
 {
-    if (!serverFeatures || !serverFeatures->haveTalkPet())
+    if ((serverFeatures == nullptr) || !serverFeatures->haveTalkPet())
         return false;
 
-    if (homunculusHandler)
+    if (homunculusHandler != nullptr)
     {
         homunculusHandler->emote(CAST_U8(
             atoi(event.args.c_str())));
@@ -1020,7 +1025,7 @@ impHandler(commandHomunEmote)
 
 impHandler(createPublicChatRoom)
 {
-    if (!chatHandler || event.args.empty())
+    if ((chatHandler == nullptr) || event.args.empty())
         return false;
     chatHandler->createChatRoom(event.args, "", 100, true);
     return true;
@@ -1028,13 +1033,13 @@ impHandler(createPublicChatRoom)
 
 impHandler(joinChatRoom)
 {
-    if (!chatHandler)
+    if (chatHandler == nullptr)
         return false;
     const std::string args = event.args;
     if (args.empty())
         return false;
     ChatObject *const chat = ChatObject::findByName(args);
-    if (!chat)
+    if (chat == nullptr)
         return false;
     chatHandler->joinChat(chat, "");
     return true;
@@ -1042,7 +1047,7 @@ impHandler(joinChatRoom)
 
 impHandler0(leaveChatRoom)
 {
-    if (chatHandler)
+    if (chatHandler != nullptr)
     {
         chatHandler->leaveChatRoom();
         return true;
@@ -1107,7 +1112,7 @@ impHandler(slide)
     int x = 0;
     int y = 0;
 
-    if (adminHandler && parse2Int(event.args, x, y))
+    if ((adminHandler != nullptr) && parse2Int(event.args, x, y))
     {
         adminHandler->slide(x, y);
         return true;
@@ -1120,7 +1125,7 @@ impHandler(selectSkillLevel)
     int skill = 0;
     int level = 0;
 
-    if (skillDialog && parse2Int(event.args, skill, level))
+    if ((skillDialog != nullptr) && parse2Int(event.args, skill, level))
     {
         skillDialog->selectSkillLevel(skill, level);
         return true;
@@ -1130,7 +1135,7 @@ impHandler(selectSkillLevel)
 
 impHandler(skill)
 {
-    if (!skillDialog)
+    if (skillDialog == nullptr)
         return false;
 
     StringVect vect;
@@ -1176,7 +1181,7 @@ impHandler(skill)
 impHandler(craft)
 {
     const std::string args = event.args;
-    if (args.empty() || !inventoryWindow)
+    if (args.empty() || (inventoryWindow == nullptr))
         return false;
 
     inventoryWindow->moveItemToCraft(atoi(args.c_str()));
@@ -1185,14 +1190,14 @@ impHandler(craft)
 
 impHandler(npcClipboard)
 {
-    if (npcHandler)
+    if (npcHandler != nullptr)
     {
         int x = 0;
         int y = 0;
 
         NpcDialog *const dialog = npcHandler->getCurrentNpcDialog();
 
-        if (dialog && parse2Int(event.args, x, y))
+        if ((dialog != nullptr) && parse2Int(event.args, x, y))
         {
             dialog->copyToClipboard(x, y);
             return true;
@@ -1201,13 +1206,22 @@ impHandler(npcClipboard)
     return false;
 }
 
+impHandler(clipboardCopy)
+{
+    const std::string args = event.args;
+    if (args.empty())
+        return false;
+    sendBuffer(args);
+    return true;
+}
+
 impHandler(addPickup)
 {
-    if (actorManager)
+    if (actorManager != nullptr)
     {
         actorManager->removePickupItem(event.args);
         actorManager->addPickupItem(event.args);
-        if (socialWindow)
+        if (socialWindow != nullptr)
             socialWindow->updatePickupFilter();
         return true;
     }
@@ -1216,7 +1230,7 @@ impHandler(addPickup)
 
 impHandler(removePickup)
 {
-    if (actorManager)
+    if (actorManager != nullptr)
     {
         if (event.args.empty())
         {   // default pickup manipulation
@@ -1235,7 +1249,7 @@ impHandler(removePickup)
         {   // any other pickups
             actorManager->removePickupItem(event.args);
         }
-        if (socialWindow)
+        if (socialWindow != nullptr)
             socialWindow->updatePickupFilter();
         return true;
     }
@@ -1244,11 +1258,11 @@ impHandler(removePickup)
 
 impHandler(ignorePickup)
 {
-    if (actorManager)
+    if (actorManager != nullptr)
     {
         actorManager->removePickupItem(event.args);
         actorManager->addIgnorePickupItem(event.args);
-        if (socialWindow)
+        if (socialWindow != nullptr)
             socialWindow->updatePickupFilter();
         return true;
     }
@@ -1432,6 +1446,33 @@ impHandler(commandGotoNpc)
     return true;
 }
 
+impHandler(commandGotoPc)
+{
+    const std::string args = event.args;
+    if (args.empty())
+        return false;
+    adminHandler->gotoName(args);
+    return true;
+}
+
+impHandler(commandRecallPc)
+{
+    const std::string args = event.args;
+    if (args.empty())
+        return false;
+    adminHandler->recallName(args);
+    return true;
+}
+
+impHandler(commandIpCheck)
+{
+    const std::string args = event.args;
+    if (args.empty())
+        return false;
+    adminHandler->ipcheckName(args);
+    return true;
+}
+
 impHandler(commandKiller)
 {
     adminHandler->killer(event.args);
@@ -1581,7 +1622,7 @@ impHandler(commandGuildRecall)
 
 impHandler(mailTo)
 {
-    if (!mailWindow)
+    if (mailWindow == nullptr)
         return false;
     mailWindow->createMail(event.args);
     return true;
@@ -1592,7 +1633,7 @@ impHandler(adoptChild)
     const std::string nick = getNick(event);
     Being *const being = actorManager->findBeingByName(
         nick, ActorType::Player);
-    if (!being)
+    if (being == nullptr)
         return true;
     familyHandler->askForChild(being);
     return true;
@@ -1605,7 +1646,7 @@ impHandler(showSkillLevels)
         return false;
     const SkillInfo *restrict const skill = skillDialog->getSkill(
         atoi(args.c_str()));
-    if (!skill)
+    if (skill == nullptr)
         return false;
     popupMenu->showSkillLevelPopup(skill);
     return true;
@@ -1618,7 +1659,7 @@ impHandler(showSkillType)
         return false;
     const SkillInfo *restrict const skill = skillDialog->getSkill(
         atoi(args.c_str()));
-    if (!skill)
+    if (skill == nullptr)
         return false;
     popupMenu->showSkillTypePopup(skill);
     return true;
@@ -1629,7 +1670,7 @@ impHandler(selectSkillType)
     int skill = 0;
     int type = 0;
 
-    if (skillDialog && parse2Int(event.args, skill, type))
+    if ((skillDialog != nullptr) && parse2Int(event.args, skill, type))
     {
         skillDialog->selectSkillCastType(skill,
             static_cast<CastTypeT>(type));
@@ -1645,7 +1686,7 @@ impHandler(showSkillOffsetX)
         return false;
     const SkillInfo *restrict const skill = skillDialog->getSkill(
         atoi(args.c_str()));
-    if (!skill)
+    if (skill == nullptr)
         return false;
     popupMenu->showSkillOffsetPopup(skill, true);
     return true;
@@ -1658,7 +1699,7 @@ impHandler(showSkillOffsetY)
         return false;
     const SkillInfo *restrict const skill = skillDialog->getSkill(
         atoi(args.c_str()));
-    if (!skill)
+    if (skill == nullptr)
         return false;
     popupMenu->showSkillOffsetPopup(skill, false);
     return true;
@@ -1669,7 +1710,7 @@ impHandler(setSkillOffsetX)
     int skill = 0;
     int offset = 0;
 
-    if (skillDialog && parse2Int(event.args, skill, offset))
+    if ((skillDialog != nullptr) && parse2Int(event.args, skill, offset))
     {
         skillDialog->setSkillOffsetX(skill, offset);
         return true;
@@ -1682,7 +1723,7 @@ impHandler(setSkillOffsetY)
     int skill = 0;
     int offset = 0;
 
-    if (skillDialog && parse2Int(event.args, skill, offset))
+    if ((skillDialog != nullptr) && parse2Int(event.args, skill, offset))
     {
         skillDialog->setSkillOffsetY(skill, offset);
         return true;
@@ -1692,7 +1733,7 @@ impHandler(setSkillOffsetY)
 
 impHandler(partyItemShare)
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return false;
 
     if (localPlayer->isInParty() == false)
@@ -1758,7 +1799,7 @@ impHandler(partyItemShare)
 
 impHandler(partyExpShare)
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return false;
 
     if (localPlayer->isInParty() == false)
@@ -1824,7 +1865,7 @@ impHandler(partyExpShare)
 
 impHandler(partyAutoItemShare)
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return false;
 
     if (localPlayer->isInParty() == false)
@@ -1890,7 +1931,7 @@ impHandler(partyAutoItemShare)
 
 impHandler0(outfitToChat)
 {
-    if (!outfitWindow || !chatWindow)
+    if ((outfitWindow == nullptr) || (chatWindow == nullptr))
         return false;
 
     const std::string str = outfitWindow->getOutfitString();
@@ -1899,4 +1940,155 @@ impHandler0(outfitToChat)
     return true;
 }
 
+impHandler0(outfitClear)
+{
+    if (outfitWindow == nullptr)
+        return false;
+
+    outfitWindow->clearCurrentOutfit();
+    return true;
+}
+
+impHandler(moveAttackUp)
+{
+    if (actorManager == nullptr)
+        return false;
+    const std::string args = event.args;
+    const int idx = actorManager->getAttackMobIndex(args);
+    if (idx > 0)
+    {
+        std::list<std::string> mobs
+            = actorManager->getAttackMobs();
+        std::list<std::string>::iterator it = mobs.begin();
+        std::list<std::string>::iterator it2 = it;
+        while (it != mobs.end())
+        {
+            if (*it == args)
+            {
+                -- it2;
+                mobs.splice(it2, mobs, it);
+                actorManager->setAttackMobs(mobs);
+                actorManager->rebuildAttackMobs();
+                break;
+            }
+            ++ it;
+            ++ it2;
+        }
+
+        if (socialWindow != nullptr)
+            socialWindow->updateAttackFilter();
+        return true;
+    }
+    return false;
+}
+
+impHandler(moveAttackDown)
+{
+    if (actorManager == nullptr)
+        return false;
+    const std::string args = event.args;
+    const int idx = actorManager->getAttackMobIndex(args);
+    const int size = actorManager->getAttackMobsSize();
+    if (idx + 1 < size)
+    {
+        std::list<std::string> mobs
+            = actorManager->getAttackMobs();
+        std::list<std::string>::iterator it = mobs.begin();
+        std::list<std::string>::iterator it2 = it;
+        while (it != mobs.end())
+        {
+            if (*it == args)
+            {
+                ++ it2;
+                if (it2 == mobs.end())
+                    break;
+
+                mobs.splice(it, mobs, it2);
+                actorManager->setAttackMobs(mobs);
+                actorManager->rebuildAttackMobs();
+                break;
+            }
+            ++ it;
+            ++ it2;
+        }
+
+        if (socialWindow != nullptr)
+            socialWindow->updateAttackFilter();
+        return true;
+    }
+    return false;
+}
+
+impHandler(movePriorityAttackUp)
+{
+    if (actorManager == nullptr)
+        return false;
+    const std::string args = event.args;
+    const int idx = actorManager->
+        getPriorityAttackMobIndex(args);
+    if (idx > 0)
+    {
+        std::list<std::string> mobs
+            = actorManager->getPriorityAttackMobs();
+        std::list<std::string>::iterator it = mobs.begin();
+        std::list<std::string>::iterator it2 = it;
+        while (it != mobs.end())
+        {
+            if (*it == args)
+            {
+                -- it2;
+                mobs.splice(it2, mobs, it);
+                actorManager->setPriorityAttackMobs(mobs);
+                actorManager->rebuildPriorityAttackMobs();
+                break;
+            }
+            ++ it;
+            ++ it2;
+        }
+
+        if (socialWindow != nullptr)
+            socialWindow->updateAttackFilter();
+        return true;
+    }
+    return false;
+}
+
+impHandler(movePriorityAttackDown)
+{
+    if (actorManager == nullptr)
+        return false;
+    const std::string args = event.args;
+    const int idx = actorManager
+        ->getPriorityAttackMobIndex(args);
+    const int size = actorManager->getPriorityAttackMobsSize();
+    if (idx + 1 < size)
+    {
+        std::list<std::string> mobs
+            = actorManager->getPriorityAttackMobs();
+        std::list<std::string>::iterator it = mobs.begin();
+        std::list<std::string>::iterator it2 = it;
+        while (it != mobs.end())
+        {
+            if (*it == args)
+            {
+                ++ it2;
+                if (it2 == mobs.end())
+                    break;
+
+                mobs.splice(it, mobs, it2);
+                actorManager->setPriorityAttackMobs(mobs);
+                actorManager->rebuildPriorityAttackMobs();
+                break;
+            }
+            ++ it;
+            ++ it2;
+        }
+
+        if (socialWindow != nullptr)
+            socialWindow->updateAttackFilter();
+        return true;
+    }
+    return false;
+}
+
 }  // namespace Actions
