@@ -40,10 +40,11 @@
 #include "gui/windows/socialwindow.h"
 #include "gui/windows/questswindow.h"
 
+#include "fs/files.h"
+
 #include "input/inputmanager.h"
 
 #include "utils/checkutils.h"
-#include "utils/files.h"
 #include "utils/mathutils.h"
 #include "utils/gettext.h"
 
@@ -80,13 +81,13 @@ class FindBeingFunctor final
 
         bool operator() (const ActorSprite *const actor) const
         {
-            if (!actor
+            if ((actor == nullptr)
                 || actor->getType() == ActorType::FloorItem
                 || actor->getType() == ActorType::Portal)
             {
                 return false;
             }
-            const Being *const b = static_cast<const Being* const>(actor);
+            const Being *const b = static_cast<const Being *>(actor);
 
             const unsigned other_y = y
                 + ((b->getType() == ActorType::Npc) ? 1 : 0);
@@ -111,7 +112,7 @@ class FindBeingEqualFunctor final
 
         bool operator() (const Being *const being) const
         {
-            if (!being || !findBeing)
+            if ((being == nullptr) || (findBeing == nullptr))
                 return false;
             return being->getId() == findBeing->getId();
         }
@@ -127,10 +128,10 @@ class SortBeingFunctor final
         bool operator() (const Being *const being1,
                          const Being *const being2) const
         {
-            if (!being1 || !being2)
+            if ((being1 == nullptr) || (being2 == nullptr))
                 return false;
 
-            if (priorityBeings)
+            if (priorityBeings != nullptr)
             {
                 int w1 = defaultPriorityIndex;
                 int w2 = defaultPriorityIndex;
@@ -170,7 +171,7 @@ class SortBeingFunctor final
 
             if (d1 != d2)
                 return d1 < d2;
-            if (attackBeings)
+            if (attackBeings != nullptr)
             {
                 int w1 = defaultAttackIndex;
                 int w2 = defaultAttackIndex;
@@ -257,7 +258,7 @@ void ActorManager::setMap(Map *const map)
 {
     mMap = map;
 
-    if (localPlayer)
+    if (localPlayer != nullptr)
         localPlayer->setMap(map);
 }
 
@@ -266,9 +267,9 @@ void ActorManager::setPlayer(LocalPlayer *const player)
     localPlayer = player;
     mActors.insert(player);
     mActorsIdMap[player->getId()] = player;
-    if (socialWindow)
+    if (socialWindow != nullptr)
         socialWindow->updateAttackFilter();
-    if (socialWindow)
+    if (socialWindow != nullptr)
         socialWindow->updatePickupFilter();
 }
 
@@ -276,7 +277,10 @@ Being *ActorManager::createBeing(const BeingId id,
                                  const ActorTypeT type,
                                  const BeingTypeId subtype)
 {
-    Being *const being = new Being(id, type, subtype, mMap);
+    Being *const being = Being::createBeing(id,
+        type,
+        subtype,
+        mMap);
 
     mActors.insert(being);
 
@@ -290,25 +294,29 @@ Being *ActorManager::createBeing(const BeingId id,
         case ActorType::Homunculus:
         case ActorType::Npc:
             being->updateFromCache();
-            if (beingHandler)
+            if (beingHandler != nullptr)
                 beingHandler->requestNameById(id);
-            if (localPlayer)
+            if (localPlayer != nullptr)
                 localPlayer->checkNewName(being);
             break;
         case ActorType::Monster:
-            if (serverFeatures && serverFeatures->haveMonsterName())
+#ifdef TMWA_SUPPORT
+            if (Net::getNetworkType() != ServerType::TMWATHENA)
+#endif  // TMWA_SUPPORT
+            {
                 beingHandler->requestNameById(id);
+            }
             break;
         case ActorType::Portal:
-            if (beingHandler &&
-                serverFeatures &&
+            if ((beingHandler != nullptr) &&
+                (serverFeatures != nullptr) &&
                 serverFeatures->haveServerWarpNames())
             {
                 beingHandler->requestNameById(id);
             }
             break;
         case ActorType::Elemental:
-            if (beingHandler)
+            if (beingHandler != nullptr)
                 beingHandler->requestNameById(id);
             break;
         case ActorType::SkillUnit:
@@ -323,12 +331,12 @@ Being *ActorManager::createBeing(const BeingId id,
 
     if (type == ActorType::Player)
     {
-        if (socialWindow)
+        if (socialWindow != nullptr)
             socialWindow->updateActiveList();
     }
     else if (type == ActorType::Npc)
     {
-        if (questsWindow)
+        if (questsWindow != nullptr)
             questsWindow->addEffect(being);
     }
     return being;
@@ -411,7 +419,7 @@ Being *ActorManager::findBeing(const BeingId id) const
     if (it != mActorsIdMap.end())
     {
         ActorSprite *const actor = (*it).second;
-        if (actor &&
+        if ((actor != nullptr) &&
             actor->getId() == id &&
             actor->getType() != ActorType::FloorItem)
         {
@@ -427,7 +435,7 @@ ActorSprite *ActorManager::findActor(const BeingId id) const
     if (it != mActorsIdMap.end())
     {
         ActorSprite *const actor = (*it).second;
-        if (actor &&
+        if ((actor != nullptr) &&
             actor->getId() == id)
         {
             return actor;
@@ -452,7 +460,7 @@ Being *ActorManager::findBeing(const int x, const int y,
 Being *ActorManager::findBeingByPixel(const int x, const int y,
                                       const AllPlayers allPlayers) const
 {
-    if (!mMap)
+    if (mMap == nullptr)
         return nullptr;
 
     const bool targetDead = mTargetDeadPlayers;
@@ -494,15 +502,15 @@ Being *ActorManager::findBeingByPixel(const int x, const int y,
 
             Being *const being = static_cast<Being*>(*it);
 
-            if (being->getInfo() && !(being->getInfo()->isTargetSelection()
-                || modActive))
+            if (being->getInfo() != nullptr &&
+                !(being->getInfo()->isTargetSelection() || modActive))
             {
                 continue;
             }
 
-            if ((being->mAction != BeingAction::DEAD
-                || (targetDead && being->getType() == ActorType::Player))
-                && (allPlayers == AllPlayers_true || being != localPlayer))
+            if ((being->mAction != BeingAction::DEAD ||
+                (targetDead && being->getType() == ActorType::Player)) &&
+                (allPlayers == AllPlayers_true || being != localPlayer))
             {
                 const int px = being->getPixelX();
                 const int py = being->getPixelY();
@@ -519,7 +527,7 @@ Being *ActorManager::findBeingByPixel(const int x, const int y,
                          (py - mapTileSize * 2 <= y) &&
                          (py + mapTileSize / 2 >  y))
                 {
-                    if (tempBeing)
+                    if (tempBeing != nullptr)
                         noBeing = true;
                     else
                         tempBeing = being;
@@ -547,8 +555,8 @@ Being *ActorManager::findBeingByPixel(const int x, const int y,
 
             Being *const being = static_cast<Being*>(*it);
 
-            if (being->getInfo() && !(being->getInfo()->isTargetSelection()
-                || modActive))
+            if (being->getInfo() != nullptr &&
+                !(being->getInfo()->isTargetSelection() || modActive))
             {
                 continue;
             }
@@ -571,7 +579,7 @@ void ActorManager::findBeingsByPixel(std::vector<ActorSprite*> &beings,
                                      const int x, const int y,
                                      const AllPlayers allPlayers) const
 {
-    if (!mMap)
+    if (mMap == nullptr)
         return;
 
     const int xtol = mapTileSize / 2;
@@ -614,9 +622,9 @@ void ActorManager::findBeingsByPixel(std::vector<ActorSprite*> &beings,
             case ActorType::Elemental:
             {
                 const Being *const being = static_cast<const Being*>(*it);
-                if (!being)
+                if (being == nullptr)
                     continue;
-                if (being->getInfo() &&
+                if ((being->getInfo() != nullptr) &&
                     !(being->getInfo()->isTargetSelection() || modActive))
                 {
                     continue;
@@ -643,7 +651,7 @@ void ActorManager::findBeingsByPixel(std::vector<ActorSprite*> &beings,
 
 Being *ActorManager::findPortalByTile(const int x, const int y) const
 {
-    if (!mMap)
+    if (mMap == nullptr)
         return nullptr;
 
     for_actorsm
@@ -702,7 +710,7 @@ bool ActorManager::pickUpAll(const int x1, const int y1,
                              const int x2, const int y2,
                              const bool serverBuggy) const
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return false;
 
     bool finded(false);
@@ -791,7 +799,7 @@ bool ActorManager::pickUpAll(const int x1, const int y1,
                 }
             }
         }
-        if (item && localPlayer->pickUp(item))
+        if ((item != nullptr) && localPlayer->pickUp(item))
             finded = true;
     }
     return finded;
@@ -800,7 +808,7 @@ bool ActorManager::pickUpAll(const int x1, const int y1,
 bool ActorManager::pickUpNearest(const int x, const int y,
                                  int maxdist) const
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return false;
 
     maxdist = maxdist * maxdist;
@@ -821,9 +829,10 @@ bool ActorManager::pickUpNearest(const int x, const int y,
             const int d = (item->getTileX() - x) * (item->getTileX() - x)
                 + (item->getTileY() - y) * (item->getTileY() - y);
 
-            if ((d < dist || !closestItem) && (!mTargetOnlyReachable
-                || localPlayer->isReachable(item->getTileX(),
-                item->getTileY(), false)))
+            if ((d < dist || closestItem == nullptr) &&
+                (!mTargetOnlyReachable || localPlayer->isReachable(
+                item->getTileX(), item->getTileY(),
+                false)))
             {
                 if (allowAll)
                 {
@@ -846,7 +855,7 @@ bool ActorManager::pickUpNearest(const int x, const int y,
             }
         }
     }
-    if (closestItem && dist <= maxdist)
+    if ((closestItem != nullptr) && dist <= maxdist)
         return localPlayer->pickUp(closestItem);
 
     return false;
@@ -880,7 +889,7 @@ Being *ActorManager::findBeingByName(const std::string &name,
 Being *ActorManager::findNearestByName(const std::string &name,
                                        const ActorTypeT &type) const
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return nullptr;
 
     int dist = 0;
@@ -904,7 +913,7 @@ Being *ActorManager::findNearestByName(const std::string &name,
 
         Being *const being = static_cast<Being*>(*it);
 
-        if (being && being->getName() == name &&
+        if ((being != nullptr) && being->getName() == name &&
             (type == ActorType::Unknown || type == being->getType()))
         {
             if (being->getType() == ActorType::Player)
@@ -958,17 +967,17 @@ void ActorManager::logic()
         {
             const Being *const being = static_cast<const Being*>(actor);
             being->addToCache();
-            if (beingEquipmentWindow)
+            if (beingEquipmentWindow != nullptr)
                 beingEquipmentWindow->resetBeing(being);
         }
-        if (localPlayer)
+        if (localPlayer != nullptr)
         {
             if (localPlayer->getTarget() == actor)
                 localPlayer->setTarget(nullptr);
             if (localPlayer->getPickUpTarget() == actor)
                 localPlayer->unSetPickUpTarget();
         }
-        if (viewport)
+        if (viewport != nullptr)
             viewport->clearHover(*it);
     }
 
@@ -977,7 +986,7 @@ void ActorManager::logic()
         ActorSprite *actor = *it;
         mActors.erase(actor);
 
-        if (actor)
+        if (actor != nullptr)
         {
             const ActorSpritesMapIterator itr = mActorsIdMap.find(
                 actor->getId());
@@ -995,10 +1004,10 @@ void ActorManager::logic()
 
 void ActorManager::clear()
 {
-    if (beingEquipmentWindow)
+    if (beingEquipmentWindow != nullptr)
         beingEquipmentWindow->setBeing(nullptr);
 
-    if (localPlayer)
+    if (localPlayer != nullptr)
     {
         localPlayer->setTarget(nullptr);
         localPlayer->unSetPickUpTarget();
@@ -1011,7 +1020,7 @@ void ActorManager::clear()
     mDeleteActors.clear();
     mActorsIdMap.clear();
 
-    if (localPlayer)
+    if (localPlayer != nullptr)
     {
         mActors.insert(localPlayer);
         mActorsIdMap[localPlayer->getId()] = localPlayer;
@@ -1022,7 +1031,7 @@ void ActorManager::clear()
 
 Being *ActorManager::findNearestPvpPlayer() const
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return nullptr;
 
     // don't attack players
@@ -1030,11 +1039,11 @@ Being *ActorManager::findNearestPvpPlayer() const
         return nullptr;
 
     const Game *const game = Game::instance();
-    if (!game)
+    if (game == nullptr)
         return nullptr;
 
     const Map *const map = game->getCurrentMap();
-    if (!map)
+    if (map == nullptr)
         return nullptr;
 
     const int mapPvpMode = map->getPvpMode();
@@ -1057,7 +1066,7 @@ Being *ActorManager::findNearestPvpPlayer() const
 
         const int teamId = being->getTeamId();
         // this condition is very TMW-specific
-        if (!(mapPvpMode || teamId))
+        if (!((mapPvpMode != 0) || (teamId != 0)))
             continue;
 
         if (!localPlayer->checAttackPermissions(being))
@@ -1096,7 +1105,7 @@ Being *ActorManager::findNearestLivingBeing(const Being *const aroundBeing,
                                             const ActorTypeT type,
                                             const AllowSort allowSort) const
 {
-    if (!aroundBeing)
+    if (aroundBeing == nullptr)
         return nullptr;
 
     return findNearestLivingBeing(aroundBeing,
@@ -1115,7 +1124,7 @@ Being *ActorManager::findNearestLivingBeing(const Being *const aroundBeing,
                                             const Being *const excluded,
                                             const AllowSort allowSort) const
 {
-    if (!aroundBeing || !localPlayer)
+    if ((aroundBeing == nullptr) || (localPlayer == nullptr))
         return nullptr;
 
     std::set<std::string> attackMobs;
@@ -1202,7 +1211,7 @@ Being *ActorManager::findNearestLivingBeing(const Being *const aroundBeing,
                 }
             }
 
-            if (being->getInfo()
+            if ((being->getInfo() != nullptr)
                 && !(being->getInfo()->isTargetSelection() || modActive))
             {
                 continue;
@@ -1300,7 +1309,7 @@ Being *ActorManager::findNearestLivingBeing(const Being *const aroundBeing,
                 }
             }
 
-            if (being->getInfo()
+            if ((being->getInfo() != nullptr)
                 && !(being->getInfo()->isTargetSelection() || modActive))
             {
                 continue;
@@ -1329,7 +1338,7 @@ Being *ActorManager::findNearestLivingBeing(const Being *const aroundBeing,
 //            logger->log("index:" + toString(index));
 //            logger->log("d:" + toString(d));
 
-            if (!filtered && (d <= dist || !closestBeing))
+            if (!filtered && (d <= dist || (closestBeing == nullptr)))
             {
                 dist = d;
                 closestBeing = being;
@@ -1337,7 +1346,7 @@ Being *ActorManager::findNearestLivingBeing(const Being *const aroundBeing,
             else if (filtered)
             {
                 int w2 = defaultPriorityIndex;
-                if (closestBeing)
+                if (closestBeing != nullptr)
                 {
                     const StringIntMapCIter it2 =  priorityMobsMap.find(
                         being->getName());
@@ -1360,7 +1369,7 @@ Being *ActorManager::findNearestLivingBeing(const Being *const aroundBeing,
                     }
                 }
 
-                if (!closestBeing)
+                if (closestBeing == nullptr)
                 {
                     dist = d;
                     closestBeing = being;
@@ -1383,9 +1392,9 @@ bool ActorManager::validateBeing(const Being *const aroundBeing,
                                  const Being* const excluded,
                                  const int maxCost) const
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return false;
-    return being && ((being->getType() == type
+    return (being != nullptr) && ((being->getType() == type
         || type == ActorType::Unknown) && (being->isAlive()
         || (mTargetDeadPlayers && type == ActorType::Player))
         && being != aroundBeing) && being != excluded
@@ -1396,7 +1405,7 @@ bool ActorManager::validateBeing(const Being *const aroundBeing,
 #ifdef TMWA_SUPPORT
 void ActorManager::healTarget() const
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return;
 
     heal(localPlayer->getTarget());
@@ -1407,8 +1416,8 @@ void ActorManager::heal(const Being *const target) const
     if (Net::getNetworkType() != ServerType::TMWATHENA)
         return;
 
-    if (!localPlayer ||
-        !chatWindow ||
+    if (localPlayer == nullptr ||
+        chatWindow == nullptr ||
         !localPlayer->isAlive() ||
         !playerHandler->canUseMagic())
     {
@@ -1416,7 +1425,8 @@ void ActorManager::heal(const Being *const target) const
     }
 
     // self
-    if (target && localPlayer->getName() == target->getName())
+    if (target != nullptr &&
+        localPlayer->getName() == target->getName())
     {
         if (PlayerInfo::getAttribute(Attributes::PLAYER_MP) >= 6
             && PlayerInfo::getAttribute(Attributes::PLAYER_HP)
@@ -1428,12 +1438,13 @@ void ActorManager::heal(const Being *const target) const
         }
     }
     // magic levels < 2
-    else if (PlayerInfo::getSkillLevel(340) < 2
-             || PlayerInfo::getSkillLevel(341) < 2)
+    else if (PlayerInfo::getSkillLevel(340) < 2 ||
+             PlayerInfo::getSkillLevel(341) < 2)
     {
         if (PlayerInfo::getAttribute(Attributes::PLAYER_MP) >= 6)
         {
-            if (target && target->getType() != ActorType::Monster)
+            if (target != nullptr &&
+                target->getType() != ActorType::Monster)
             {
                 if (!PacketLimiter::limitPackets(PacketType::PACKET_CHAT))
                     return;
@@ -1453,11 +1464,12 @@ void ActorManager::heal(const Being *const target) const
     else
     {
         // mp > 10 and target not monster
-        if (PlayerInfo::getAttribute(Attributes::PLAYER_MP) >= 10 && target
-            && target->getType() != ActorType::Monster)
+        if (PlayerInfo::getAttribute(Attributes::PLAYER_MP) >= 10 &&
+            target != nullptr &&
+            target->getType() != ActorType::Monster)
         {
             // target not enemy
-            if (player_relations.getRelation(target->getName()) !=
+            if (playerRelations.getRelation(target->getName()) !=
                 Relation::ENEMY2)
             {
                 if (!PacketLimiter::limitPackets(PacketType::PACKET_CHAT))
@@ -1474,7 +1486,7 @@ void ActorManager::heal(const Being *const target) const
             }
         }
         // heal self if selected monster or selection empty
-        else if ((!target || target->getType() == ActorType::Monster)
+        else if ((target == nullptr || target->getType() == ActorType::Monster)
                  && PlayerInfo::getAttribute(Attributes::PLAYER_MP) >= 6
                  && PlayerInfo::getAttribute(Attributes::PLAYER_HP)
                  != PlayerInfo::getAttribute(Attributes::PLAYER_MAX_HP))
@@ -1489,7 +1501,7 @@ void ActorManager::heal(const Being *const target) const
 
 Being* ActorManager::findMostDamagedPlayer(const int maxTileDist) const
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return nullptr;
 
     int maxDamageTaken = 0;
@@ -1502,10 +1514,10 @@ Being* ActorManager::findMostDamagedPlayer(const int maxTileDist) const
 
         Being *const being = static_cast<Being*>(*it);
 
-        if (!being || !being->isAlive() ||     // don't heal dead
-            player_relations.getRelation(being->getName()) ==
-            Relation::ENEMY2 ||                // don't heal enemy
-            localPlayer == being)              // don't heal self
+        if ((being == nullptr) || !being->isAlive() ||  // don't heal dead
+            playerRelations.getRelation(being->getName()) ==
+            Relation::ENEMY2 ||                         // don't heal enemy
+            localPlayer == being)                       // don't heal self
         {
             continue;
         }
@@ -1532,8 +1544,8 @@ void ActorManager::itenplz() const
 {
     if (Net::getNetworkType() != ServerType::TMWATHENA)
         return;
-    if (!localPlayer ||
-        !chatWindow ||
+    if (localPlayer == nullptr ||
+        chatWindow == nullptr ||
         !localPlayer->isAlive() ||
         !playerHandler->canUseMagic())
     {
@@ -1581,7 +1593,7 @@ void ActorManager::printAllToChat()
 
 void ActorManager::printBeingsToChat(const std::string &header) const
 {
-    if (!debugChatTab)
+    if (debugChatTab == nullptr)
         return;
 
     debugChatTab->chatLog("---------------------------------------",
@@ -1612,7 +1624,7 @@ void ActorManager::printBeingsToChat(const std::string &header) const
     FOR_EACH (ActorSpritesMapConstIterator, itr, mActorsIdMap)
     {
         const ActorSprite *const actor = (*itr).second;
-        if (!actor)
+        if (actor == nullptr)
             continue;
         if (actor->getId() != (*itr).first)
             debugChatTab->chatLog("Actor with wrong key in map", "");
@@ -1639,7 +1651,7 @@ void ActorManager::printBeingsToChat(const std::string &header) const
 void ActorManager::printBeingsToChat(const std::vector<Being*> &beings,
                                      const std::string &header)
 {
-    if (!debugChatTab)
+    if (debugChatTab == nullptr)
         return;
 
     debugChatTab->chatLog("---------------------------------------",
@@ -1648,7 +1660,7 @@ void ActorManager::printBeingsToChat(const std::vector<Being*> &beings,
 
     FOR_EACH (std::vector<Being*>::const_iterator, i, beings)
     {
-        if (!*i)
+        if (*i == nullptr)
             continue;
 
         const Being *const being = *i;
@@ -1793,7 +1805,7 @@ void ActorManager::parseLevels(std::string levels) const
         {
             Being *const being = findBeingByName(part.substr(0, bktPos),
                 ActorType::Player);
-            if (being)
+            if (being != nullptr)
             {
                 being->setLevel(atoi(part.substr(bktPos + 1).c_str()));
                 being->addToCache();
@@ -1971,7 +1983,7 @@ int ActorManager::getPickupItemIndex(const std::string &name) const
     i_end = list.end();\
     while (i != i_end)\
     {\
-        if (*i == "")\
+        if ((*i).empty())\
             empty = true;\
         m##mob##s.push_back(*i);\
         m##mob##sSet.insert(*i);\
@@ -2029,7 +2041,7 @@ bool ActorManager::checkForPickup(const FloorItem *const item) const
             return true;
         }
     }
-    else if (item && mPickupItemsSet.find(item->getName())
+    else if ((item != nullptr) && mPickupItemsSet.find(item->getName())
              != mPickupItemsSet.end())
     {
         return true;
@@ -2073,7 +2085,7 @@ Being *ActorManager::cloneBeing(const Being *const srcBeing,
         toInt(srcBeing->getId(), int) + id, BeingId),
         ActorType::Player,
         srcBeing->getSubType());
-    if (!dstBeing)
+    if (dstBeing == nullptr)
         return nullptr;
     dstBeing->setGender(srcBeing->getGender());
     dstBeing->setAction(srcBeing->getCurrentAction(), 0);
@@ -2118,7 +2130,7 @@ void ActorManager::updateBadges() const
         if (actor->getType() == ActorType::Player)
         {
             Being *const being = static_cast<Being*>(actor);
-            being->showBadges(showBadges);
+            being->showBadges(showBadges != 0u);
         }
     }
 }
@@ -2129,7 +2141,7 @@ void ActorManager::updateNameId(const std::string &name,
     if (!mEnableIdCollecting)
         return;
     const int id = CAST_S32(beingId);
-    if (id &&
+    if ((id != 0) &&
         (id < 2000000 ||
         id >= 110000000))
     {
@@ -2145,10 +2157,9 @@ void ActorManager::updateNameId(const std::string &name,
         std::string dir;
         if (beingId != BeingId_zero)
         {
-            dir = settings.usersIdDir;
-            dir.append(idStr);
-            dir.append("/");
-            dir.append(stringToHexPath(name));
+            dir = pathJoin(settings.usersIdDir,
+                idStr,
+                stringToHexPath(name));
             Files::saveTextFile(dir,
                 "info.txt",
                 (name + "\n").append(dateStr));
@@ -2171,7 +2182,7 @@ void ActorManager::updateSeenPlayers(const std::set<std::string>
     FOR_EACH (std::set<std::string>::const_iterator, it, onlinePlayers)
     {
         const std::string name = *it;
-        if (!findBeingByName(name, ActorType::Player))
+        if (findBeingByName(name, ActorType::Player) == nullptr)
             updateNameId(name, BeingId_zero);
     }
 }
@@ -2199,7 +2210,7 @@ void ActorManager::removeRoom(const int chatId)
         {
             Being *const being = static_cast<Being*>(actor);
             const ChatObject *const chat = being->getChat();
-            if (chat && chat->chatId == chatId)
+            if ((chat != nullptr) && chat->chatId == chatId)
             {
                 being->setChat(nullptr);
             }
@@ -2209,7 +2220,7 @@ void ActorManager::removeRoom(const int chatId)
 
 void ActorManager::updateRoom(const ChatObject *const newChat)
 {
-    if (!newChat)
+    if (newChat == nullptr)
         return;
 
     for_actors
@@ -2219,7 +2230,7 @@ void ActorManager::updateRoom(const ChatObject *const newChat)
         {
             const Being *const being = static_cast<const Being*>(actor);
             ChatObject *const chat = being->getChat();
-            if (chat && chat->chatId == newChat->chatId)
+            if ((chat != nullptr) && chat->chatId == newChat->chatId)
             {
                 chat->ownerId = newChat->ownerId;
                 chat->maxUsers = newChat->maxUsers;
@@ -2243,7 +2254,7 @@ void ActorManager::addChar(const int32_t id,
 {
     mChars[id] = name;
 
-    if (!guiInput)
+    if (guiInput == nullptr)
         return;
 
     guiInput->simulateMouseMove();
