@@ -47,9 +47,12 @@
 
 #include "utils/timer.h"
 
+PRAGMA48(GCC diagnostic push)
+PRAGMA48(GCC diagnostic ignored "-Wshadow")
 #ifndef SDL_BIG_ENDIAN
 #include <SDL_endian.h>
 #endif  // SDL_BYTEORDER
+PRAGMA48(GCC diagnostic pop)
 #endif  // USE_SDL2
 
 #include "debug.h"
@@ -97,7 +100,7 @@ bool CompoundSprite::reset()
     bool ret = false;
     FOR_EACH (SpriteIterator, it, mSprites)
     {
-        if (*it)
+        if (*it != nullptr)
             ret |= (*it)->reset();
     }
     if (ret)
@@ -112,7 +115,7 @@ bool CompoundSprite::play(const std::string &action)
     bool ret2 = true;
     FOR_EACH (SpriteIterator, it, mSprites)
     {
-        if (*it)
+        if (*it != nullptr)
         {
             const bool tmpVal = (*it)->play(action);
             ret |= tmpVal;
@@ -133,7 +136,7 @@ bool CompoundSprite::update(const int time)
     mLastTime = time;
     FOR_EACH (SpriteIterator, it, mSprites)
     {
-        if (*it)
+        if (*it != nullptr)
             ret |= (*it)->update(time);
     }
     mNeedsRedraw |= ret;
@@ -151,11 +154,11 @@ void CompoundSprite::drawSimple(Graphics *const graphics,
     if (mSprites.empty())  // Nothing to draw
         return;
 
-    if (mAlpha == 1.0F && mImage)
+    if (mAlpha == 1.0F && (mImage != nullptr))
     {
         graphics->drawImage(mImage, posX + mOffsetX, posY + mOffsetY);
     }
-    else if (mAlpha && mAlphaImage)
+    else if ((mAlpha != 0.0f) && (mAlphaImage != nullptr))
     {
         mAlphaImage->setAlpha(mAlpha);
         graphics->drawImage(mAlphaImage,
@@ -173,7 +176,7 @@ void CompoundSprite::drawSprites(Graphics *const graphics,
 {
     FOR_EACH (SpriteConstIterator, it, mSprites)
     {
-        if (*it)
+        if (*it != nullptr)
         {
             (*it)->setAlpha(mAlpha);
             (*it)->draw(graphics, posX, posY);
@@ -187,7 +190,7 @@ void CompoundSprite::drawSpritesSDL(Graphics *const graphics,
 {
     FOR_EACH (SpriteConstIterator, it, mSprites)
     {
-        if (*it)
+        if (*it != nullptr)
             (*it)->draw(graphics, posX, posY);
     }
 }
@@ -197,7 +200,7 @@ int CompoundSprite::getWidth() const
     FOR_EACH (SpriteConstIterator, it, mSprites)
     {
         const Sprite *const base = *it;
-        if (base)
+        if (base != nullptr)
             return base->getWidth();
     }
 
@@ -209,7 +212,7 @@ int CompoundSprite::getHeight() const
     FOR_EACH (SpriteConstIterator, it, mSprites)
     {
         const Sprite *const base = *it;
-        if (base)
+        if (base != nullptr)
             return base->getHeight();
     }
 
@@ -226,7 +229,7 @@ bool CompoundSprite::setSpriteDirection(const SpriteDirection::Type direction)
     bool ret = false;
     FOR_EACH (SpriteIterator, it, mSprites)
     {
-        if (*it)
+        if (*it != nullptr)
             ret |= (*it)->setSpriteDirection(direction);
     }
     if (ret)
@@ -237,7 +240,7 @@ bool CompoundSprite::setSpriteDirection(const SpriteDirection::Type direction)
 
 int CompoundSprite::getNumberOfLayers() const
 {
-    if (mImage || mAlphaImage)
+    if ((mImage != nullptr) || (mAlphaImage != nullptr))
         return 1;
     else
         return CAST_S32(mSprites.size());
@@ -247,7 +250,7 @@ unsigned int CompoundSprite::getCurrentFrame() const
 {
     FOR_EACH (SpriteConstIterator, it, mSprites)
     {
-        if (*it)
+        if (*it != nullptr)
             return (*it)->getCurrentFrame();
     }
     return 0;
@@ -257,7 +260,7 @@ unsigned int CompoundSprite::getFrameCount() const
 {
     FOR_EACH (SpriteConstIterator, it, mSprites)
     {
-        if (*it)
+        if (*it != nullptr)
             return (*it)->getFrameCount();
     }
     return 0;
@@ -283,7 +286,7 @@ void CompoundSprite::setSprite(const size_t layer, Sprite *const sprite)
 void CompoundSprite::removeSprite(const int layer)
 {
     // Skip if it won't change anything
-    if (!mSprites[layer])
+    if (mSprites[layer] == nullptr)
         return;
 
     delete2(mSprites[layer]);
@@ -334,10 +337,10 @@ void CompoundSprite::redraw() const
     SDL_Surface *const surface = MSDL_CreateRGBSurface(SDL_HWSURFACE,
         BUFFER_WIDTH, BUFFER_HEIGHT, 32, rmask, gmask, bmask, amask);
 
-    if (!surface)
+    if (surface == nullptr)
         return;
 
-    SurfaceGraphics *graphics = new SurfaceGraphics();
+    SurfaceGraphics *graphics = new SurfaceGraphics;
     graphics->setBlitMode(BlitMode::BLIT_GFX);
     graphics->setTarget(surface);
     graphics->beginDraw();
@@ -346,10 +349,10 @@ void CompoundSprite::redraw() const
     int tileY = mapTileSize;
 
     const Game *const game = Game::instance();
-    if (game)
+    if (game != nullptr)
     {
         const Map *const map = game->getCurrentMap();
-        if (map)
+        if (map != nullptr)
         {
             tileX = map->getTileWidth() / 2;
             tileY = map->getTileWidth();
@@ -366,20 +369,15 @@ void CompoundSprite::redraw() const
 
     delete2(graphics);
 
-    SDL_Surface *const surfaceA = MSDL_CreateRGBSurface(SDL_HWSURFACE,
-        BUFFER_WIDTH, BUFFER_HEIGHT, 32, rmask, gmask, bmask, amask);
-
     SDL_SetAlpha(surface, 0, SDL_ALPHA_OPAQUE);
-    SDL_BlitSurface(surface, nullptr, surfaceA, nullptr);
 
-    delete mImage;
     delete mAlphaImage;
 
-    mImage = imageHelper->loadSurface(surface);
-    MSDL_FreeSurface(surface);
-
     if (ImageHelper::mEnableAlpha)
     {
+        SDL_Surface *const surfaceA = MSDL_CreateRGBSurface(SDL_HWSURFACE,
+            BUFFER_WIDTH, BUFFER_HEIGHT, 32, rmask, gmask, bmask, amask);
+        SDL_BlitSurface(surface, nullptr, surfaceA, nullptr);
         mAlphaImage = imageHelper->loadSurface(surfaceA);
         MSDL_FreeSurface(surfaceA);
     }
@@ -387,6 +385,10 @@ void CompoundSprite::redraw() const
     {
         mAlphaImage = nullptr;
     }
+
+    delete mImage;
+    mImage = imageHelper->loadSurface(surface);
+    MSDL_FreeSurface(surface);
 #endif  // USE_SDL2
 }
 
@@ -402,7 +404,7 @@ void CompoundSprite::setAlpha(float alpha)
         {
             FOR_EACH (SpriteConstIterator, it, mSprites)
             {
-                if (*it)
+                if (*it != nullptr)
                     (*it)->setAlpha(alpha);
             }
         }
@@ -438,7 +440,7 @@ void CompoundSprite::updateImages() const
 
             redraw();
 
-            if (mImage)
+            if (mImage != nullptr)
                 initCurrentCacheItem();
         }
         else
@@ -455,7 +457,7 @@ bool CompoundSprite::updateFromCache() const
 //    static int hits = 0;
 //    static int miss = 0;
 
-    if (mCacheItem && mCacheItem->image)
+    if ((mCacheItem != nullptr) && (mCacheItem->image != nullptr))
     {
         imagesCache.push_front(mCacheItem);
         mCacheItem = nullptr;
@@ -477,7 +479,7 @@ bool CompoundSprite::updateFromCache() const
     FOR_EACH (ImagesCache::iterator, it, imagesCache)
     {
         CompoundItem *const ic = *it;
-        if (ic && ic->data.size() == sz)
+        if ((ic != nullptr) && ic->data.size() == sz)
         {
             bool fail(false);
             VectorPointers::const_iterator it2 = ic->data.begin();
@@ -490,9 +492,9 @@ bool CompoundSprite::updateFromCache() const
             {
                 const void *ptr1 = nullptr;
                 const void *ptr2 = nullptr;
-                if (*it1)
+                if (*it1 != nullptr)
                     ptr1 = (*it1)->getHash();
-                if (*it2)
+                if (*it2 != nullptr)
                     ptr2 = *it2;
                 if (ptr1 != ptr2)
                 {
@@ -521,14 +523,14 @@ bool CompoundSprite::updateFromCache() const
 void CompoundSprite::initCurrentCacheItem() const
 {
     delete mCacheItem;
-    mCacheItem = new CompoundItem();
+    mCacheItem = new CompoundItem;
     mCacheItem->image = mImage;
     mCacheItem->alphaImage = mAlphaImage;
 //    mCacheItem->alpha = mAlpha;
 
     FOR_EACH (SpriteConstIterator, it, mSprites)
     {
-        if (*it)
+        if (*it != nullptr)
             mCacheItem->data.push_back((*it)->getHash());
         else
             mCacheItem->data.push_back(nullptr);
@@ -540,7 +542,7 @@ bool CompoundSprite::updateNumber(const unsigned num)
     bool res(false);
     FOR_EACH (SpriteConstIterator, it, mSprites)
     {
-        if (*it)
+        if (*it != nullptr)
         {
             if ((*it)->updateNumber(num))
                 res = true;
