@@ -33,7 +33,6 @@
 #include "settings.h"
 #include "soundmanager.h"
 #include "spellmanager.h"
-#include "units.h"
 
 #include "being/localplayer.h"
 #include "being/playerinfo.h"
@@ -43,11 +42,8 @@
 
 #include "enums/being/attributesstrings.h"
 
-#include "input/inputmanager.h"
-#include "input/joystick.h"
-#include "input/keyboardconfig.h"
-
-#include "input/touch/touchmanager.h"
+#include "fs/virtfs/fs.h"
+#include "fs/virtfs/tools.h"
 
 #include "gui/dialogsmanager.h"
 #include "gui/gui.h"
@@ -80,6 +76,12 @@
 #include "gui/widgets/desktop.h"
 #include "gui/widgets/windowcontainer.h"
 
+#include "input/inputmanager.h"
+#include "input/joystick.h"
+#include "input/keyboardconfig.h"
+
+#include "input/touch/touchmanager.h"
+
 #include "net/charserverhandler.h"
 #include "net/chathandler.h"
 #include "net/download.h"
@@ -113,6 +115,8 @@
 #include "resources/db/horsedb.h"
 #include "resources/db/itemdb.h"
 #include "resources/db/itemfielddb.h"
+#include "resources/db/itemoptiondb.h"
+#include "resources/db/languagedb.h"
 #include "resources/db/sounddb.h"
 #include "resources/db/mapdb.h"
 #include "resources/db/mercenarydb.h"
@@ -126,12 +130,17 @@
 #include "resources/db/skillunitdb.h"
 #include "resources/db/statdb.h"
 #include "resources/db/statuseffectdb.h"
+#include "resources/db/textdb.h"
+#include "resources/db/unitsdb.h"
 #include "resources/db/weaponsdb.h"
 
+#include "resources/dye/dyepalette.h"
+
 #include "resources/resourcemanager/resourcemanager.h"
 
 #include "resources/sprite/spritereference.h"
 
+#include "utils/checkutils.h"
 #include "utils/cpu.h"
 #include "utils/delete2.h"
 #include "utils/dumplibs.h"
@@ -141,9 +150,8 @@
 #include "utils/gettexthelper.h"
 #include "utils/mrand.h"
 #ifdef ANDROID
-#include "utils/paths.h"
+#include "fs/paths.h"
 #endif  // ANDROID
-#include "utils/physfstools.h"
 #include "utils/sdlcheckutils.h"
 #include "utils/timer.h"
 
@@ -160,14 +168,20 @@
 #endif  // USE_OPENGL
 
 #ifdef WIN32
+PRAGMA48(GCC diagnostic push)
+PRAGMA48(GCC diagnostic ignored "-Wshadow")
 #include <SDL_syswm.h>
-#include "utils/specialfolder.h"
+PRAGMA48(GCC diagnostic pop)
+#include "fs/specialfolder.h"
 #undef ERROR
 #endif  // WIN32
 
 #ifdef ANDROID
 #ifndef USE_SDL2
+PRAGMA48(GCC diagnostic push)
+PRAGMA48(GCC diagnostic ignored "-Wshadow")
 #include <SDL_screenkeyboard.h>
+PRAGMA48(GCC diagnostic pop)
 #include <fstream>
 #endif  // USE_SDL2
 #endif  // ANDROID
@@ -178,11 +192,14 @@
 #include "mumblemanager.h"
 #endif  // USE_MUMBLE
 
+PRAGMA48(GCC diagnostic push)
+PRAGMA48(GCC diagnostic ignored "-Wshadow")
 #ifdef USE_SDL2
 #include <SDL2_framerate.h>
 #else  // USE_SDL2
 #include <SDL_framerate.h>
 #endif  // USE_SDL2
+PRAGMA48(GCC diagnostic pop)
 
 #include "debug.h"
 
@@ -202,6 +219,7 @@ time_t start_time;
 unsigned int mLastHost = 0;
 unsigned long mSearchHash = 0;
 int textures_count = 0;
+volatile bool isTerminate = false;
 
 namespace
 {
@@ -213,7 +231,7 @@ namespace
 
             A_DELETE_COPY(AccountListener)
 
-            void action(const ActionEvent &) override final
+            void action(const ActionEvent &event A_UNUSED) override final
             {
                 client->setState(State::CHAR_SELECT);
             }
@@ -227,7 +245,7 @@ namespace
 
             A_DELETE_COPY(LoginListener)
 
-            void action(const ActionEvent &) override final
+            void action(const ActionEvent &event A_UNUSED) override final
             {
                 client->setState(State::PRE_LOGIN);
             }
@@ -295,15 +313,23 @@ void Client::gameInit()
 
     // Configure logger
     if (!settings.options.logFileName.empty())
+    {
         settings.logFileName = settings.options.logFileName;
+    }
     else
-        settings.logFileName = settings.localDataDir + "/manaplus.log";
+    {
+        settings.logFileName = pathJoin(settings.localDataDir,
+            "manaplus.log");
+    }
+    logger->log("Log file: " + settings.logFileName);
     logger->setLogFile(settings.logFileName);
 
 #ifdef USE_FUZZER
     Fuzzer::init();
 #endif  // USE_FUZZER
 
+    if (settings.options.ipc == true)
+        IPC::start();
     if (settings.options.test.empty())
         ConfigManager::backupConfig("config.xml");
     ConfigManager::initConfiguration();
@@ -323,8 +349,7 @@ void Client::gameInit()
         ConfigManager::storeSafeParameters();
 #endif  // ANDROID
 
-    ResourceManager::init();
-    if (!resourceManager->setWriteDir(settings.localDataDir))
+    if (!VirtFs::setWriteDir(settings.localDataDir))
     {
         logger->error(strprintf("%s couldn't be set as home directory! "
             "Exiting.", settings.localDataDir.c_str()));
@@ -387,10 +412,12 @@ void Client::gameInit()
     ConfigManager::checkConfigVersion();
     logVars();
     Cpu::detect();
+    DyePalette::initFunctions();
 #if defined(USE_OPENGL)
 #if !defined(ANDROID) && !defined(__APPLE__) && \
     !defined(__native_client__) && !defined(UNITTESTS)
     if (!settings.options.safeMode &&
+        settings.options.renderer < 0 &&
         settings.options.test.empty() &&
         !config.getBoolValue("videodetected"))
     {
@@ -414,13 +441,15 @@ void Client::gameInit()
     // Add the main data directories to our PhysicsFS search path
     if (!settings.options.dataPath.empty())
     {
-        resourceManager->addToSearchPath(settings.options.dataPath,
+        VirtFs::mountDir(settings.options.dataPath,
             Append_false);
     }
 
     // Add the local data directory to PhysicsFS search path
-    resourceManager->addToSearchPath(settings.localDataDir, Append_false);
+    VirtFs::mountDir(settings.localDataDir,
+        Append_false);
     TranslationManager::loadCurrentLang();
+    TranslationManager::loadDictionaryLang();
 #ifdef ENABLE_CUSTOMNLS
     TranslationManager::loadGettextLang();
 #endif  // ENABLE_CUSTOMNLS
@@ -440,7 +469,7 @@ void Client::gameInit()
     emoteShortcut = new EmoteShortcut;
     dropShortcut = new DropShortcut;
 
-    gui = new Gui();
+    gui = new Gui;
     gui->postInit(mainGraphics);
     dialogsManager = new DialogsManager;
     popupManager = new PopupManager;
@@ -453,12 +482,12 @@ void Client::gameInit()
     inputManager.init();
 
     // Initialise player relations
-    player_relations.init();
+    playerRelations.init();
     Joystick::init();
     WindowManager::createWindows();
 
     keyboard.update();
-    if (joystick)
+    if (joystick != nullptr)
         joystick->update();
 
     // Initialize default server
@@ -473,7 +502,7 @@ void Client::gameInit()
     loginData.username = settings.options.username;
     loginData.password = settings.options.password;
     LoginDialog::savedPassword = settings.options.password;
-    loginData.remember = serverConfig.getValue("remember", 1);
+    loginData.remember = (serverConfig.getValue("remember", 1) != 0);
     loginData.registerLogin = false;
 
     if (mCurrentServer.hostname.empty())
@@ -522,15 +551,17 @@ void Client::gameInit()
 
 #ifdef USE_MUMBLE
     if (!mumbleManager)
-        mumbleManager = new MumbleManager();
+        mumbleManager = new MumbleManager;
 #endif  // USE_MUMBLE
 
     mSkin = theme->load("windowmenu.xml", "");
-    if (mSkin)
+    if (mSkin != nullptr)
     {
         mButtonPadding = mSkin->getPadding();
         mButtonSpacing = mSkin->getOption("spacing", 3);
     }
+    if (settings.options.error)
+        inputManager.executeAction(InputAction::ERROR);
 }
 
 Client::~Client()
@@ -603,15 +634,18 @@ void Client::testsClear()
 
 void Client::gameClear()
 {
-    if (logger)
+    if (logger != nullptr)
         logger->log1("Quitting1");
+    isTerminate = true;
     config.removeListeners(this);
 
     delete2(assertListener);
 
+    if (ipc != nullptr)
+        ipc->stop();
     eventsManager.shutdown();
     WindowManager::deleteWindows();
-    if (windowContainer)
+    if (windowContainer != nullptr)
         windowContainer->slowLogic();
 
     stopTimers();
@@ -622,8 +656,11 @@ void Client::gameClear()
     DeadDB::unload();
     ColorDB::unload();
     SoundDB::unload();
+    LanguageDb::unload();
+    TextDb::unload();
     EmoteDB::unload();
     ItemDB::unload();
+    ItemOptionDb::unload();
     ItemFieldDb::unload();
     const ServerTypeT type = Net::getNetworkType();
     if (type == ServerType::EATHENA ||
@@ -647,13 +684,13 @@ void Client::gameClear()
     StatusEffectDB::unload();
     ModDB::unload();
 
-    if (loginHandler)
+    if (loginHandler != nullptr)
         loginHandler->clearWorlds();
 
-    if (chatHandler)
+    if (chatHandler != nullptr)
         chatHandler->clear();
 
-    if (charServerHandler)
+    if (charServerHandler != nullptr)
         charServerHandler->clear();
 
     delete2(ipc);
@@ -670,9 +707,9 @@ void Client::gameClear()
     delete2(emoteShortcut);
     delete2(dropShortcut);
 
-    player_relations.store();
+    playerRelations.store();
 
-    if (logger)
+    if (logger != nullptr)
         logger->log1("Quitting2");
 
     delete2(mCurrentDialog);
@@ -680,22 +717,22 @@ void Client::gameClear()
     delete2(dialogsManager);
     delete2(gui);
 
-    if (inventoryHandler)
+    if (inventoryHandler != nullptr)
         inventoryHandler->clear();
 
-    if (logger)
+    if (logger != nullptr)
         logger->log1("Quitting3");
 
     touchManager.clear();
 
     graphicsManager.deleteRenderers();
 
-    if (logger)
+    if (logger != nullptr)
         logger->log1("Quitting4");
 
     XML::cleanupXML();
 
-    if (logger)
+    if (logger != nullptr)
         logger->log1("Quitting5");
 
     BeingInfo::clear();
@@ -703,26 +740,26 @@ void Client::gameClear()
     // Shutdown sound
     soundManager.close();
 
-    if (logger)
+    if (logger != nullptr)
         logger->log1("Quitting6");
 
     ActorSprite::unload();
 
     ResourceManager::deleteInstance();
 
-    if (logger)
+    if (logger != nullptr)
         logger->log1("Quitting8");
 
     WindowManager::deleteIcon();
 
-    if (logger)
+    if (logger != nullptr)
         logger->log1("Quitting9");
 
     delete2(joystick);
 
     keyboard.deinit();
 
-    if (logger)
+    if (logger != nullptr)
         logger->log1("Quitting10");
 
     soundManager.shutdown();
@@ -739,7 +776,7 @@ void Client::gameClear()
     config.clear();
     serverConfig.clear();
 
-    if (logger)
+    if (logger != nullptr)
         logger->log1("Quitting11");
 
 #ifdef USE_PROFILER
@@ -781,8 +818,8 @@ int Client::testsExec()
 
 void Client::stateConnectGame1()
 {
-    if (gameHandler &&
-        loginHandler &&
+    if ((gameHandler != nullptr) &&
+        (loginHandler != nullptr) &&
         gameHandler->isConnected())
     {
         loginHandler->disconnect();
@@ -798,7 +835,7 @@ void Client::stateConnectServer1()
         PacketLimiter::initPacketLimiter();
         initTradeFilter();
         Dirs::initUsersDir();
-        player_relations.init();
+        playerRelations.init();
 
         // Initialize the item and emote shortcuts.
         for (unsigned f = 0; f < SHORTCUT_TABS; f ++)
@@ -824,8 +861,8 @@ void Client::stateConnectServer1()
         settings.persistentIp = mCurrentServer.persistentIp;
         settings.supportUrl = mCurrentServer.supportUrl;
         settings.updateMirrors = mCurrentServer.updateMirrors;
-        settings.enableRemoteCommands = serverConfig.getValue(
-            "enableRemoteCommands", 1);
+        settings.enableRemoteCommands = (serverConfig.getValue(
+            "enableRemoteCommands", 1) != 0);
 
         if (settings.options.username.empty())
         {
@@ -841,7 +878,7 @@ void Client::stateConnectServer1()
         settings.login = loginData.username;
         WindowManager::updateTitle();
 
-        loginData.remember = serverConfig.getValue("remember", 1);
+        loginData.remember = (serverConfig.getValue("remember", 1) != 0);
         Net::connectToServer(mCurrentServer);
 
 #ifdef USE_MUMBLE
@@ -860,7 +897,7 @@ void Client::stateConnectServer1()
         }
     }
     else if (mOldState != State::CHOOSE_SERVER &&
-             loginHandler &&
+             (loginHandler != nullptr) &&
              loginHandler->isConnected())
     {
         mState = State::PRE_LOGIN;
@@ -870,7 +907,7 @@ void Client::stateConnectServer1()
 void Client::stateWorldSelect1()
 {
     if (mOldState == State::UPDATE &&
-        loginHandler)
+        (loginHandler != nullptr))
     {
         if (loginHandler->getWorlds().size() < 2)
             mState = State::PRE_LOGIN;
@@ -879,13 +916,13 @@ void Client::stateWorldSelect1()
 
 void Client::stateGame1()
 {
-    if (!gui)
+    if (gui == nullptr)
         return;
 
     BasicContainer2 *const top = static_cast<BasicContainer2*>(
         gui->getTop());
 
-    if (!top)
+    if (top == nullptr)
         return;
 
     CREATEWIDGETV(desktop, Desktop, nullptr);
@@ -922,7 +959,7 @@ void Client::stateGame1()
 void Client::stateSwitchLogin1()
 {
     if (mOldState == State::GAME &&
-        gameHandler)
+        (gameHandler != nullptr))
     {
         gameHandler->disconnect();
     }
@@ -939,21 +976,21 @@ int Client::gameExec()
             continue;
 
         BLOCK_START("Client::gameExec 3")
-        if (generalHandler)
+        if (generalHandler != nullptr)
             generalHandler->flushNetwork();
         BLOCK_END("Client::gameExec 3")
 
         BLOCK_START("Client::gameExec 4")
-        if (gui)
+        if (gui != nullptr)
             gui->logic();
         cur_time = time(nullptr);
         int k = 0;
         while (lastTickTime != tick_time &&
                k < 40)
         {
-            if (mGame)
+            if (mGame != nullptr)
                 mGame->logic();
-            else if (gui)
+            else if (gui != nullptr)
                 gui->handleInput();
 
             ++lastTickTime;
@@ -962,9 +999,9 @@ int Client::gameExec()
         soundManager.logic();
 
         logic_count += k;
-        if (gui)
+        if (gui != nullptr)
             gui->slowLogic();
-        if (mGame)
+        if (mGame != nullptr)
             mGame->slowLogic();
         slowLogic();
         BLOCK_END("Client::gameExec 4")
@@ -976,7 +1013,7 @@ int Client::gameExec()
         if (!WindowManager::getIsMinimized())
         {
             frame_count++;
-            if (gui)
+            if (gui != nullptr)
                 gui->draw();
             mainGraphics->updateScreen();
         }
@@ -1024,15 +1061,15 @@ int Client::gameExec()
                 delete2(mGame);
                 assertListener = new AssertListener;
                 Game::clearInstance();
-                resourceManager->cleanOrphans();
+                ResourceManager::cleanOrphans();
                 Party::clearParties();
                 Guild::clearGuilds();
                 NpcDialog::clearDialogs();
-                if (guildHandler)
+                if (guildHandler != nullptr)
                     guildHandler->clear();
-                if (partyHandler)
+                if (partyHandler != nullptr)
                     partyHandler->clear();
-                if (chatLogger)
+                if (chatLogger != nullptr)
                     chatLogger->clear();
                 if (!settings.options.dataPath.empty())
                     UpdaterWindow::unloadMods(settings.options.dataPath);
@@ -1043,8 +1080,11 @@ int Client::gameExec()
             }
             else if (mOldState == State::CHAR_SELECT)
             {
-                if (mState != State::CHANGEPASSWORD && charServerHandler)
+                if (mState != State::CHANGEPASSWORD &&
+                    charServerHandler != nullptr)
+                {
                     charServerHandler->clear();
+                }
             }
 
             mOldState = mState;
@@ -1054,7 +1094,7 @@ int Client::gameExec()
 
             // State has changed, while the quitDialog was active, it might
             // not be correct anymore
-            if (mQuitDialog)
+            if (mQuitDialog != nullptr)
             {
                 mQuitDialog->scheduleDelete();
                 mQuitDialog = nullptr;
@@ -1073,7 +1113,7 @@ int Client::gameExec()
                     if (settings.options.dataPath.empty())
                     {
                         // Add customdata directory
-                        resourceManager->searchAndRemoveArchives(
+                        VirtFs::searchAndRemoveArchives(
                             "customdata/",
                             "zip");
                     }
@@ -1086,19 +1126,17 @@ int Client::gameExec()
 
                     if (!settings.options.skipUpdate)
                     {
-                        resourceManager->searchAndRemoveArchives(
-                            settings.updatesDir +
-                            "/local/",
+                        VirtFs::searchAndRemoveArchives(
+                            pathJoin(settings.updatesDir, "local/"),
                             "zip");
 
-                        resourceManager->removeFromSearchPath(
-                            settings.localDataDir +
-                            dirSeparator +
-                            settings.updatesDir +
-                            "/local/");
+                        VirtFs::unmountDirSilent(pathJoin(
+                            settings.localDataDir,
+                            settings.updatesDir,
+                            "local/"));
                     }
 
-                    resourceManager->clearCache();
+                    ResourceManager::clearCache();
 
                     loginData.clearUpdateHost();
                     serverVersion = 0;
@@ -1142,6 +1180,7 @@ int Client::gameExec()
                         _("Connecting to server"),
                         State::SWITCH_SERVER);
                     TranslationManager::loadCurrentLang();
+                    TranslationManager::loadDictionaryLang();
                     BLOCK_END("Client::gameExec State::CONNECT_SERVER")
                     break;
 
@@ -1198,7 +1237,7 @@ int Client::gameExec()
                         // TRANSLATORS: connection dialog header
                         _("Logging in"),
                         State::SWITCH_SERVER);
-                    if (loginHandler)
+                    if (loginHandler != nullptr)
                         loginHandler->loginOrRegister(&loginData);
                     BLOCK_END("Client::gameExec State::LOGIN_ATTEMPT")
                     break;
@@ -1208,7 +1247,8 @@ int Client::gameExec()
                     logger->log1("State: WORLD SELECT");
                     {
                         TranslationManager::loadCurrentLang();
-                        if (!loginHandler)
+                        TranslationManager::loadDictionaryLang();
+                        if (loginHandler == nullptr)
                         {
                             BLOCK_END("Client::gameExec State::WORLD_SELECT")
                             break;
@@ -1270,18 +1310,17 @@ int Client::gameExec()
                         settings.oldUpdates.clear();
                         UpdaterWindow::loadDirMods(settings.options.dataPath);
                     }
-                    else if (loginData.updateType & UpdateType::Skip)
+                    else if ((loginData.updateType & UpdateType::Skip) != 0)
                     {
-                        settings.oldUpdates = settings.localDataDir
-                            + dirSeparator + settings.updatesDir;
+                        settings.oldUpdates = pathJoin(settings.localDataDir,
+                            settings.updatesDir);
                         UpdaterWindow::loadLocalUpdates(settings.oldUpdates);
                         mState = State::LOAD_DATA;
                     }
                     else
                     {
-                        settings.oldUpdates = settings.localDataDir +
-                            dirSeparator +
-                            settings.updatesDir;
+                        settings.oldUpdates = pathJoin(settings.localDataDir,
+                            settings.updatesDir);
                         CREATEWIDGETV(mCurrentDialog, UpdaterWindow,
                             settings.updateHost,
                             settings.oldUpdates,
@@ -1301,7 +1340,7 @@ int Client::gameExec()
                     if (settings.options.dataPath.empty())
                     {
                         // Add customdata directory
-                        resourceManager->searchAndAddArchives(
+                        VirtFs::searchAndAddArchives(
                             "customdata/",
                             "zip",
                             Append_false);
@@ -1309,35 +1348,35 @@ int Client::gameExec()
 
                     if (!settings.options.skipUpdate)
                     {
-                        resourceManager->searchAndAddArchives(
+                        VirtFs::searchAndAddArchives(
                             settings.updatesDir + "/local/",
                             "zip",
                             Append_false);
 
-                        resourceManager->addToSearchPath(
-                            settings.localDataDir +
-                            dirSeparator +
-                            settings.updatesDir +
-                            "/local/",
+                        VirtFs::mountDir(pathJoin(
+                            settings.localDataDir,
+                            settings.updatesDir,
+                            "local/"),
                             Append_false);
                     }
 
                     logger->log("Init paths");
-                    paths.init("paths.xml", UseResman_true);
+                    paths.init("paths.xml", UseVirtFs_true);
                     paths.setDefaultValues(getPathsDefaults());
                     initPaths();
-                    if (!SpriteReference::Empty)
+                    if (SpriteReference::Empty == nullptr)
                     {
                         SpriteReference::Empty = new SpriteReference(
                             paths.getStringValue("spriteErrorFile"),
                             0);
                     }
 
-                    if (!BeingInfo::unknown)
+                    if (BeingInfo::unknown == nullptr)
                         BeingInfo::unknown = new BeingInfo;
 
                     initFeatures();
                     TranslationManager::loadCurrentLang();
+                    TranslationManager::loadDictionaryLang();
                     PlayerInfo::stateChange(mState);
 
                     delete spellManager;
@@ -1353,8 +1392,11 @@ int Client::gameExec()
                     PaletteDB::load();
                     ColorDB::load();
                     SoundDB::load();
+                    LanguageDb::load();
+                    TextDb::load();
                     MapDB::load();
                     ItemFieldDb::load();
+                    ItemOptionDb::load();
                     ItemDB::load();
                     Being::load();
                     const ServerTypeT type = Net::getNetworkType();
@@ -1362,7 +1404,7 @@ int Client::gameExec()
                         type == ServerType::EVOL2)
                     {
                         NetworkDb::load();
-                        if (loginHandler)
+                        if (loginHandler != nullptr)
                             loginHandler->updatePacketVersion();
                         MercenaryDB::load();
                         HomunculusDB::load();
@@ -1374,18 +1416,18 @@ int Client::gameExec()
                     AvatarDB::load();
                     BadgesDB::load();
                     WeaponsDB::load();
+                    UnitsDb::loadUnits();
                     NPCDB::load();
                     NpcDialogDB::load();
                     PETDB::load();
                     EmoteDB::load();
 //                    ModDB::load();
                     StatusEffectDB::load();
-                    Units::loadUnits();
                     EquipmentWindow::prepareSlotNames();
 
                     ActorSprite::load();
 
-                    if (desktop)
+                    if (desktop != nullptr)
                         desktop->reloadWallpaper();
 
                     mState = State::GET_CHARACTERS;
@@ -1399,7 +1441,7 @@ int Client::gameExec()
                         // TRANSLATORS: connection dialog header
                         _("Requesting characters"),
                         State::SWITCH_SERVER);
-                    if (charServerHandler)
+                    if (charServerHandler != nullptr)
                         charServerHandler->requestCharacters();
                     BLOCK_END("Client::gameExec State::GET_CHARACTERS")
                     break;
@@ -1442,7 +1484,7 @@ int Client::gameExec()
                         // TRANSLATORS: connection dialog header
                         _("Connecting to the game server"),
                         State::CHOOSE_SERVER);
-                    if (gameHandler)
+                    if (gameHandler != nullptr)
                         gameHandler->connect();
                     BLOCK_END("Client::gameExec State::CONNECT_GAME")
                     break;
@@ -1454,14 +1496,14 @@ int Client::gameExec()
                         // TRANSLATORS: connection dialog header
                         _("Changing game servers"),
                         State::SWITCH_CHARACTER);
-                    if (gameHandler)
+                    if (gameHandler != nullptr)
                         gameHandler->connect();
                     BLOCK_END("Client::gameExec State::CHANGE_MAP")
                     break;
 
                 case State::GAME:
                     BLOCK_START("Client::gameExec State::GAME")
-                    if (localPlayer)
+                    if (localPlayer != nullptr)
                     {
                         logger->log("Memorizing selected character %s",
                             localPlayer->getName().c_str());
@@ -1480,7 +1522,7 @@ int Client::gameExec()
                     // Allow any alpha opacity
                     theme->setMinimumOpacity(-1.0F);
 
-                    if (chatLogger)
+                    if (chatLogger != nullptr)
                         chatLogger->setServerName(settings.serverName);
 
 #ifdef ANDROID
@@ -1498,7 +1540,7 @@ int Client::gameExec()
                     mCurrentDialog = nullptr;
 
                     logger->log1("State: GAME");
-                    if (generalHandler)
+                    if (generalHandler != nullptr)
                         generalHandler->reloadPartially();
                     mGame = new Game;
                     BLOCK_END("Client::gameExec State::GAME")
@@ -1562,7 +1604,7 @@ int Client::gameExec()
                 case State::REGISTER_ATTEMPT:
                     BLOCK_START("Client::gameExec State::REGISTER_ATTEMPT")
                     logger->log("Username is %s", loginData.username.c_str());
-                    if (loginHandler)
+                    if (loginHandler != nullptr)
                         loginHandler->registerAccount(&loginData);
                     BLOCK_END("Client::gameExec State::REGISTER_ATTEMPT")
                     break;
@@ -1580,7 +1622,7 @@ int Client::gameExec()
                     BLOCK_START("Client::gameExec "
                         "State::CHANGEPASSWORD_ATTEMPT")
                     logger->log1("State: CHANGE PASSWORD ATTEMPT");
-                    if (loginHandler)
+                    if (loginHandler != nullptr)
                     {
                         loginHandler->changePassword(loginData.password,
                             loginData.newPassword);
@@ -1621,7 +1663,7 @@ int Client::gameExec()
 
                 case State::CHANGEEMAIL_ATTEMPT:
                     logger->log1("State: CHANGE EMAIL ATTEMPT");
-                    if (loginHandler)
+                    if (loginHandler != nullptr)
                         loginHandler->changeEmail(loginData.email);
                     break;
 
@@ -1647,9 +1689,9 @@ int Client::gameExec()
                     BLOCK_START("Client::gameExec State::SWITCH_SERVER")
                     logger->log1("State: SWITCH SERVER");
 
-                    if (loginHandler)
+                    if (loginHandler != nullptr)
                         loginHandler->disconnect();
-                    if (gameHandler)
+                    if (gameHandler != nullptr)
                     {
                         gameHandler->disconnect();
                         gameHandler->clear();
@@ -1659,7 +1701,7 @@ int Client::gameExec()
                     WindowManager::updateTitle();
                     serverConfig.write();
                     serverConfig.unload();
-                    if (setupWindow)
+                    if (setupWindow != nullptr)
                         setupWindow->externalUnload();
 
                     mState = State::CHOOSE_SERVER;
@@ -1670,14 +1712,14 @@ int Client::gameExec()
                     BLOCK_START("Client::gameExec State::SWITCH_LOGIN")
                     logger->log1("State: SWITCH LOGIN");
 
-                    if (loginHandler)
+                    if (loginHandler != nullptr)
                     {
                         loginHandler->logout();
                         loginHandler->disconnect();
                     }
-                    if (gameHandler)
+                    if (gameHandler != nullptr)
                         gameHandler->disconnect();
-                    if (loginHandler)
+                    if (loginHandler != nullptr)
                         loginHandler->connect();
 
                     settings.login.clear();
@@ -1691,7 +1733,7 @@ int Client::gameExec()
                     logger->log1("State: SWITCH CHARACTER");
 
                     // Done with game
-                    if (gameHandler)
+                    if (gameHandler != nullptr)
                         gameHandler->disconnect();
 
                     settings.login.clear();
@@ -1718,7 +1760,7 @@ int Client::gameExec()
                 case State::FORCE_QUIT:
                     BLOCK_START("Client::gameExec State::FORCE_QUIT")
                     logger->log1("State: FORCE QUIT");
-                    if (generalHandler)
+                    if (generalHandler != nullptr)
                         generalHandler->unload();
                     mState = State::EXIT;
                     BLOCK_END("Client::gameExec State::FORCE_QUIT")
@@ -1837,7 +1879,7 @@ void Client::action(const ActionEvent &event)
         return;
     }
 
-    if (setupWindow)
+    if (setupWindow != nullptr)
     {
         setupWindow->setVisible(fromBool(
             !setupWindow->isWindowVisible(), Visible));
@@ -1853,7 +1895,7 @@ void Client::action(const ActionEvent &event)
 void Client::initFeatures()
 {
     features.init(paths.getStringValue("featuresFile"),
-        UseResman_true,
+        UseVirtFs_true,
         SkipError_true);
     features.setDefaultValues(getFeaturesDefaults());
     settings.fixDeadAnimation = features.getBoolValue("fixDeadAnimation");
@@ -1866,6 +1908,7 @@ void Client::initPaths()
     settings.linkCommandSymbol = paths.getStringValue("linkCommandSymbol");
     if (settings.linkCommandSymbol.empty())
         settings.linkCommandSymbol = "=";
+    settings.overweightPercent = paths.getIntValue("overweightPercent");
 }
 
 void Client::initTradeFilter()
@@ -1876,7 +1919,7 @@ void Client::initTradeFilter()
     std::ofstream tradeFile;
     struct stat statbuf;
 
-    if (stat(tradeListName.c_str(), &statbuf) ||
+    if ((stat(tradeListName.c_str(), &statbuf) != 0) ||
         !S_ISREG(statbuf.st_mode))
     {
         tradeFile.open(tradeListName.c_str(),
@@ -1899,6 +1942,11 @@ void Client::initTradeFilter()
             tradeFile << "i'm trade" << std::endl;
             tradeFile << "i'm trading" << std::endl;
         }
+        else
+        {
+            reportAlways("Error opening file for writing: %s",
+                tradeListName.c_str());
+        }
         tradeFile.close();
     }
 }
@@ -1917,7 +1965,7 @@ bool Client::isTmw()
 
 void Client::moveButtons(const int width)
 {
-    if (mSetupButton)
+    if (mSetupButton != nullptr)
     {
         int x = width - mSetupButton->getWidth() - mButtonPadding;
         mSetupButton->setPosition(x, mButtonPadding);
@@ -1960,7 +2008,7 @@ void Client::logVars()
 
 void Client::slowLogic()
 {
-    if (!gameHandler ||
+    if ((gameHandler == nullptr) ||
         !gameHandler->mustPing())
     {
         return;
@@ -1973,16 +2021,16 @@ void Client::slowLogic()
             mState == State::LOGIN ||
             mState == State::LOGIN_ATTEMPT)
         {
-            if (loginHandler)
+            if (loginHandler != nullptr)
                 loginHandler->ping();
-            if (generalHandler)
+            if (generalHandler != nullptr)
                 generalHandler->flushSend();
         }
         else if (mState == State::CHAR_SELECT)
         {
-            if (charServerHandler)
+            if (charServerHandler != nullptr)
                 charServerHandler->ping();
-            if (generalHandler)
+            if (generalHandler != nullptr)
                 generalHandler->flushSend();
         }
     }
