@@ -25,8 +25,9 @@
 #include "main.h"
 #include "settings.h"
 
+#include "fs/paths.h"
+
 #include "utils/gettext.h"
-#include "utils/paths.h"
 #include "utils/stringutils.h"
 
 #include <getopt.h>
@@ -130,7 +131,7 @@ static void printVersion()
 
 void parseOptions(const int argc, char *const argv[])
 {
-    const char *const optstring = "hvud:U:P:Dc:p:y:l:L:C:s:t:T:a:r";
+    const char *const optstring = "hvud:U:P:Dc:p:y:l:L:C:s:t:T:a:r:e";
 
     const struct option long_options[] =
     {
@@ -156,6 +157,9 @@ void parseOptions(const int argc, char *const argv[])
         { "test",           required_argument, nullptr, 't' },
         { "renderer",       required_argument, nullptr, 'r' },
         { "server-type",    required_argument, nullptr, 'y' },
+        { "enable-ipc",     no_argument,       nullptr, 'I' },
+        { "default-cursor", no_argument,       nullptr, 'q' },
+        { "error",          no_argument,       nullptr, 'e' },
         { nullptr,          0,                 nullptr, 0 }
     };
 
@@ -247,6 +251,15 @@ void parseOptions(const int argc, char *const argv[])
             case 'y':
                 options.serverType = optarg;
                 break;
+            case 'I':
+                options.ipc = true;
+                break;
+            case 'q':
+                options.defaultCursor = true;
+                break;
+            case 'e':
+                options.error = true;
+                break;
             default:
                 break;
         }
