@@ -24,16 +24,16 @@
 
 #include "client.h"
 #include "configuration.h"
-#include "logger.h"
 #include "settings.h"
 
 #include "being/beingspeech.h"
 
-#include "utils/files.h"
+#include "fs/files.h"
+#include "fs/mkdir.h"
+#include "fs/paths.h"
+
+#include "utils/checkutils.h"
 #include "utils/gettext.h"
-#include "utils/mkdir.h"
-#include "utils/paths.h"
-#include "utils/physfstools.h"
 
 #include "render/renderers.h"
 
@@ -53,9 +53,9 @@ static void setDefaultOption(const char *const name,
  */
 void ConfigManager::initServerConfig(const std::string &serverName)
 {
-    settings.serverConfigDir = settings.configDir + dirSeparator + serverName;
+    settings.serverConfigDir = pathJoin(settings.configDir, serverName);
 
-    if (mkdir_r(settings.serverConfigDir.c_str()))
+    if (mkdir_r(settings.serverConfigDir.c_str()) != 0)
     {
         // TRANSLATORS: directory creation error
         logger->error(strprintf(_("%s doesn't exist and can't be created! "
@@ -63,18 +63,29 @@ void ConfigManager::initServerConfig(const std::string &serverName)
     }
     const std::string configPath = settings.serverConfigDir + "/config.xml";
     FILE *configFile = fopen(configPath.c_str(), "r");
-    if (!configFile)
+    if (configFile == nullptr)
     {
-        configFile = fopen(configPath.c_str(), "wt");
+        configFile = fopen(configPath.c_str(), "wb");
         logger->log("Creating new server config: " + configPath);
+        if (configFile != nullptr)
+        {
+            fputs("<?xml version=\"1.0\"?>\n", configFile);
+            fputs("<configuration>\n", configFile);
+            fputs("</configuration>\n", configFile);
+        }
     }
-    if (configFile)
+    if (configFile != nullptr)
     {
         fclose(configFile);
         serverConfig.init(configPath);
         serverConfig.setDefaultValues(getConfigDefaults());
         logger->log("serverConfigPath: " + configPath);
     }
+    else
+    {
+        reportAlways("Error creating server config: %s",
+            configPath.c_str());
+    }
 
     const bool val = client->isTmw();
     setDefaultOption("enableManaMarketBot", val);
@@ -121,20 +132,31 @@ void ConfigManager::initConfiguration()
 
     std::string configPath;
 
+#ifndef UNITTESTS
     if (settings.options.test.empty())
         configPath = settings.configDir + "/config.xml";
     else
         configPath = settings.configDir + "/test.xml";
+#else  // UNITTESTS
+
+    configPath = settings.configDir + "/unittestconfig.xml";
+#endif  // UNITTESTS
 
     FILE *configFile = fopen(configPath.c_str(), "r");
-    if (!configFile)
+    if (configFile == nullptr)
     {
-        configFile = fopen(configPath.c_str(), "wt");
+        configFile = fopen(configPath.c_str(), "wb");
         logger->log1("Creating new config");
+        if (configFile != nullptr)
+        {
+            fputs("<?xml version=\"1.0\"?>\n", configFile);
+            fputs("<configuration>\n", configFile);
+            fputs("</configuration>\n", configFile);
+        }
     }
-    if (!configFile)
+    if (configFile == nullptr)
     {
-        logger->log("Can't create %s. Using defaults.",
+        reportAlways("Can't create %s. Using defaults.",
             configPath.c_str());
     }
     else
@@ -143,29 +165,31 @@ void ConfigManager::initConfiguration()
         config.init(configPath);
         logger->log1("init 3");
         config.setDefaultValues(getConfigDefaults());
-        logger->log("configPath: " + configPath);
+        logger->log("configuration file: " + configPath);
     }
 }
 
 void ConfigManager::backupConfig(const std::string &name)
 {
-    const std::string fileName3 = std::string(settings.configDir).append(
-        "/").append(name);
+    const std::string fileName3 = pathJoin(settings.configDir, name);
     StringVect arr;
+    if (Files::existsLocal(fileName3) == false)
+    {
+        logger->log("Config %s not exists, backup skipped.",
+            name.c_str());
+        return;
+    }
     if (Files::loadTextFileLocal(fileName3, arr) == true)
     {
-        if (arr.size() == 0)
+        if (arr.empty())
             return;
 
         arr.clear();
-        const std::string tmpName = std::string(
-            settings.configDir).append(
-            "/").append(
-            name).append(
-            ".tmp");
+        const std::string tmpName = pathJoin(settings.configDir,
+            name).append(".tmp");
         Files::copyFile(fileName3, tmpName);
         if (Files::loadTextFileLocal(tmpName, arr) == false ||
-            arr.size() == 0)
+            arr.empty())
         {
             logger->safeError("Error backuping configs. "
                 "Probably no free space on disk.");
@@ -173,11 +197,8 @@ void ConfigManager::backupConfig(const std::string &name)
         arr.clear();
     }
 
-    const std::string confName = std::string(
-        settings.configDir).append(
-        "/").append(
-        name).append(
-        ".bak");
+    const std::string confName = pathJoin(settings.configDir,
+        name).append(".bak");
     const int maxFileIndex = 5;
     ::remove((confName + toString(maxFileIndex)).c_str());
     for (int f = maxFileIndex; f > 1; f --)
