@@ -22,13 +22,17 @@
 
 #include "configuration.h"
 
-#include "logger.h"
 #include "variabledata.h"
 
+#include "fs/files.h"
+#include "fs/paths.h"
+
+#include "fs/virtfs/fs.h"
+
 #include "listeners/configlistener.h"
 
+#include "utils/checkutils.h"
 #include "utils/delete2.h"
-#include "utils/paths.h"
 #ifdef DEBUG_CONFIG
 #include "utils/stringmap.h"
 #endif  // DEBUG_CONFIG
@@ -361,7 +365,7 @@ Configuration::Configuration() :
     mDefaultsData(nullptr),
     mDirectory(),
     mFilename(),
-    mUseResManager(UseResman_false),
+    mUseResManager(UseVirtFs_false),
     mUpdated(false)
 {
 #ifdef DEBUG_CONFIG
@@ -372,7 +376,7 @@ Configuration::Configuration() :
 
 void Configuration::cleanDefaults()
 {
-    if (mDefaultsData)
+    if (mDefaultsData != nullptr)
     {
         for (DefaultsData::const_iterator iter = mDefaultsData->begin();
              iter != mDefaultsData->end();
@@ -396,7 +400,7 @@ void Configuration::unload()
     mConfigPath.clear();
     mDirectory.clear();
     mFilename.clear();
-    mUseResManager = UseResman_false;
+    mUseResManager = UseVirtFs_false;
     ConfigurationObject::clear();
 }
 
@@ -413,15 +417,15 @@ int Configuration::getIntValue(const std::string &key) const
     const Options::const_iterator iter = mOptions.find(key);
     if (iter == mOptions.end())
     {
-        if (mDefaultsData)
+        if (mDefaultsData != nullptr)
         {
             const DefaultsData::const_iterator itdef
                 = mDefaultsData->find(key);
 
-            if (itdef != mDefaultsData->end() && itdef->second)
+            if (itdef != mDefaultsData->end() && (itdef->second != nullptr))
             {
                 const VariableData *const data = itdef->second;
-                const VariableData::DataType type = static_cast<const
+                const VariableData::DataType type = static_cast<
                     VariableData::DataType>(data->getType());
                 if (type == VariableData::DATA_INT)
                 {
@@ -466,11 +470,11 @@ int Configuration::resetIntValue(const std::string &key)
 {
     GETLOG();
     int defaultValue = 0;
-    if (mDefaultsData)
+    if (mDefaultsData != nullptr)
     {
         const DefaultsData::const_iterator itdef = mDefaultsData->find(key);
         const VariableData *const data = itdef->second;
-        if (itdef != mDefaultsData->end() && data
+        if (itdef != mDefaultsData->end() && (data != nullptr)
             && data->getType() == VariableData::DATA_INT)
         {
             defaultValue = (static_cast<const IntData*>(
@@ -490,20 +494,20 @@ int Configuration::resetIntValue(const std::string &key)
 std::string Configuration::getStringValue(const std::string &key) const
 {
     GETLOG();
-    std::string defaultValue("");
+    std::string defaultValue;
     const Options::const_iterator iter = mOptions.find(key);
     if (iter == mOptions.end())
     {
-        if (mDefaultsData)
+        if (mDefaultsData != nullptr)
         {
             const DefaultsData::const_iterator
                 itdef = mDefaultsData->find(key);
 
             if (itdef != mDefaultsData->end() &&
-                itdef->second)
+                (itdef->second != nullptr))
             {
                 const VariableData *const data = itdef->second;
-                const VariableData::DataType type = static_cast<const
+                const VariableData::DataType type = static_cast<
                     VariableData::DataType>(data->getType());
                 if (type == VariableData::DATA_STRING)
                 {
@@ -522,6 +526,11 @@ std::string Configuration::getStringValue(const std::string &key) const
                     defaultValue = toString((static_cast<const IntData*>(
                         data))->getData());
                 }
+                else if (type == VariableData::DATA_FLOAT)
+                {
+                    defaultValue = toString((static_cast<const FloatData*>(
+                        data))->getData());
+                }
             }
             else
             {
@@ -546,13 +555,13 @@ float Configuration::getFloatValue(const std::string &key) const
     const Options::const_iterator iter = mOptions.find(key);
     if (iter == mOptions.end())
     {
-        if (mDefaultsData)
+        if (mDefaultsData != nullptr)
         {
             const DefaultsData::const_iterator itdef
                 = mDefaultsData->find(key);
 
             if (itdef != mDefaultsData->end() &&
-                itdef->second)
+                (itdef->second != nullptr))
             {
                 const VariableData *const data = itdef->second;
                 const VariableData::DataType type = static_cast<
@@ -604,13 +613,13 @@ bool Configuration::getBoolValue(const std::string &key) const
     const Options::const_iterator iter = mOptions.find(key);
     if (iter == mOptions.end())
     {
-        if (mDefaultsData)
+        if (mDefaultsData != nullptr)
         {
             const DefaultsData::const_iterator itdef
                 = mDefaultsData->find(key);
 
             if (itdef != mDefaultsData->end() &&
-                itdef->second)
+                (itdef->second != nullptr))
             {
                 const VariableData *const data = itdef->second;
                 const VariableData::DataType type = static_cast<
@@ -673,13 +682,13 @@ bool Configuration::resetBoolValue(const std::string &key)
 {
     GETLOG();
     bool defaultValue = false;
-    if (mDefaultsData)
+    if (mDefaultsData != nullptr)
     {
         const DefaultsData::const_iterator itdef = mDefaultsData->find(key);
         const VariableData *const data = itdef->second;
 
         if (itdef != mDefaultsData->end() &&
-            data &&
+            (data != nullptr) &&
             data->getType() == VariableData::DATA_BOOL)
         {
             defaultValue = (static_cast<const BoolData*>(data))->getData();
@@ -697,11 +706,11 @@ bool Configuration::resetBoolValue(const std::string &key)
 }
 
 
-void ConfigurationObject::initFromXML(const XmlNodePtrConst parentNode)
+void ConfigurationObject::initFromXML(XmlNodeConstPtrConst parentNode)
 {
     clear();
 
-    if (!parentNode)
+    if (parentNode == nullptr)
         return;
 
     for_each_xml_child_node(node, parentNode)
@@ -738,38 +747,51 @@ void ConfigurationObject::initFromXML(const XmlNodePtrConst parentNode)
 }
 
 void Configuration::init(const std::string &filename,
-                         const UseResman useResManager,
+                         const UseVirtFs useResManager,
                          const SkipError skipError)
 {
     cleanDefaults();
-    XML::Document doc(filename,
-        useResManager,
-        skipError);
+    clear();
     mFilename = filename;
     mUseResManager = useResManager;
 
-    if (useResManager == UseResman_true)
+    if (useResManager == UseVirtFs_true)
     {
-        mConfigPath = "PhysFS://" + filename;
+        mConfigPath = "virtfs://" + filename;
         mDirectory.clear();
+        if (VirtFs::exists(filename) == false)
+        {
+            logger->log("Warning: No configuration file (%s)",
+                filename.c_str());
+            return;
+        }
     }
     else
     {
         mConfigPath = filename;
         logger->log1("init 1");
         mDirectory = getRealPath(getFileDir(filename));
+        if (Files::existsLocal(filename) == false)
+        {
+            logger->log("Warning: No configuration file (%s)",
+                filename.c_str());
+            return;
+        }
     }
-    logger->log1("init 2");
 
-    if (!doc.rootNode())
+    XML::Document doc(filename,
+        useResManager,
+        skipError);
+    logger->log1("init 2");
+    if (doc.rootNode() == nullptr)
     {
         logger->log("Couldn't open configuration file: %s", filename.c_str());
         return;
     }
 
-    const XmlNodePtrConst rootNode = doc.rootNode();
+    XmlNodeConstPtrConst rootNode = doc.rootNode();
 
-    if (!rootNode || !xmlNameEqual(rootNode, "configuration"))
+    if ((rootNode == nullptr) || !xmlNameEqual(rootNode, "configuration"))
     {
         logger->log("Warning: No configuration file (%s)", filename.c_str());
         return;
@@ -781,15 +803,15 @@ void Configuration::init(const std::string &filename,
 void Configuration::reInit()
 {
     XML::Document doc(mFilename, mUseResManager, SkipError_false);
-    if (!doc.rootNode())
+    if (doc.rootNode() == nullptr)
     {
         logger->log("Couldn't open configuration file: %s", mFilename.c_str());
         return;
     }
 
-    const XmlNodePtrConst rootNode = doc.rootNode();
+    XmlNodeConstPtrConst rootNode = doc.rootNode();
 
-    if (!rootNode || !xmlNameEqual(rootNode, "configuration"))
+    if ((rootNode == nullptr) || !xmlNameEqual(rootNode, "configuration"))
     {
         logger->log("Warning: No configuration file (%s)", mFilename.c_str());
         return;
@@ -798,7 +820,7 @@ void Configuration::reInit()
     initFromXML(rootNode);
 }
 
-void ConfigurationObject::writeToXML(const XmlTextWriterPtr writer)
+void ConfigurationObject::writeToXML(XmlTextWriterPtr writer)
 {
     FOR_EACH (Options::const_iterator, i, mOptions)
     {
@@ -829,7 +851,7 @@ void ConfigurationObject::writeToXML(const XmlTextWriterPtr writer)
         FOR_EACH (ConfigurationList::const_iterator, elt_it, it->second)
         {
             XmlTextWriterStartElement(writer, name);
-            if (*elt_it)
+            if (*elt_it != nullptr)
                 (*elt_it)->writeToXML(writer);
             XmlTextWriterEndElement(writer);
         }
@@ -856,10 +878,10 @@ void Configuration::write()
     mUpdated = false;
     // Do not attempt to write to file that cannot be opened for writing
     FILE *const testFile = fopen(mConfigPath.c_str(), "w");
-    if (!testFile)
+    if (testFile == nullptr)
     {
-        logger->log("Configuration::write() couldn't open %s for writing",
-                    mConfigPath.c_str());
+        reportAlways("Configuration::write() couldn't open %s for writing",
+            mConfigPath.c_str());
         BLOCK_END("Configuration::write")
         return;
     }
@@ -868,10 +890,10 @@ void Configuration::write()
         fclose(testFile);
     }
 
-    const XmlTextWriterPtr writer = XmlNewTextWriterFilename(
+    XmlTextWriterPtr writer = XmlNewTextWriterFilename(
         mConfigPath.c_str(), 0);
 
-    if (!writer)
+    if (writer == nullptr)
     {
         logger->log1("Configuration::write() error while creating writer");
         BLOCK_END("Configuration::write")
@@ -883,11 +905,13 @@ void Configuration::write()
     XmlTextWriterSetIndent(writer, 1);
     XmlTextWriterStartDocument(writer, nullptr, nullptr, nullptr);
 //    xmlTextWriterStartDocument(writer, nullptr, "utf8", nullptr);
-    XmlTextWriterStartElement(writer, "configuration");
+    XmlTextWriterStartRootElement(writer, "configuration");
 
     writeToXML(writer);
 
     XmlTextWriterEndDocument(writer);
+    XmlSaveTextWriterFilename(writer,
+        mConfigPath.c_str());
     XmlFreeTextWriter(writer);
     BLOCK_END("Configuration::write")
 }
