@@ -25,7 +25,7 @@
 
 #include <string>
 
-const std::string GENERAL_CHANNEL = "";
+const std::string GENERAL_CHANNEL;
 const std::string GM_CHANNEL = "#gm";
 const std::string TRADE_CHANNEL = "#trade";
 
