@@ -28,17 +28,17 @@
 #include "main.h"
 #include "settings.h"
 
+#include "fs/mkdir.h"
+#include "fs/paths.h"
+
+#include "fs/virtfs/fs.h"
+
 #include "utils/base64.h"
 #if defined(__native_client__) || (defined(ANDROID) && defined(USE_SDL2))
-#include "utils/files.h"
+#include "fs/files.h"
 #endif  // defined(__native_client__) || (defined(ANDROID) &&
         // defined(USE_SDL2))
 #include "utils/gettext.h"
-#include "utils/mkdir.h"
-#include "utils/paths.h"
-#include "utils/physfstools.h"
-
-#include "resources/resourcemanager/resourcemanager.h"
 
 #ifdef ANDROID
 #ifdef USE_SDL2
@@ -53,8 +53,11 @@
 #endif  // __APPLE__
 
 #ifdef WIN32
+PRAGMA48(GCC diagnostic push)
+PRAGMA48(GCC diagnostic ignored "-Wshadow")
 #include <SDL_syswm.h>
-#include "utils/specialfolder.h"
+PRAGMA48(GCC diagnostic pop)
+#include "fs/specialfolder.h"
 #undef ERROR
 #endif  // WIN32
 
@@ -79,7 +82,7 @@ static void updateProgress(int cnt)
     const int h = mainGraphics->mHeight;
     mainGraphics->setColor(Color(255, 255, 255));
     const int maxSize = mainGraphics->mWidth - 100;
-    const int width = maxSize * progress / 450;
+    const int width = maxSize * progress / 50;
     mainGraphics->fillRectangle(Rect(50, h - 100, width, 50));
     mainGraphics->updateScreen();
 }
@@ -103,8 +106,8 @@ void extractAssets()
         logger->log("error: APPDIR is not set!");
         return;
     }
-    const std::string fileName = std::string(getenv(
-        "APPDIR")).append("/data.zip");
+    const std::string fileName = pathJoin(getenv("APPDIR"),
+        "data.zip");
     logger->log("Extracting asset into: " + fileName);
     uint8_t *buf = new uint8_t[1000000];
 
@@ -132,8 +135,8 @@ void extractAssets()
     }
     fclose(file);
 
-    const std::string fileName2 = std::string(getenv(
-        "APPDIR")).append("/locale.zip");
+    const std::string fileName2 = pathJoin(getenv("APPDIR"),
+        "locale.zip");
     FILE *const file2 = fopen(fileName2.c_str(), "w");
     SDL_RWops *const rw = SDL_RWFromFile("manaplus-locale.zip", "r");
     if (rw)
@@ -163,8 +166,8 @@ void Dirs::updateDataPath()
         }
         else
         {
-            settings.options.dataPath = branding.getDirectory().append(
-                dirSeparator) + branding.getStringValue("dataPath");
+            settings.options.dataPath = pathJoin(branding.getDirectory(),
+                branding.getStringValue("dataPath"));
         }
         settings.options.skipUpdate = true;
     }
@@ -177,22 +180,23 @@ void Dirs::extractDataDir()
     resetProgress();
     extractAssets();
 
-    const std::string zipName = std::string(getenv(
-        "APPDIR")).append(
-        "/data.zip");
-    const std::string dirName = std::string(getenv(
-        "APPDIR")).append(
-        "/data");
-    Files::extractZip(zipName, "data", dirName);
+    const std::string zipName = pathJoin(getenv("APPDIR"), "data.zip");
+    const std::string dirName = pathJoin(getenv("APPDIR"), "data");
+    VirtFs::mountZip2(zipName,
+        "data",
+        Append_false);
+    VirtFs::mountZip2(zipName,
+        "data/perserver/default",
+        Append_false);
     Files::extractLocale();
 #endif  // defined(ANDROID) && defined(USE_SDL2)
 }
 
 void Dirs::mountDataDir()
 {
-    resourceManager->addToSearchPath(PKG_DATADIR "data/perserver/default",
+    VirtFs::mountDirSilent(PKG_DATADIR "data/perserver/default",
         Append_false);
-    resourceManager->addToSearchPath("data/perserver/default",
+    VirtFs::mountDirSilent("data/perserver/default",
         Append_false);
 
 #if defined __APPLE__
@@ -207,64 +211,63 @@ void Dirs::mountDataDir()
         fprintf(stderr, "Can't find Resources directory\n");
     }
     CFRelease(resourcesURL);
-    // possible crash
-    strncat(path, "/data", PATH_MAX - 1);
-    resourceManager->addToSearchPath(path, Append_false);
+    std::string path2 = pathJoin(path, "data");
+    VirtFs::mountDir(pathJoin(path2, "perserver/default"), Append_false);
+    VirtFs::mountDir(path2, Append_false);
 // possible this need for support run client from dmg images.
 //    mPackageDir = path;
 #endif  // defined __APPLE__
 
-    resourceManager->addToSearchPath(PKG_DATADIR "data", Append_false);
+    VirtFs::mountDirSilent(PKG_DATADIR "data", Append_false);
     setPackageDir(PKG_DATADIR "data");
-    resourceManager->addToSearchPath("data", Append_false);
+    VirtFs::mountDirSilent("data", Append_false);
 
 #ifdef ANDROID
 #ifdef USE_SDL2
     if (getenv("APPDIR"))
     {
         const std::string appDir = getenv("APPDIR");
-        resourceManager->addToSearchPath(appDir + "/data", Append_false);
-        resourceManager->addToSearchPath(appDir + "/data/perserver/default",
+        VirtFs::mountDir(appDir + "/data", Append_false);
+        VirtFs::mountDir(appDir + "/data/perserver/default",
             Append_false);
     }
 #endif  // USE_SDL2
 #endif  // ANDROID
 
 #if defined __native_client__
-    resourceManager->addToSearchPath("/http/data.zip", Append_false);
+    VirtFs::mountZip("/http/data.zip", Append_false);
+    VirtFs::mountZip2("/http/data.zip",
+        "perserver/default",
+        Append_false);
 #endif  // defined __native_client__
 
-    // Add branding/data to PhysFS search path
+#ifndef WIN32
+    // Add branding/data to VirtFS search path
     if (!settings.options.brandingPath.empty())
     {
         std::string path = settings.options.brandingPath;
 
         // Strip blah.manaplus from the path
-#ifdef WIN32
-        const int loc1 = path.find_last_of('/');
-        const int loc2 = path.find_last_of('\\');
-        const int loc = CAST_S32(std::max(loc1, loc2));
-#else  // WIN32
-
         const int loc = CAST_S32(path.find_last_of('/'));
-#endif  // WIN32
 
         if (loc > 0)
         {
-            resourceManager->addToSearchPath(path.substr(
+            VirtFs::mountDir(path.substr(
                 0, loc + 1).append("data"),
                 Append_false);
         }
     }
+#endif  // WIN32
 }
 
 void Dirs::initRootDir()
 {
-    settings.rootDir = PhysFs::getBaseDir();
+    settings.rootDir = VirtFs::getBaseDir();
     const std::string portableName = settings.rootDir + "portable.xml";
     struct stat statbuf;
 
-    if (!stat(portableName.c_str(), &statbuf) && S_ISREG(statbuf.st_mode))
+    if (stat(portableName.c_str(), &statbuf) == 0 &&
+        S_ISREG(statbuf.st_mode))
     {
         std::string dir;
         Configuration portable;
@@ -332,45 +335,47 @@ void Dirs::initLocalDataDir()
     {
 #ifdef __APPLE__
         // Use Application Directory instead of .mana
-        settings.localDataDir = std::string(PhysFs::getUserDir()) +
-            "/Library/Application Support/" +
-            branding.getValue("appName", "ManaPlus");
+        settings.localDataDir = pathJoin(VirtFs::getUserDir(),
+            "Library/Application Support",
+            branding.getValue("appName", "ManaPlus"));
 #elif defined __HAIKU__
-        settings.localDataDir = std::string(PhysFs::getUserDir()) +
-           "/config/data/Mana";
+        settings.localDataDir = pathJoin(VirtFs::getUserDir(),
+           "config/data/Mana");
 #elif defined WIN32
         settings.localDataDir = getSpecialFolderLocation(CSIDL_LOCAL_APPDATA);
         if (settings.localDataDir.empty())
-            settings.localDataDir = std::string(PhysFs::getUserDir());
-        settings.localDataDir.append("/Mana");
+            settings.localDataDir = VirtFs::getUserDir();
+        settings.localDataDir = pathJoin(settings.localDataDir,
+            "Mana");
 #elif defined __ANDROID__
-        settings.localDataDir = getSdStoragePath() + branding.getValue(
-            "appShort", "ManaPlus") + "/local";
+        settings.localDataDir = pathJoin(getSdStoragePath(),
+            branding.getValue("appShort", "ManaPlus"),
+            "local");
 #elif defined __native_client__
-        settings.localDataDir = _nacl_dir.append("/local");
+        settings.localDataDir = pathJoin(_nacl_dir, "local");
 #else  // __APPLE__
 
-        settings.localDataDir = std::string(PhysFs::getUserDir()) +
-            ".local/share/mana";
+        settings.localDataDir = pathJoin(VirtFs::getUserDir(),
+            ".local/share/mana");
 #endif  // __APPLE__
     }
 
-    if (mkdir_r(settings.localDataDir.c_str()))
+    if (mkdir_r(settings.localDataDir.c_str()) != 0)
     {
         // TRANSLATORS: directory creation error
         logger->error(strprintf(_("%s doesn't exist and can't be created! "
             "Exiting."), settings.localDataDir.c_str()));
     }
 #ifdef USE_PROFILER
-    Perfomance::init(settings.localDataDir + "/profiler.log");
+    Perfomance::init(pathJoin(settings.localDataDir, "profiler.log"));
 #endif  // USE_PROFILER
 }
 
 void Dirs::initTempDir()
 {
-    settings.tempDir = settings.localDataDir + dirSeparator + "temp";
+    settings.tempDir = pathJoin(settings.localDataDir, "temp");
 
-    if (mkdir_r(settings.tempDir.c_str()))
+    if (mkdir_r(settings.tempDir.c_str()) != 0)
     {
         // TRANSLATORS: directory creation error
         logger->error(strprintf(_("%s doesn't exist and can't be created! "
@@ -386,12 +391,12 @@ void Dirs::initConfigDir()
     if (settings.configDir.empty())
     {
 #ifdef __APPLE__
-        settings.configDir = settings.localDataDir + dirSeparator
-            + branding.getValue("appShort", "mana");
+        settings.configDir = pathJoin(settings.localDataDir,
+            branding.getValue("appShort", "mana"));
 #elif defined __HAIKU__
-        settings.configDir = std::string(PhysFs::getUserDir()) +
-           "/config/settings/Mana" +
-           branding.getValue("appName", "ManaPlus");
+        settings.configDir = pathJoin(VirtFs::getUserDir(),
+           "config/settings/Mana",
+           branding.getValue("appName", "ManaPlus"));
 #elif defined WIN32
         settings.configDir = getSpecialFolderLocation(CSIDL_APPDATA);
         if (settings.configDir.empty())
@@ -400,24 +405,27 @@ void Dirs::initConfigDir()
         }
         else
         {
-            settings.configDir.append("/mana/").append(branding.getValue(
-                "appShort", "mana"));
+            settings.configDir = pathJoin(settings.configDir,
+                "mana",
+                branding.getValue("appShort", "mana"));
         }
 #elif defined __ANDROID__
-        settings.configDir = getSdStoragePath() + branding.getValue(
-            "appShort", "ManaPlus").append("/config");
+        settings.configDir = pathJoin(getSdStoragePath(),
+            branding.getValue("appShort", "ManaPlus"),
+            "config");
 #elif defined __native_client__
-        settings.configDir = _nacl_dir.append("/config");
+        settings.configDir = pathJoin(_nacl_dir, "config");
 #else  // __APPLE__
 
-        settings.configDir = std::string(PhysFs::getUserDir()).append(
-            "/.config/mana/").append(branding.getValue("appShort", "mana"));
+        settings.configDir = pathJoin(VirtFs::getUserDir(),
+            ".config/mana",
+            branding.getValue("appShort", "mana"));
 #endif  // __APPLE__
 
         logger->log("Generating config dir: " + settings.configDir);
     }
 
-    if (mkdir_r(settings.configDir.c_str()))
+    if (mkdir_r(settings.configDir.c_str()) != 0)
     {
         // TRANSLATORS: directory creation error
         logger->error(strprintf(_("%s doesn't exist and can't be created! "
@@ -443,10 +451,7 @@ void Dirs::initUpdatesDir()
     if (settings.updateHost.length() < 2)
     {
         if (settings.updatesDir.empty())
-        {
-            settings.updatesDir = std::string("updates/").append(
-                settings.serverName);
-        }
+            settings.updatesDir = pathJoin("updates", settings.serverName);
         return;
     }
 
@@ -490,22 +495,13 @@ void Dirs::initUpdatesDir()
     const std::string updateDir("/" + settings.updatesDir);
 
     // Verify that the updates directory exists. Create if necessary.
-    if (!PhysFs::isDirectory(updateDir.c_str()))
+    if (!VirtFs::isDirectory(updateDir))
     {
-        if (!PhysFs::mkdir(updateDir.c_str()))
+        if (!VirtFs::mkdir(updateDir))
         {
 #if defined WIN32
-            std::string newDir = settings.localDataDir +
-                "\\" +
-                settings.updatesDir;
-            size_t loc = newDir.find("/", 0);
-
-            while (loc != std::string::npos)
-            {
-                newDir.replace(loc, 1, "\\");
-                loc = newDir.find("/", loc);
-            }
-
+            std::string newDir = pathJoin(settings.localDataDir,
+                settings.updatesDir);
             if (!CreateDirectory(newDir.c_str(), nullptr) &&
                 GetLastError() != ERROR_ALREADY_EXISTS)
             {
@@ -518,19 +514,20 @@ void Dirs::initUpdatesDir()
 #else  // defined WIN32
 
             logger->log("Error: %s/%s can't be made, but doesn't exist!",
-                settings.localDataDir.c_str(), settings.updatesDir.c_str());
+                settings.localDataDir.c_str(),
+                settings.updatesDir.c_str());
             // TRANSLATORS: update server initialisation error
             errorMessage = _("Error creating updates directory!");
             client->setState(State::ERROR);
 #endif  // defined WIN32
         }
     }
-    const std::string updateLocal = updateDir + "/local";
-    const std::string updateFix = updateDir + "/fix";
-    if (!PhysFs::isDirectory(updateLocal.c_str()))
-        PhysFs::mkdir(updateLocal.c_str());
-    if (!PhysFs::isDirectory(updateFix.c_str()))
-        PhysFs::mkdir(updateFix.c_str());
+    const std::string updateLocal = pathJoin(updateDir, "local");
+    const std::string updateFix = pathJoin(updateDir, "fix");
+    if (!VirtFs::isDirectory(updateLocal))
+        VirtFs::mkdir(updateLocal);
+    if (!VirtFs::isDirectory(updateFix))
+        VirtFs::mkdir(updateFix);
 }
 
 void Dirs::initScreenshotDir()
@@ -538,7 +535,7 @@ void Dirs::initScreenshotDir()
     if (!settings.options.screenshotDir.empty())
     {
         settings.screenshotDir = settings.options.screenshotDir;
-        if (mkdir_r(settings.screenshotDir.c_str()))
+        if (mkdir_r(settings.screenshotDir.c_str()) != 0)
         {
             logger->log(strprintf(
                 // TRANSLATORS: directory creation error
@@ -549,7 +546,7 @@ void Dirs::initScreenshotDir()
     else if (settings.screenshotDir.empty())
     {
 #ifdef __native_client__
-        settings.screenshotDir = _nacl_dir + "/screenshots/";
+        settings.screenshotDir = pathJoin(_nacl_dir, "screenshots/");
 #else  // __native_client__
         settings.screenshotDir = decodeBase64String(
             config.getStringValue("screenshotDirectory3"));
@@ -576,7 +573,7 @@ void Dirs::initScreenshotDir()
 
                 if (!configScreenshotSuffix.empty())
                 {
-                    settings.screenshotDir.append(dirSeparator).append(
+                    settings.screenshotDir = pathJoin(settings.screenshotDir,
                         configScreenshotSuffix);
                 }
             }
@@ -591,7 +588,7 @@ void Dirs::initScreenshotDir()
 void Dirs::initUsersDir()
 {
     settings.usersDir = settings.serverConfigDir + "/users/";
-    if (mkdir_r(settings.usersDir.c_str()))
+    if (mkdir_r(settings.usersDir.c_str()) != 0)
     {
         // TRANSLATORS: directory creation error
         logger->error(strprintf(_("%s doesn't exist and can't be created!"),
@@ -599,7 +596,7 @@ void Dirs::initUsersDir()
     }
 
     settings.npcsDir = settings.serverConfigDir + "/npcs/";
-    if (mkdir_r(settings.npcsDir.c_str()))
+    if (mkdir_r(settings.npcsDir.c_str()) != 0)
     {
         // TRANSLATORS: directory creation error
         logger->error(strprintf(_("%s doesn't exist and can't be created!"),
@@ -607,7 +604,7 @@ void Dirs::initUsersDir()
     }
 
     settings.usersIdDir = settings.serverConfigDir + "/usersid/";
-    if (mkdir_r(settings.usersIdDir.c_str()))
+    if (mkdir_r(settings.usersIdDir.c_str()) != 0)
     {
         // TRANSLATORS: directory creation error
         logger->error(strprintf(_("%s doesn't exist and can't be created!"),
