@@ -18,7 +18,7 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "catch.hpp"
+#include "test/unittests.h"
 
 #include "gui/fonts/font.h"
 #include "gui/fonts/textchunk.h"
@@ -32,8 +32,8 @@ TEST_CASE("TextChunkList empty", "TextChunkList")
     REQUIRE(0 == list.size);
     REQUIRE(nullptr == list.start);
     REQUIRE(nullptr == list.end);
-    REQUIRE(0 == list.search.size());
-    REQUIRE(0 == list.searchWidth.size());
+    REQUIRE(list.search.empty());
+    REQUIRE(list.searchWidth.empty());
 }
 
 TEST_CASE("TextChunkList add 1", "TextChunkList")
@@ -57,6 +57,7 @@ TEST_CASE("TextChunkList add 1", "TextChunkList")
 
     REQUIRE(1 == list.searchWidth.size());
     REQUIRE(chunk == (*list.searchWidth.find(chunk->text)).second);
+    delete chunk;
 }
 
 TEST_CASE("TextChunkList add 2", "TextChunkList")
@@ -87,6 +88,8 @@ TEST_CASE("TextChunkList add 2", "TextChunkList")
 
     REQUIRE(1 == list.searchWidth.size());
     REQUIRE(chunk1 == (*list.searchWidth.find(chunk1->text)).second);
+    delete chunk1;
+    delete chunk2;
 }
 
 TEST_CASE("TextChunkList addRemoveBack 1", "TextChunkList")
@@ -102,8 +105,8 @@ TEST_CASE("TextChunkList addRemoveBack 1", "TextChunkList")
     REQUIRE(0 == list.size);
     REQUIRE(nullptr == list.start);
     REQUIRE(nullptr == list.end);
-    REQUIRE(0 == list.search.size());
-    REQUIRE(0 == list.searchWidth.size());
+    REQUIRE(list.search.empty());
+    REQUIRE(list.searchWidth.empty());
 }
 
 TEST_CASE("TextChunkList addRemoveBack 2", "TextChunkList")
@@ -131,6 +134,7 @@ TEST_CASE("TextChunkList addRemoveBack 2", "TextChunkList")
 
     REQUIRE(1 == list.searchWidth.size());
     REQUIRE(chunk1 == (*list.searchWidth.find(chunk1->text)).second);
+    delete chunk1;
 }
 
 TEST_CASE("TextChunkList addRemoveBack 3", "TextChunkList")
@@ -150,8 +154,8 @@ TEST_CASE("TextChunkList addRemoveBack 3", "TextChunkList")
     REQUIRE(nullptr == list.start);
     REQUIRE(nullptr == list.end);
 
-    REQUIRE(0 == list.search.size());
-    REQUIRE(0 == list.searchWidth.size());
+    REQUIRE(list.search.empty());
+    REQUIRE(list.searchWidth.empty());
 }
 
 TEST_CASE("TextChunkList addRemoveBack 4", "TextChunkList")
@@ -181,7 +185,8 @@ TEST_CASE("TextChunkList addRemoveBack 4", "TextChunkList")
     REQUIRE(chunk1 == (*list.search.find(TextChunkSmall(
         chunk1->text, chunk1->color, chunk1->color2))).second);
 
-    REQUIRE(0 == list.searchWidth.size());
+    REQUIRE(list.searchWidth.empty());
+    delete chunk1;
 }
 
 TEST_CASE("TextChunkList moveToFirst 1", "TextChunkList")
@@ -199,6 +204,7 @@ TEST_CASE("TextChunkList moveToFirst 1", "TextChunkList")
     REQUIRE(chunk == list.end);
     REQUIRE(nullptr == chunk->prev);
     REQUIRE(nullptr == chunk->next);
+    delete chunk;
 }
 
 TEST_CASE("TextChunkList moveToFirst 2", "TextChunkList")
@@ -221,6 +227,8 @@ TEST_CASE("TextChunkList moveToFirst 2", "TextChunkList")
     REQUIRE(chunk2 == chunk1->next);
     REQUIRE(chunk1 == chunk2->prev);
     REQUIRE(nullptr == chunk2->next);
+    delete chunk1;
+    delete chunk2;
 }
 
 TEST_CASE("TextChunkList moveToFirst 3", "TextChunkList")
@@ -248,6 +256,9 @@ TEST_CASE("TextChunkList moveToFirst 3", "TextChunkList")
     REQUIRE(chunk3 == chunk2->next);
     REQUIRE(chunk2 == chunk3->prev);
     REQUIRE(nullptr == chunk3->next);
+    delete chunk1;
+    delete chunk2;
+    delete chunk3;
 }
 
 TEST_CASE("TextChunkList moveToFirst 4", "TextChunkList")
@@ -275,6 +286,9 @@ TEST_CASE("TextChunkList moveToFirst 4", "TextChunkList")
     REQUIRE(chunk3 == chunk2->next);
     REQUIRE(chunk2 == chunk3->prev);
     REQUIRE(nullptr == chunk3->next);
+    delete chunk1;
+    delete chunk2;
+    delete chunk3;
 }
 
 TEST_CASE("TextChunkList clear 1", "TextChunkList")
@@ -292,8 +306,8 @@ TEST_CASE("TextChunkList clear 1", "TextChunkList")
     REQUIRE(nullptr == list.start);
     REQUIRE(nullptr == list.end);
     REQUIRE(chunksLeft == textChunkCnt);
-    REQUIRE(0 == list.search.size());
-    REQUIRE(0 == list.searchWidth.size());
+    REQUIRE(list.search.empty());
+    REQUIRE(list.searchWidth.empty());
 }
 
 TEST_CASE("TextChunkList clear 2", "TextChunkList")
@@ -317,8 +331,8 @@ TEST_CASE("TextChunkList clear 2", "TextChunkList")
     REQUIRE(nullptr == list.start);
     REQUIRE(nullptr == list.end);
     REQUIRE(chunksLeft == textChunkCnt);
-    REQUIRE(0 == list.search.size());
-    REQUIRE(0 == list.searchWidth.size());
+    REQUIRE(list.search.empty());
+    REQUIRE(list.searchWidth.empty());
 }
 
 TEST_CASE("TextChunkList clear 3", "TextChunkList")
@@ -344,12 +358,12 @@ TEST_CASE("TextChunkList clear 3", "TextChunkList")
     list.removeBack();
     REQUIRE((chunksLeft + 2) == textChunkCnt);
     REQUIRE(2 == list.search.size());
-    REQUIRE(0 == list.searchWidth.size());
+    REQUIRE(list.searchWidth.empty());
 
     list.clear();
     REQUIRE(chunksLeft == textChunkCnt);
-    REQUIRE(0 == list.search.size());
-    REQUIRE(0 == list.searchWidth.size());
+    REQUIRE(list.search.empty());
+    REQUIRE(list.searchWidth.empty());
 }
 
 TEST_CASE("TextChunkList clear 4", "TextChunkList")
@@ -375,12 +389,12 @@ TEST_CASE("TextChunkList clear 4", "TextChunkList")
     list.removeBack(2);
     REQUIRE((chunksLeft + 1) == textChunkCnt);
     REQUIRE(1 == list.search.size());
-    REQUIRE(0 == list.searchWidth.size());
+    REQUIRE(list.searchWidth.empty());
 
     list.clear();
     REQUIRE(chunksLeft == textChunkCnt);
-    REQUIRE(0 == list.search.size());
-    REQUIRE(0 == list.searchWidth.size());
+    REQUIRE(list.search.empty());
+    REQUIRE(list.searchWidth.empty());
 }
 
 TEST_CASE("TextChunkList remove 1", "TextChunkList")
@@ -399,8 +413,8 @@ TEST_CASE("TextChunkList remove 1", "TextChunkList")
     REQUIRE(nullptr == list.start);
     REQUIRE(nullptr == list.end);
     REQUIRE(chunksLeft == textChunkCnt);
-    REQUIRE(0 == list.search.size());
-    REQUIRE(0 == list.searchWidth.size());
+    REQUIRE(list.search.empty());
+    REQUIRE(list.searchWidth.empty());
 }
 
 TEST_CASE("TextChunkList remove 2", "TextChunkList")
@@ -427,6 +441,8 @@ TEST_CASE("TextChunkList remove 2", "TextChunkList")
     REQUIRE((chunksLeft + 2) == textChunkCnt);
     REQUIRE(2 == list.search.size());
     REQUIRE(2 == list.searchWidth.size());
+    delete chunk2;
+    delete chunk3;
 }
 
 TEST_CASE("TextChunkList remove 3", "TextChunkList")
@@ -453,6 +469,8 @@ TEST_CASE("TextChunkList remove 3", "TextChunkList")
     REQUIRE((chunksLeft + 2) == textChunkCnt);
     REQUIRE(2 == list.search.size());
     REQUIRE(2 == list.searchWidth.size());
+    delete chunk1;
+    delete chunk3;
 }
 
 TEST_CASE("TextChunkList sort 1", "TextChunkList")
