@@ -49,7 +49,7 @@ std::string NamesModel::getElementAt(int i)
 void NamesModel::fillFromArray(const char *const *const arr,
                                const std::size_t sz)
 {
-    if (!arr)
+    if (arr == nullptr)
         return;
     for (size_t f = 0; f < sz; f ++)
         mNames.push_back(gettext(arr[f]));
