@@ -28,10 +28,12 @@
 
 #include "debug.h"
 
-ShopItems::ShopItems(const bool mergeDuplicates) :
+ShopItems::ShopItems(const bool mergeDuplicates,
+                     const std::string &currency) :
     ListModel(),
     mAllShopItems(),
     mShopItems(),
+    mCurrency(currency),
     mMergeDuplicates(mergeDuplicates)
 {
 }
@@ -44,7 +46,7 @@ ShopItems::~ShopItems()
 std::string ShopItems::getElementAt(int i)
 {
     if (i < 0 || CAST_U32(i)
-        >= CAST_U32(mShopItems.size()) || !mShopItems.at(i))
+        >= CAST_U32(mShopItems.size()) || (mShopItems.at(i) == nullptr))
     {
         return "";
     }
@@ -58,7 +60,13 @@ ShopItem *ShopItems::addItem(const int id,
                              const int amount,
                              const int price)
 {
-    ShopItem *const item = new ShopItem(-1, id, type, color, amount, price);
+    ShopItem *const item = new ShopItem(-1,
+        id,
+        type,
+        color,
+        amount,
+        price,
+        mCurrency);
     mShopItems.push_back(item);
     mAllShopItems.push_back(item);
     return item;
@@ -71,9 +79,15 @@ ShopItem *ShopItems::addItemNoDup(const int id,
                                   const int price)
 {
     ShopItem *item = findItem(id, color);
-    if (!item)
+    if (item == nullptr)
     {
-        item = new ShopItem(-1, id, type, color, amount, price);
+        item = new ShopItem(-1,
+            id,
+            type,
+            color,
+            amount,
+            price,
+            mCurrency);
         mShopItems.push_back(item);
         mAllShopItems.push_back(item);
     }
@@ -91,13 +105,19 @@ ShopItem *ShopItems::addItem2(const int inventoryIndex,
     if (mMergeDuplicates)
         item = findItem(id, color);
 
-    if (item)
+    if (item != nullptr)
     {
         item->addDuplicate(inventoryIndex, quantity);
     }
     else
     {
-        item = new ShopItem(inventoryIndex, id, type, color, quantity, price);
+        item = new ShopItem(inventoryIndex,
+            id,
+            type,
+            color,
+            quantity,
+            price,
+            mCurrency);
         mShopItems.push_back(item);
         mAllShopItems.push_back(item);
     }
@@ -179,7 +199,7 @@ void ShopItems::updateList()
     FOR_EACH (std::vector<ShopItem*>::iterator, it, mAllShopItems)
     {
         ShopItem *const item = *it;
-        if (item && item->isVisible())
+        if ((item != nullptr) && item->isVisible())
             mShopItems.push_back(item);
     }
 }
