@@ -25,7 +25,6 @@
 
 #include "actormanager.h"
 #include "configuration.h"
-#include "units.h"
 
 #include "gui/gui.h"
 
@@ -39,14 +38,21 @@
 
 #include "resources/iteminfo.h"
 
+#include "resources/db/itemoptiondb.h"
+#include "resources/db/unitsdb.h"
+
 #include "resources/image/image.h"
 
 #include "resources/item/item.h"
+#include "resources/item/itemfieldtype.h"
+#include "resources/item/itemoptionslist.h"
 
 #include "resources/loaders/imageloader.h"
 
 #include "net/beinghandler.h"
-#include "net/serverfeatures.h"
+#include "net/net.h"
+
+#include "utils/translation/podict.h"
 
 #include "debug.h"
 
@@ -59,6 +65,7 @@ ItemPopup::ItemPopup() :
     mItemEffect(new TextBox(this)),
     mItemWeight(new TextBox(this)),
     mItemCards(new TextBox(this)),
+    mItemOptions(new TextBox(this)),
     mItemType(ItemDbType::UNUSABLE),
     mIcon(new Icon(this, nullptr)),
     mLastName(),
@@ -94,6 +101,12 @@ ItemPopup::ItemPopup() :
     mItemCards->setPosition(0, 4 * fontHeight);
     mItemCards->setForegroundColorAll(getThemeColor(ThemeColorId::POPUP),
         getThemeColor(ThemeColorId::POPUP_OUTLINE));
+
+    // Item options
+    mItemOptions->setEditable(false);
+    mItemOptions->setPosition(0, 5 * fontHeight);
+    mItemOptions->setForegroundColorAll(getThemeColor(ThemeColorId::POPUP),
+        getThemeColor(ThemeColorId::POPUP_OUTLINE));
 }
 
 void ItemPopup::postInit()
@@ -104,6 +117,7 @@ void ItemPopup::postInit()
     add(mItemEffect);
     add(mItemWeight);
     add(mItemCards);
+    add(mItemOptions);
     add(mIcon);
 
     addMouseListener(this);
@@ -111,10 +125,10 @@ void ItemPopup::postInit()
 
 ItemPopup::~ItemPopup()
 {
-    if (mIcon)
+    if (mIcon != nullptr)
     {
         Image *const image = mIcon->getImage();
-        if (image)
+        if (image != nullptr)
             image->decRef();
     }
 }
@@ -122,7 +136,7 @@ ItemPopup::~ItemPopup()
 void ItemPopup::setItem(const Item *const item,
                         const bool showImage)
 {
-    if (!item)
+    if (item == nullptr)
         return;
 
     const ItemInfo &ii = item->getInfo();
@@ -130,23 +144,26 @@ void ItemPopup::setItem(const Item *const item,
         item->getColor(),
         showImage,
         item->getId(),
-        item->getCards());
+        item->getCards(),
+        item->getOptions());
     if (item->getRefine() > 0)
     {
         mLastName = ii.getName();
         mLastColor = item->getColor();
         mLastId = item->getId();
-        if (serverFeatures->haveItemColors())
+#ifdef TMWA_SUPPORT
+        if (Net::getNetworkType() == ServerType::TMWATHENA)
         {
             mItemName->setCaption(strprintf("%s (+%u), %d",
-                ii.getName(item->getColor()).c_str(),
+                ii.getName().c_str(),
                 CAST_U32(item->getRefine()),
                 ii.getId()));
         }
         else
+#endif  // TMWA_SUPPORT
         {
             mItemName->setCaption(strprintf("%s (+%u), %d",
-                ii.getName().c_str(),
+                ii.getName(item->getColor()).c_str(),
                 CAST_U32(item->getRefine()),
                 ii.getId()));
         }
@@ -161,10 +178,11 @@ void ItemPopup::setItem(const ItemInfo &item,
                         const ItemColor color,
                         const bool showImage,
                         int id,
-                        const int *const cards)
+                        const int *const cards,
+                        const ItemOptionsList *const options)
 {
-    if (!mIcon || (item.getName() == mLastName && color == mLastColor
-        && id == mLastId))
+    if (mIcon == nullptr ||
+        (item.getName() == mLastName && color == mLastColor && id == mLastId))
     {
         return;
     }
@@ -175,17 +193,18 @@ void ItemPopup::setItem(const ItemInfo &item,
     int space = 0;
 
     Image *const oldImage = mIcon->getImage();
-    if (oldImage)
+    if (oldImage != nullptr)
         oldImage->decRef();
 
     if (showImage)
     {
         Image *const image = Loader::getImage(combineDye2(
-            paths.getStringValue("itemIcons").append(item.getDisplay().image),
+            pathJoin(paths.getStringValue("itemIcons"),
+            item.getDisplay().image),
             item.getDyeIconColorsString(color)));
 
         mIcon->setImage(image);
-        if (image)
+        if (image != nullptr)
         {
             mIcon->setPosition(0, 0);
             space = mIcon->getWidth();
@@ -202,18 +221,20 @@ void ItemPopup::setItem(const ItemInfo &item,
     mLastColor = color;
     mLastId = id;
 
-    if (serverFeatures->haveItemColors())
-    {
-        mItemName->setCaption(strprintf("%s, %d",
-            item.getName(color).c_str(), id));
-        mItemDesc->setTextWrapped(item.getDescription(color), 196);
-    }
-    else
+#ifdef TMWA_SUPPORT
+    if (Net::getNetworkType() == ServerType::TMWATHENA)
     {
         mItemName->setCaption(strprintf("%s, %d",
             item.getName().c_str(), id));
         mItemDesc->setTextWrapped(item.getDescription(), 196);
     }
+    else
+#endif  // TMWA_SUPPORT
+    {
+        mItemName->setCaption(strprintf("%s, %d",
+            item.getName(color).c_str(), id));
+        mItemDesc->setTextWrapped(item.getDescription(color), 196);
+    }
 
     mItemName->adjustSize();
     setLabelColor(mItemName, mItemType);
@@ -222,8 +243,9 @@ void ItemPopup::setItem(const ItemInfo &item,
     mItemEffect->setTextWrapped(item.getEffect(), 196);
     // TRANSLATORS: popup label
     mItemWeight->setTextWrapped(strprintf(_("Weight: %s"),
-        Units::formatWeight(item.getWeight()).c_str()), 196);
+        UnitsDb::formatWeight(item.getWeight()).c_str()), 196);
     mItemCards->setTextWrapped(getCardsString(cards), 196);
+    mItemOptions->setTextWrapped(getOptionsString(options), 196);
 
     int minWidth = mItemName->getWidth() + space;
 
@@ -237,29 +259,37 @@ void ItemPopup::setItem(const ItemInfo &item,
         minWidth = mItemWeight->getMinWidth();
     if (mItemCards->getMinWidth() > minWidth)
         minWidth = mItemCards->getMinWidth();
+    if (mItemOptions->getMinWidth() > minWidth)
+        minWidth = mItemOptions->getMinWidth();
 
     const int numRowsDesc = mItemDesc->getNumberOfRows();
     const int numRowsEffect = mItemEffect->getNumberOfRows();
     const int numRowsWeight = mItemWeight->getNumberOfRows();
     const int numRowsCards = mItemCards->getNumberOfRows();
+    const int numRowsOptions = mItemOptions->getNumberOfRows();
     const int height = getFont()->getHeight();
 
     if (item.getEffect().empty())
     {
         setContentSize(minWidth,
-            (numRowsDesc + 2 + numRowsWeight + numRowsCards) * height);
+            (numRowsDesc + 2 + numRowsWeight + numRowsCards + numRowsOptions) *
+            height);
         mItemWeight->setPosition(0, (numRowsDesc + 2) * height);
         mItemCards->setPosition(0, (numRowsDesc + numRowsWeight + 2) * height);
+        mItemOptions->setPosition(0,
+            (numRowsDesc + numRowsWeight + numRowsCards + 2) * height);
     }
     else
     {
         setContentSize(minWidth, (numRowsDesc + numRowsEffect + 2
-            + numRowsWeight + numRowsCards) * height);
+            + numRowsWeight + numRowsCards + numRowsOptions) * height);
         mItemEffect->setPosition(0, (numRowsDesc + 2) * height);
         mItemWeight->setPosition(0, (numRowsDesc + numRowsEffect + 2)
             * height);
         mItemCards->setPosition(0, (numRowsDesc + numRowsEffect
             + numRowsWeight + 2) * height);
+        mItemOptions->setPosition(0, (numRowsDesc + numRowsEffect
+            + numRowsWeight + numRowsCards + 2) * height);
     }
 
     mItemDesc->setPosition(0, 2 * height);
@@ -267,7 +297,7 @@ void ItemPopup::setItem(const ItemInfo &item,
 
 std::string ItemPopup::getCardsString(const int *const cards)
 {
-    if (!cards)
+    if (cards == nullptr)
         return std::string();
 
     std::string label;
@@ -301,7 +331,7 @@ std::string ItemPopup::getCardsString(const int *const cards)
             for (int f = 0; f < maxCards; f ++)
             {
                 const int id = cards[f];
-                if (id)
+                if (id != 0)
                 {
                     if (!label.empty())
                         label.append(" / ");
@@ -317,6 +347,41 @@ std::string ItemPopup::getCardsString(const int *const cards)
     }
 }
 
+std::string ItemPopup::getOptionsString(const ItemOptionsList *const options)
+{
+    if (options == nullptr || translator == nullptr)
+        return std::string();
+    const size_t sz = options->size();
+    std::string effect;
+    for (size_t f = 0; f < sz; f ++)
+    {
+        const ItemOption &option = options->get(f);
+        if (option.index == 0)
+            continue;
+        const std::vector<ItemFieldType*> &fields = ItemOptionDb::getFields(
+            option.index);
+        if (fields.empty())
+            continue;
+        const std::string valueStr = toString(option.value);
+        FOR_EACH (std::vector<ItemFieldType*>::const_iterator, it, fields)
+        {
+            const ItemFieldType *const field = *it;
+            std::string value = valueStr;
+            if (!effect.empty())
+                effect.append(" / ");
+            if (field->sign && value[0] != '-')
+                value.append("+").append(value);
+            const std::string format = translator->getStr(field->description);
+            effect.append(strprintf(format.c_str(),
+                value.c_str()));
+        }
+    }
+    if (effect.empty())
+        return effect;
+    // TRANSLATORS: popup label
+    return _("Options: ") + effect;
+}
+
 #define caseSetColor(name1, name2) \
     case name1: \
     { \
