@@ -29,6 +29,9 @@
 
 #include "const/gui/theme.h"
 
+#include "fs/virtfs/fs.h"
+#include "fs/virtfs/list.h"
+
 #include "gui/skin.h"
 #include "gui/themeinfo.h"
 
@@ -45,8 +48,6 @@
 #include "resources/loaders/xmlloader.h"
 
 #include "utils/dtor.h"
-#include "utils/files.h"
-#include "utils/physfstools.h"
 
 #include "debug.h"
 
@@ -64,8 +65,8 @@ static void initDefaultThemePath()
     defaultThemePath = branding.getStringValue("guiThemePath");
 
     logger->log("defaultThemePath: " + defaultThemePath);
-    if (!defaultThemePath.empty() && PhysFs::isDirectory(
-        defaultThemePath.c_str()))
+    if (!defaultThemePath.empty() &&
+        VirtFs::isDirectory(defaultThemePath))
     {
         return;
     }
@@ -157,12 +158,12 @@ Color Theme::getProgressColor(const ProgressColorIdT type,
 {
     int color[3] = {0, 0, 0};
 
-    if (theme)
+    if (theme != nullptr)
     {
         const DyePalette *const dye
             = theme->mProgressColors[CAST_SIZE(type)];
 
-        if (dye)
+        if (dye != nullptr)
         {
             dye->getColor(progress, color);
         }
@@ -186,7 +187,7 @@ Skin *Theme::load(const std::string &filename,
     const SkinIterator skinIterator = mSkins.find(filename);
     if (mSkins.end() != skinIterator)
     {
-        if (skinIterator->second)
+        if (skinIterator->second != nullptr)
             skinIterator->second->instances++;
         return skinIterator->second;
     }
@@ -195,9 +196,9 @@ Skin *Theme::load(const std::string &filename,
     if (mScreenDensity.empty())
     {   // if no density detected
         skin = readSkin(filename, full);
-        if (!skin && !filename2.empty() && filename2 != filename)
+        if ((skin == nullptr) && !filename2.empty() && filename2 != filename)
             skin = readSkin(filename2, full);
-        if (!skin && filename2 != "window.xml")
+        if ((skin == nullptr) && filename2 != "window.xml")
             skin = readSkin("window.xml", full);
     }
     else
@@ -206,25 +207,25 @@ Skin *Theme::load(const std::string &filename,
         std::string name = filename;
         if (findCutLast(name, ".xml"))
             skin = readSkin(name + endStr, full);
-        if (!skin)
+        if (skin == nullptr)
             skin = readSkin(filename, full);
-        if (!skin && !filename2.empty() && filename2 != filename)
+        if ((skin == nullptr) && !filename2.empty() && filename2 != filename)
         {
             name = filename2;
             if (findCutLast(name, ".xml"))
                 skin = readSkin(name + endStr, full);
-            if (!skin)
+            if (skin == nullptr)
                 skin = readSkin(filename2, full);
         }
-        if (!skin && filename2 != "window.xml")
+        if ((skin == nullptr) && filename2 != "window.xml")
         {
             skin = readSkin("window" + endStr, full);
-            if (!skin)
+            if (skin == nullptr)
                 skin = readSkin("window.xml", full);
         }
     }
 
-    if (!skin)
+    if (skin == nullptr)
     {
         // Try falling back on the defaultPath if this makes sense
         if (filename != defaultPath)
@@ -235,7 +236,7 @@ Skin *Theme::load(const std::string &filename,
             skin = readSkin(defaultPath, full);
         }
 
-        if (!skin)
+        if (skin == nullptr)
         {
             logger->log(strprintf("Error: Loading default skin '%s' failed. "
                                   "Make sure the skin file is valid.",
@@ -249,10 +250,10 @@ Skin *Theme::load(const std::string &filename,
 
 void Theme::unload(Skin *const skin)
 {
-    if (!skin)
+    if (skin == nullptr)
         return;
     skin->instances --;
-    if (!skin->instances)
+    if (skin->instances == 0)
     {
         SkinIterator it = mSkins.begin();
         const SkinIterator it_end = mSkins.end();
@@ -283,12 +284,12 @@ void Theme::updateAlpha()
     FOR_EACH (SkinIterator, iter, mSkins)
     {
         Skin *const skin = iter->second;
-        if (skin)
+        if (skin != nullptr)
             skin->updateAlpha(mMinimumOpacity);
     }
 }
 
-void Theme::optionChanged(const std::string &)
+void Theme::optionChanged(const std::string &name A_UNUSED)
 {
     updateAlpha();
 }
@@ -397,15 +398,15 @@ Skin *Theme::readSkin(const std::string &filename, const bool full)
         return nullptr;
 
     const std::string path = resolveThemePath(filename);
-    if (!PhysFs::exists(path.c_str()))
+    if (!VirtFs::exists(path))
         return nullptr;
     XML::Document *const doc = Loader::getXml(path,
-        UseResman_true,
+        UseVirtFs_true,
         SkipError_true);
-    if (!doc)
+    if (doc == nullptr)
         return nullptr;
-    const XmlNodePtr rootNode = doc->rootNode();
-    if (!rootNode || !xmlNameEqual(rootNode, "skinset"))
+    XmlNodeConstPtr rootNode = doc->rootNode();
+    if ((rootNode == nullptr) || !xmlNameEqual(rootNode, "skinset"))
     {
         doc->decRef();
         return nullptr;
@@ -423,8 +424,6 @@ Skin *Theme::readSkin(const std::string &filename, const bool full)
     Image *const dBorders = Theme::getImageFromTheme(skinSetImage);
     ImageRect *const border = new ImageRect;
     ImageRect *const images = new ImageRect;
-    memset(border, 0, sizeof(ImageRect));
-    memset(images, 0, sizeof(ImageRect));
     int padding = 3;
     int titlePadding = 4;
     int titlebarHeight = 0;
@@ -460,7 +459,7 @@ Skin *Theme::readSkin(const std::string &filename, const bool full)
                         partNode, "ypos", 0) + globalYPos;
                     helper.width = XML::getProperty(partNode, "width", 0);
                     helper.height = XML::getProperty(partNode, "height", 0);
-                    if (!helper.width || !helper.height)
+                    if ((helper.width == 0) || (helper.height == 0))
                         continue;
                     helper.image = dBorders;
 
@@ -527,7 +526,7 @@ Skin *Theme::readSkin(const std::string &filename, const bool full)
         }
     }
 
-    if (dBorders)
+    if (dBorders != nullptr)
         dBorders->decRef();
 
     (*mOptions)["closePadding"] = closePadding;
@@ -550,11 +549,11 @@ bool Theme::tryThemePath(const std::string &themeName)
     if (!themeName.empty())
     {
         const std::string path = defaultThemePath + themeName;
-        if (PhysFs::exists(path.c_str()))
+        if (VirtFs::exists(path))
         {
             mThemePath = path;
             mThemeName = themeName;
-            if (theme)
+            if (theme != nullptr)
                 theme->loadColors("");
             return true;
         }
@@ -565,25 +564,25 @@ bool Theme::tryThemePath(const std::string &themeName)
 
 void Theme::fillSkinsList(StringVect &list)
 {
-    Files::getDirs(branding.getStringValue("guiThemePath"), list);
+    VirtFs::getDirs(branding.getStringValue("guiThemePath"), list);
 }
 
 void Theme::fillFontsList(StringVect &list)
 {
-    PhysFs::permitLinks(true);
-    Files::getFiles(branding.getStringValue("fontsPath"), list);
-    PhysFs::permitLinks(false);
+    VirtFs::permitLinks(true);
+    VirtFs::getFiles(branding.getStringValue("fontsPath"), list);
+    VirtFs::permitLinks(false);
 }
 
 void Theme::fillSoundsList(StringVect &list)
 {
-    char **skins = PhysFs::enumerateFiles(
-        branding.getStringValue("systemsounds").c_str());
+    VirtFs::List *const skins = VirtFs::enumerateFiles(
+        branding.getStringValue("systemsounds"));
 
-    for (char **i = skins; *i; i++)
+    FOR_EACH (StringVectCIter, i, skins->names)
     {
-        if (!PhysFs::isDirectory((
-            branding.getStringValue("systemsounds") + *i).c_str()))
+        if (!VirtFs::isDirectory((branding.getStringValue(
+            "systemsounds") + *i)))
         {
             std::string str = *i;
             if (findCutLast(str, ".ogg"))
@@ -591,7 +590,7 @@ void Theme::fillSoundsList(StringVect &list)
         }
     }
 
-    PhysFs::freeList(skins);
+    VirtFs::freeList(skins);
 }
 
 void Theme::selectSkin()
@@ -637,18 +636,18 @@ std::string Theme::resolveThemePath(const std::string &path)
     if (file.find('/') != std::string::npos)
     {
         // Might be a valid path already
-        if (PhysFs::exists(file.c_str()))
+        if (VirtFs::exists(file))
             return path;
     }
 
     // Try the theme
-    file = getThemePath().append("/").append(file);
+    file = pathJoin(getThemePath(), file);
 
-    if (PhysFs::exists(file.c_str()))
-        return getThemePath().append("/").append(path);
+    if (VirtFs::exists(file))
+        return pathJoin(getThemePath(), path);
 
     // Backup
-    return branding.getStringValue("guiPath").append(path);
+    return pathJoin(branding.getStringValue("guiPath"), path);
 }
 
 Image *Theme::getImageFromTheme(const std::string &path)
@@ -905,7 +904,7 @@ static int readColorType(const std::string &type)
 
 static Color readColor(const std::string &description)
 {
-    const int size = static_cast<const int>(description.length());
+    const int size = static_cast<int>(description.length());
     if (size < 7 || description[0] != '#')
     {
         logger->log("Error, invalid theme color palette: %s",
@@ -959,7 +958,7 @@ static GradientTypeT readColorGradient(const std::string &grad)
 
     for (int i = 0; i < 4; i++)
     {
-        if (compareStrI(grad, grads[i]))
+        if (compareStrI(grad, grads[i]) != 0)
             return static_cast<GradientTypeT>(i);
     }
 
@@ -1002,16 +1001,16 @@ void Theme::loadColors(std::string file)
     if (file.empty())
         file = "colors.xml";
     else
-        file.append("/colors.xml");
+        file = pathJoin(file, "colors.xml");
 
     XML::Document *const doc = Loader::getXml(resolveThemePath(file),
-        UseResman_true,
+        UseVirtFs_true,
         SkipError_false);
-    if (!doc)
+    if (doc == nullptr)
         return;
-    const XmlNodePtrConst root = doc->rootNode();
+    XmlNodeConstPtrConst root = doc->rootNode();
 
-    if (!root || !xmlNameEqual(root, "colors"))
+    if ((root == nullptr) || !xmlNameEqual(root, "colors"))
     {
         logger->log("Error loading colors file: %s", file.c_str());
         doc->decRef();
@@ -1096,7 +1095,7 @@ void Theme::loadRect(ImageRect &image,
                      const int end)
 {
     Skin *const skin = load(name, name2, false);
-    if (skin)
+    if (skin != nullptr)
     {
         loadGrid();
         unload(skin);
@@ -1110,7 +1109,7 @@ Skin *Theme::loadSkinRect(ImageRect &image,
                           const int end)
 {
     Skin *const skin = load(name, name2);
-    if (skin)
+    if (skin != nullptr)
         loadGrid();
     return skin;
 }
@@ -1121,7 +1120,7 @@ void Theme::unloadRect(const ImageRect &rect,
 {
     for (int f = start; f <= end; f ++)
     {
-        if (rect.grid[f])
+        if (rect.grid[f] != nullptr)
             rect.grid[f]->decRef();
     }
 }
@@ -1129,14 +1128,14 @@ void Theme::unloadRect(const ImageRect &rect,
 Image *Theme::getImageFromThemeXml(const std::string &name,
                                    const std::string &name2)
 {
-    if (!theme)
+    if (theme == nullptr)
         return nullptr;
 
     Skin *const skin = theme->load(name, name2, false);
-    if (skin)
+    if (skin != nullptr)
     {
         const ImageRect &rect = skin->getBorder();
-        if (rect.grid[0])
+        if (rect.grid[0] != nullptr)
         {
             Image *const image = rect.grid[0];
             image->incRef();
@@ -1152,18 +1151,18 @@ ImageSet *Theme::getImageSetFromThemeXml(const std::string &name,
                                          const std::string &name2,
                                          const int w, const int h)
 {
-    if (!theme)
+    if (theme == nullptr)
         return nullptr;
 
     Skin *const skin = theme->load(name, name2, false);
-    if (skin)
+    if (skin != nullptr)
     {
         const ImageRect &rect = skin->getBorder();
-        if (rect.grid[0])
+        if (rect.grid[0] != nullptr)
         {
             Image *const image = rect.grid[0];
             const SDL_Rect &rect2 = image->mBounds;
-            if (rect2.w && rect2.h)
+            if ((rect2.w != 0u) && (rect2.h != 0u))
             {
                 ImageSet *const imageSet = Loader::getSubImageSet(
                     image, w, h);
@@ -1177,16 +1176,28 @@ ImageSet *Theme::getImageSetFromThemeXml(const std::string &name,
 }
 
 #define readValue(name) \
-        info->name = reinterpret_cast<const char*>(\
-            XmlNodeGetContent(infoNode))
+        { \
+            tmpData = reinterpret_cast<XmlChar*>( \
+                XmlNodeGetContent(infoNode)); \
+            info->name = tmpData; \
+            XmlFree(tmpData); \
+        }
 
 #define readIntValue(name) \
-        info->name = atoi(reinterpret_cast<const char*>(\
-            XmlNodeGetContent(infoNode)))
+        { \
+            tmpData = reinterpret_cast<XmlChar*>( \
+                XmlNodeGetContent(infoNode)); \
+            info->name = atoi(tmpData); \
+            XmlFree(tmpData); \
+        }
 
 #define readFloatValue(name) \
-        info->name = static_cast<float>(atof(reinterpret_cast<const char*>(\
-            XmlNodeGetContent(infoNode))))
+        { \
+            tmpData = reinterpret_cast<XmlChar*>( \
+                XmlNodeGetContent(infoNode)); \
+            info->name = static_cast<float>(atof(tmpData)); \
+            XmlFree(tmpData); \
+        }
 
 ThemeInfo *Theme::loadInfo(const std::string &themeName)
 {
@@ -1197,59 +1208,61 @@ ThemeInfo *Theme::loadInfo(const std::string &themeName)
     }
     else
     {
-        path = std::string(defaultThemePath).append(
-            themeName).append("/info.xml");
+        path = pathJoin(defaultThemePath,
+            themeName,
+            "info.xml");
     }
     logger->log("loading: " + path);
     XML::Document *const doc = Loader::getXml(path,
-        UseResman_true,
+        UseVirtFs_true,
         SkipError_false);
-    if (!doc)
+    if (doc == nullptr)
         return nullptr;
-    const XmlNodePtrConst rootNode = doc->rootNode();
+    XmlNodeConstPtrConst rootNode = doc->rootNode();
 
-    if (!rootNode || !xmlNameEqual(rootNode, "info"))
+    if ((rootNode == nullptr) || !xmlNameEqual(rootNode, "info"))
     {
         doc->decRef();
         return nullptr;
     }
 
-    ThemeInfo *const info = new ThemeInfo();
+    ThemeInfo *const info = new ThemeInfo;
 
     const std::string fontSize2("fontSize_" + mScreenDensity);
     const std::string npcfontSize2("npcfontSize_" + mScreenDensity);
+    XmlChar *tmpData = nullptr;
     for_each_xml_child_node(infoNode, rootNode)
     {
         if (xmlNameEqual(infoNode, "name"))
-            readValue(name);
+            readValue(name)
         else if (xmlNameEqual(infoNode, "copyright"))
-            readValue(copyright);
+            readValue(copyright)
         else if (xmlNameEqual(infoNode, "font"))
-            readValue(font);
+            readValue(font)
         else if (xmlNameEqual(infoNode, "boldFont"))
-            readValue(boldFont);
+            readValue(boldFont)
         else if (xmlNameEqual(infoNode, "particleFont"))
-            readValue(particleFont);
+            readValue(particleFont)
         else if (xmlNameEqual(infoNode, "helpFont"))
-            readValue(helpFont);
+            readValue(helpFont)
         else if (xmlNameEqual(infoNode, "secureFont"))
-            readValue(secureFont);
+            readValue(secureFont)
         else if (xmlNameEqual(infoNode, "npcFont"))
-            readValue(npcFont);
+            readValue(npcFont)
         else if (xmlNameEqual(infoNode, "japanFont"))
-            readValue(japanFont);
+            readValue(japanFont)
         else if (xmlNameEqual(infoNode, "chinaFont"))
-            readValue(chinaFont);
+            readValue(chinaFont)
         else if (xmlNameEqual(infoNode, "fontSize"))
-            readIntValue(fontSize);
+            readIntValue(fontSize)
         else if (xmlNameEqual(infoNode, "npcfontSize"))
-            readIntValue(npcfontSize);
+            readIntValue(npcfontSize)
         else if (xmlNameEqual(infoNode, "guialpha"))
-            readFloatValue(guiAlpha);
+            readFloatValue(guiAlpha)
         else if (xmlNameEqual(infoNode, fontSize2.c_str()))
-            readIntValue(fontSize);
+            readIntValue(fontSize)
         else if (xmlNameEqual(infoNode, npcfontSize2.c_str()))
-            readIntValue(npcfontSize);
+            readIntValue(npcfontSize)
     }
     doc->decRef();
     return info;
