@@ -61,7 +61,6 @@
 Viewport *viewport = nullptr;
 
 extern volatile int tick_time;
-extern MiniStatusWindow *miniStatusWindow;
 
 Viewport::Viewport() :
     WindowContainer(nullptr),
@@ -93,6 +92,7 @@ Viewport::Viewport() :
     mEnableLazyScrolling(config.getBoolValue("enableLazyScrolling")),
     mMouseDirectionMove(config.getBoolValue("mouseDirectionMove")),
     mLongMouseClick(config.getBoolValue("longmouseclick")),
+    mAllowMoveByMouse(config.getBoolValue("allowMoveByMouse")),
     mMouseClicked(false),
     mPlayerFollowMouse(false)
 {
@@ -106,6 +106,7 @@ Viewport::Viewport() :
     config.addListener("enableLazyScrolling", this);
     config.addListener("mouseDirectionMove", this);
     config.addListener("longmouseclick", this);
+    config.addListener("allowMoveByMouse", this);
 
     setFocusable(true);
     updateMidVars();
@@ -119,7 +120,7 @@ Viewport::~Viewport()
 
 void Viewport::setMap(Map *const map)
 {
-    if (mMap && map)
+    if ((mMap != nullptr) && (map != nullptr))
         map->setDrawLayersFlags(mMap->getDrawLayersFlags());
     mMap = map;
     updateMaxVars();
@@ -130,7 +131,7 @@ void Viewport::draw(Graphics *const graphics)
     BLOCK_START("Viewport::draw 1")
     static int lastTick = tick_time;
 
-    if (!mMap || !localPlayer)
+    if ((mMap == nullptr) || (localPlayer == nullptr))
     {
         graphics->setColor(Color(64, 64, 64));
         graphics->fillRectangle(
@@ -245,7 +246,7 @@ void Viewport::draw(Graphics *const graphics)
     }
 
     // Draw text
-    if (textManager)
+    if (textManager != nullptr)
         textManager->draw(graphics, mPixelViewX, mPixelViewY);
 
     // Draw player names, speech, and emotion sprite as needed
@@ -255,11 +256,11 @@ void Viewport::draw(Graphics *const graphics)
         if ((*it)->getType() == ActorType::FloorItem)
             continue;
         Being *const b = static_cast<Being*>(*it);
-        b->drawSpeech(mPixelViewX, mPixelViewY);
         b->drawEmotion(graphics, mPixelViewX, mPixelViewY);
+        b->drawSpeech(mPixelViewX, mPixelViewY);
     }
 
-    if (miniStatusWindow)
+    if (miniStatusWindow != nullptr)
         miniStatusWindow->drawIcons(graphics);
 
     // Draw contained widgets
@@ -283,14 +284,14 @@ void Viewport::logic()
 
 void Viewport::followMouse()
 {
-    if (!gui)
+    if (gui == nullptr)
         return;
     const MouseStateType button = Gui::getMouseState(mMouseX, mMouseY);
     // If the left button is dragged
-    if (mPlayerFollowMouse && (button & SDL_BUTTON(1)))
+    if (mPlayerFollowMouse && ((button & SDL_BUTTON(1)) != 0))
     {
         // We create a mouse event and send it to mouseDragged.
-        MouseEvent event(nullptr,
+        const MouseEvent event(nullptr,
             MouseEventType::DRAGGED,
             MouseButton::LEFT,
             mMouseX,
@@ -303,8 +304,14 @@ void Viewport::followMouse()
 
 void Viewport::drawDebugPath(Graphics *const graphics)
 {
-    if (!localPlayer || !userPalette || !actorManager || !mMap || !gui)
+    if (localPlayer == nullptr ||
+        userPalette == nullptr ||
+        actorManager == nullptr ||
+        mMap == nullptr ||
+        gui == nullptr)
+    {
         return;
+    }
 
     Gui::getMouseState(mMouseX, mMouseY);
 
@@ -333,7 +340,7 @@ void Viewport::drawDebugPath(Graphics *const graphics)
     FOR_EACH (ActorSpritesConstIterator, it, actors)
     {
         const Being *const being = dynamic_cast<const Being*>(*it);
-        if (being && being != localPlayer)
+        if ((being != nullptr) && being != localPlayer)
         {
             const Path &beingPath = being->getPath();
             drawPath(graphics, beingPath, userPalette->getColorWithAlpha(
@@ -356,7 +363,7 @@ void Viewport::drawPath(Graphics *const graphics,
         const int squareY = i->y * mapTileSize - mPixelViewY + 12;
 
         graphics->fillRectangle(Rect(squareX, squareY, 8, 8));
-        if (mMap)
+        if (mMap != nullptr)
         {
             const std::string str = toString(cnt);
             font->drawString(graphics,
@@ -374,12 +381,12 @@ bool Viewport::openContextMenu(const MouseEvent &event)
     mPlayerFollowMouse = false;
     const int eventX = event.getX();
     const int eventY = event.getY();
-    if (!popupMenu)
+    if (popupMenu == nullptr)
         return false;
-    if (mHoverBeing)
+    if (mHoverBeing != nullptr)
     {
         validateSpeed();
-        if (actorManager)
+        if (actorManager != nullptr)
         {
             std::vector<ActorSprite*> beings;
             const int x = mMouseX + mPixelViewX;
@@ -392,21 +399,21 @@ bool Viewport::openContextMenu(const MouseEvent &event)
             return true;
         }
     }
-    else if (mHoverItem)
+    else if (mHoverItem != nullptr)
     {
         validateSpeed();
         popupMenu->showPopup(eventX, eventY, mHoverItem);
         return true;
     }
-    else if (mHoverSign)
+    else if (mHoverSign != nullptr)
     {
         validateSpeed();
         popupMenu->showPopup(eventX, eventY, mHoverSign);
         return true;
     }
-    else if (settings.cameraMode)
+    else if (settings.cameraMode != 0u)
     {
-        if (!mMap)
+        if (mMap == nullptr)
             return false;
         popupMenu->showMapPopup(eventX, eventY,
             (mMouseX + mPixelViewX) / mMap->getTileWidth(),
@@ -422,7 +429,7 @@ bool Viewport::leftMouseAction()
     const bool stopAttack = inputManager.isActionActive(
         InputAction::STOP_ATTACK);
     // Interact with some being
-    if (mHoverBeing)
+    if (mHoverBeing != nullptr)
     {
         if (!mHoverBeing->isAlive())
             return true;
@@ -440,15 +447,18 @@ bool Viewport::leftMouseAction()
             {
                 case ActorType::Player:
                     validateSpeed();
-                    if (actorManager)
+                    if (actorManager != nullptr)
                     {
 #ifdef TMWA_SUPPORT
                         if (localPlayer != mHoverBeing || mSelfMouseHeal)
                             actorManager->heal(mHoverBeing);
 #endif  // TMWA_SUPPORT
 
-                        if (localPlayer == mHoverBeing && mHoverItem)
+                        if (localPlayer == mHoverBeing &&
+                            mHoverItem != nullptr)
+                        {
                             localPlayer->pickUp(mHoverItem);
+                        }
                         return true;
                     }
                     break;
@@ -498,14 +508,14 @@ bool Viewport::leftMouseAction()
         }
     }
     // Picks up a item if we clicked on one
-    if (mHoverItem)
+    if (mHoverItem != nullptr)
     {
         validateSpeed();
         localPlayer->pickUp(mHoverItem);
     }
     else if (stopAttack)
     {
-        if (mMap)
+        if (mMap != nullptr)
         {
             const int mouseTileX = (mMouseX + mPixelViewX)
                 / mMap->getTileWidth();
@@ -524,10 +534,12 @@ bool Viewport::leftMouseAction()
         validateSpeed();
         localPlayer->stopAttack();
         localPlayer->cancelFollow();
-        mPlayerFollowMouse = true;
-
-        // Make the player go to the mouse position
-        followMouse();
+        mPlayerFollowMouse = mAllowMoveByMouse;
+        if (mPlayerFollowMouse)
+        {
+            // Make the player go to the mouse position
+            followMouse();
+        }
     }
     return false;
 }
@@ -538,7 +550,7 @@ void Viewport::mousePressed(MouseEvent &event)
         return;
 
     // Check if we are alive and kickin'
-    if (!mMap || !localPlayer)
+    if ((mMap == nullptr) || (localPlayer == nullptr))
         return;
 
     // Check if we are busy
@@ -586,12 +598,12 @@ void Viewport::mousePressed(MouseEvent &event)
         mPlayerFollowMouse = false;
         validateSpeed();
         // Find the being nearest to the clicked position
-        if (actorManager)
+        if (actorManager != nullptr)
         {
             Being *const target = actorManager->findNearestLivingBeing(
                 pixelX, pixelY, 20, ActorType::Monster, nullptr);
 
-            if (target)
+            if (target != nullptr)
                 localPlayer->setTarget(target);
         }
     }
@@ -605,7 +617,7 @@ void Viewport::getMouseTile(int &destX, int &destY) const
 void Viewport::getMouseTile(const int x, const int y,
                             int &destX, int &destY) const
 {
-    if (!mMap)
+    if (mMap == nullptr)
         return;
     const int tw = mMap->getTileWidth();
     const int th = mMap->getTileHeight();
@@ -652,7 +664,7 @@ void Viewport::getMouseTile(const int x, const int y,
 
 void Viewport::walkByMouse(const MouseEvent &event)
 {
-    if (!mMap || !localPlayer)
+    if ((mMap == nullptr) || (localPlayer == nullptr))
         return;
     if (mPlayerFollowMouse
         && !inputManager.isActionActive(InputAction::STOP_ATTACK)
@@ -674,7 +686,7 @@ void Viewport::walkByMouse(const MouseEvent &event)
                     / static_cast<float>(height);
                 int x = event.getX() - width;
                 int y = event.getY() - height;
-                if (!x && !y)
+                if ((x == 0) && (y == 0))
                     return;
                 const int x2 = abs(x);
                 const int y2 = abs(y);
@@ -683,15 +695,16 @@ void Viewport::walkByMouse(const MouseEvent &event)
                 int dy = 0;
                 if (x2 > y2)
                 {
-                    if (y2 && static_cast<float>(x2) / static_cast<float>(y2)
-                        / wh > diff)
+                    if (y2 != 0 &&
+                        static_cast<float>(x2) / static_cast<float>(y2) /
+                        wh > diff)
                     {
                         y = 0;
                     }
                 }
                 else
                 {
-                    if (x2 && y2 * wh / x2 > diff)
+                    if ((x2 != 0) && y2 * wh / x2 > diff)
                         x = 0;
                 }
                 if (x > 0)
@@ -714,7 +727,7 @@ void Viewport::walkByMouse(const MouseEvent &event)
                 }
                 else
                 {
-                    if (dx && dy)
+                    if ((dx != 0) && (dy != 0))
                     {
                         // try avoid diagonal collision
                         if (x2 > y2)
@@ -753,7 +766,7 @@ void Viewport::walkByMouse(const MouseEvent &event)
                     else
                     {
                         // try avoid vertical or horisontal collision
-                        if (!dx)
+                        if (dx == 0)
                         {
                             if (mMap->getWalk(playerX + 1,
                                 playerY + dy,
@@ -774,7 +787,7 @@ void Viewport::walkByMouse(const MouseEvent &event)
                                 dx = -1;
                             }
                         }
-                        if (!dy)
+                        if (dy == 0)
                         {
                             if (mMap->getWalk(playerX + dx,
                                 playerY + 1,
@@ -833,8 +846,9 @@ void Viewport::mouseDragged(MouseEvent &event)
         mPlayerFollowMouse = false;
         return;
     }
-    if (mMouseClicked &&
-        localPlayer &&
+    if (mAllowMoveByMouse &&
+        mMouseClicked &&
+        (localPlayer != nullptr) &&
         localPlayer->canMove())
     {
         if (abs(event.getX() - mMousePressX) > 32
@@ -860,7 +874,7 @@ void Viewport::mouseReleased(MouseEvent &event)
         if (eventButton == MouseButton::LEFT)
         {
             // long button press
-            if (gui && gui->isLongPress())
+            if ((gui != nullptr) && gui->isLongPress())
             {
                 if (openContextMenu(event))
                 {
@@ -894,13 +908,19 @@ void Viewport::optionChanged(const std::string &name)
         mMouseDirectionMove = config.getBoolValue("mouseDirectionMove");
     else if (name == "longmouseclick")
         mLongMouseClick = config.getBoolValue("longmouseclick");
+    else if (name == "allowMoveByMouse")
+        mAllowMoveByMouse = config.getBoolValue("allowMoveByMouse");
 }
 
 void Viewport::mouseMoved(MouseEvent &event)
 {
     // Check if we are on the map
-    if (!mMap || !localPlayer || !actorManager)
+    if (mMap == nullptr ||
+        localPlayer == nullptr ||
+        actorManager == nullptr)
+    {
         return;
+    }
 
     if (mMouseDirectionMove)
         mPlayerFollowMouse = false;
@@ -910,9 +930,9 @@ void Viewport::mouseMoved(MouseEvent &event)
 
     ActorTypeT type = ActorType::Unknown;
     mHoverBeing = actorManager->findBeingByPixel(x, y, AllPlayers_true);
-    if (mHoverBeing)
+    if (mHoverBeing != nullptr)
         type = mHoverBeing->getType();
-    if (mHoverBeing
+    if ((mHoverBeing != nullptr)
         && (type == ActorType::Player
         || type == ActorType::Npc
         || type == ActorType::Homunculus
@@ -920,7 +940,7 @@ void Viewport::mouseMoved(MouseEvent &event)
         || type == ActorType::Pet))
     {
         popupManager->hideTextPopup();
-        if (mShowBeingPopup && beingPopup)
+        if (mShowBeingPopup && (beingPopup != nullptr))
             beingPopup->show(mMouseX, mMouseY, mHoverBeing);
     }
     else
@@ -931,10 +951,10 @@ void Viewport::mouseMoved(MouseEvent &event)
     mHoverItem = actorManager->findItem(x / mMap->getTileWidth(),
         y / mMap->getTileHeight());
 
-    if (!mHoverBeing && !mHoverItem)
+    if ((mHoverBeing == nullptr) && (mHoverItem == nullptr))
     {
         const SpecialLayer *const specialLayer = mMap->getSpecialLayer();
-        if (specialLayer)
+        if (specialLayer != nullptr)
         {
             const int mouseTileX = (mMouseX + mPixelViewX)
                 / mMap->getTileWidth();
@@ -942,12 +962,13 @@ void Viewport::mouseMoved(MouseEvent &event)
                 / mMap->getTileHeight();
 
             mHoverSign = specialLayer->getTile(mouseTileX, mouseTileY);
-            if (mHoverSign && mHoverSign->getType() != MapItemType::EMPTY)
+            if (mHoverSign != nullptr &&
+                mHoverSign->getType() != MapItemType::EMPTY)
             {
                 if (!mHoverSign->getComment().empty())
                 {
                     popupManager->hideBeingPopup();
-                    if (textPopup)
+                    if (textPopup != nullptr)
                     {
                         textPopup->show(mMouseX, mMouseY,
                             mHoverSign->getComment());
@@ -966,7 +987,7 @@ void Viewport::mouseMoved(MouseEvent &event)
     if (!event.isConsumed() && popupManager->isTextPopupVisible())
         popupManager->hideTextPopup();
 
-    if (mHoverBeing)
+    if (mHoverBeing != nullptr)
     {
         switch (type)
         {
@@ -991,7 +1012,7 @@ void Viewport::mouseMoved(MouseEvent &event)
         }
     }
     // Item mouseover
-    else if (mHoverItem)
+    else if (mHoverItem != nullptr)
     {
         gui->setCursorType(mHoverItem->getHoverCursor());
     }
@@ -1007,7 +1028,7 @@ void Viewport::toggleMapDrawType()
         CAST_S32(settings.mapDrawType) + 1);
     if (settings.mapDrawType > MapType::BLACKWHITE)
         settings.mapDrawType = MapType::NORMAL;
-    if (mMap)
+    if (mMap != nullptr)
         mMap->setDrawLayersFlags(settings.mapDrawType);
 }
 
@@ -1016,7 +1037,7 @@ void Viewport::toggleCameraMode()
     settings.cameraMode ++;
     if (settings.cameraMode > 1)
         settings.cameraMode = 0;
-    if (!settings.cameraMode)
+    if (settings.cameraMode == 0u)
     {
         mCameraRelativeX = 0;
         mCameraRelativeY = 0;
@@ -1051,11 +1072,11 @@ void Viewport::moveCamera(const int dx, const int dy)
 void Viewport::moveCameraToActor(const BeingId actorId,
                                  const int x, const int y)
 {
-    if (!localPlayer || !actorManager)
+    if ((localPlayer == nullptr) || (actorManager == nullptr))
         return;
 
     const Actor *const actor = actorManager->findBeing(actorId);
-    if (!actor)
+    if (actor == nullptr)
         return;
     settings.cameraMode = 1;
     mCameraRelativeX = actor->mPixelX - localPlayer->mPixelX + x;
@@ -1065,7 +1086,7 @@ void Viewport::moveCameraToActor(const BeingId actorId,
 
 void Viewport::moveCameraToPosition(const int x, const int y)
 {
-    if (!localPlayer)
+    if (localPlayer == nullptr)
         return;
 
     settings.cameraMode = 1;
@@ -1095,7 +1116,7 @@ void Viewport::validateSpeed()
     if (!inputManager.isActionActive(InputAction::TARGET_ATTACK) &&
         !inputManager.isActionActive(InputAction::ATTACK))
     {
-        if (Game::instance())
+        if (Game::instance() != nullptr)
             Game::instance()->setValidSpeed();
     }
 }
@@ -1110,7 +1131,7 @@ void Viewport::updateMidVars()
 
 void Viewport::updateMaxVars()
 {
-    if (!mMap)
+    if (mMap == nullptr)
         return;
     mViewXmax = mMap->getWidth() * mMap->getTileWidth()
         - mainGraphics->mWidth;
