@@ -23,15 +23,10 @@
 
 #include "gui/widgets/browserbox.h"
 
-#include "itemcolormanager.h"
-#include "main.h"
-#include "settings.h"
-
-#include "const/resources/item/cards.h"
-
-#include "input/inputmanager.h"
+#include "enums/gui/linkhighlightmode.h"
 
 #include "gui/gui.h"
+#include "gui/mouseoverlink.h"
 #include "gui/skin.h"
 
 #include "gui/fonts/font.h"
@@ -40,17 +35,6 @@
 
 #include "render/graphics.h"
 
-#ifndef DYECMD
-#include "resources/beinginfo.h"
-#include "resources/iteminfo.h"
-
-#include "resources/db/homunculusdb.h"
-#include "resources/db/itemdb.h"
-#include "resources/db/mercenarydb.h"
-#include "resources/db/monsterdb.h"
-#include "resources/db/petdb.h"
-#endif  // DYECMD
-
 #include "resources/imageset.h"
 
 #include "resources/image/image.h"
@@ -58,6 +42,8 @@
 #include "resources/loaders/imageloader.h"
 #include "resources/loaders/imagesetloader.h"
 
+#include "utils/browserboxtools.h"
+#include "utils/checkutils.h"
 #include "utils/stringutils.h"
 #include "utils/timer.h"
 #include "utils/translation/podict.h"
@@ -66,51 +52,26 @@
 
 #include "debug.h"
 
-namespace
-{
-    struct MouseOverLink final
-    {
-        MouseOverLink(const int x,
-                      const int y) :
-            mX(x),
-            mY(y)
-        { }
-
-        A_DEFAULT_COPY(MouseOverLink)
-
-        bool operator() (const BrowserLink &link) const
-        {
-            return (mX >= link.x1 &&
-                mX < link.x2 &&
-                mY >= link.y1 &&
-                mY < link.y2);
-        }
-        const int mX;
-        const int mY;
-    };
-}  // namespace
-
 ImageSet *BrowserBox::mEmotes = nullptr;
 int BrowserBox::mInstances = 0;
 
 #define readColor(color) \
-    mColors[0][color] = getThemeColor(ThemeColorId::color); \
-    mColors[1][color] = getThemeColor(ThemeColorId::color##_OUTLINE)
+    mColors[0][ColorName::color] = getThemeColor(ThemeColorId::color); \
+    mColors[1][ColorName::color] = getThemeColor(ThemeColorId::color##_OUTLINE)
 
 BrowserBox::BrowserBox(const Widget2 *const widget,
-                       const unsigned int mode,
                        const Opaque opaque,
                        const std::string &skin) :
     Widget(widget),
     MouseListener(),
+    WidgetListener(),
     mTextRows(),
     mTextRowLinksCount(),
     mLineParts(),
     mLinks(),
     mLinkHandler(nullptr),
     mSkin(nullptr),
-    mMode(mode),
-    mHighMode(0),
+    mHighlightMode(0),
     mSelectedLink(-1),
     mMaxRows(0),
     mHeight(0),
@@ -136,10 +97,11 @@ BrowserBox::BrowserBox(const Widget2 *const widget,
 
     setFocusable(true);
     addMouseListener(this);
+    addWidgetListener(this);
 
     mBackgroundColor = getThemeColor(ThemeColorId::BACKGROUND);
 
-    if (theme)
+    if (theme != nullptr)
         mSkin = theme->load(skin, "browserbox.xml");
     if (mInstances == 0)
     {
@@ -148,16 +110,16 @@ BrowserBox::BrowserBox(const Widget2 *const widget,
     }
     mInstances ++;
 
-    if (mSkin)
+    if (mSkin != nullptr)
     {
         mPadding = mSkin->getPadding();
         mNewLinePadding = CAST_U32(
             mSkin->getOption("newLinePadding", 15));
         mItemPadding = mSkin->getOption("itemPadding");
-        if (mSkin->getOption("highlightBackground"))
-            mHighMode |= BACKGROUND;
-        if (mSkin->getOption("highlightUnderline"))
-            mHighMode |= UNDERLINE;
+        if (mSkin->getOption("highlightBackground") != 0)
+            mHighlightMode |= LinkHighlightMode::BACKGROUND;
+        if (mSkin->getOption("highlightUnderline") != 0)
+            mHighlightMode |= LinkHighlightMode::UNDERLINE;
     }
 
     readColor(BLACK);
@@ -177,10 +139,10 @@ BrowserBox::BrowserBox(const Widget2 *const widget,
 
 BrowserBox::~BrowserBox()
 {
-    if (gui)
+    if (gui != nullptr)
         gui->removeDragged(this);
 
-    if (theme)
+    if (theme != nullptr)
     {
         theme->unload(mSkin);
         mSkin = nullptr;
@@ -189,7 +151,7 @@ BrowserBox::~BrowserBox()
     mInstances --;
     if (mInstances == 0)
     {
-        if (mEmotes)
+        if (mEmotes != nullptr)
         {
             mEmotes->decRef();
             mEmotes = nullptr;
@@ -206,7 +168,6 @@ void BrowserBox::addRow(const std::string &row, const bool atTop)
 {
     std::string tmp = row;
     std::string newRow;
-    size_t idx1;
     const Font *const font = getFont();
     int linksCount = 0;
 
@@ -215,8 +176,7 @@ void BrowserBox::addRow(const std::string &row, const bool atTop)
 
     if (mProcessVars)
     {
-        tmp = replaceAll(tmp, "%VER%", SMALL_VERSION);
-        tmp = replaceAll(tmp, "%SUPPORTURL%", settings.supportUrl);
+        BrowserBoxTools::replaceVars(tmp);
     }
 
     // Use links and user defined colors
@@ -229,22 +189,10 @@ void BrowserBox::addRow(const std::string &row, const bool atTop)
 
         if (mEnableKeys)
         {
-            idx1 = tmp.find("###");
-            while (idx1 != std::string::npos)
-            {
-                const size_t idx2 = tmp.find(';', idx1);
-                if (idx2 == std::string::npos)
-                    break;
-
-                const std::string str = inputManager.getKeyValueByNameLong(
-                    tmp.substr(idx1 + 3, idx2 - idx1 - 3));
-                tmp.replace(idx1, idx2 - idx1 + 1, str);
-
-                idx1 = tmp.find("###");
-            }
+            BrowserBoxTools::replaceKeys(tmp);
         }
 
-        idx1 = tmp.find("@@");
+        size_t idx1 = tmp.find("@@");
         while (idx1 != std::string::npos)
         {
             const size_t idx2 = tmp.find('|', idx1);
@@ -258,69 +206,9 @@ void BrowserBox::addRow(const std::string &row, const bool atTop)
             bLink.y2 = bLink.y1 + font->getHeight();
             if (bLink.caption.empty())
             {
-                bLink.caption = bLink.link;
-#ifndef DYECMD
-                const std::string link = bLink.link;
-                if (!link.empty() && link[0] == 'm')
-                {  // monster link
-                    const BeingTypeId id = static_cast<BeingTypeId>(
-                        atoi(bLink.link.substr(1).c_str()));
-                    BeingInfo *info = MonsterDB::get(id);
-                    if (info)
-                        bLink.caption = info->getName();
-                }
-                else if (!link.empty() && link[0] == 'p')
-                {  // pet link
-                    const BeingTypeId id = static_cast<BeingTypeId>(
-                        atoi(bLink.link.substr(1).c_str()));
-                    BeingInfo *info = PETDB::get(id);
-                    if (info)
-                        bLink.caption = info->getName();
-                }
-                else if (!link.empty() && link[0] == 'h')
-                {  // homunculus link
-                    const BeingTypeId id = static_cast<BeingTypeId>(
-                        atoi(bLink.link.substr(1).c_str()));
-                    BeingInfo *info = HomunculusDB::get(id);
-                    if (info)
-                        bLink.caption = info->getName();
-                }
-                else if (!link.empty() && link[0] == 'M')
-                {  // homunculus link
-                    const BeingTypeId id = static_cast<BeingTypeId>(
-                        atoi(bLink.link.substr(1).c_str()));
-                    BeingInfo *info = MercenaryDB::get(id);
-                    if (info)
-                        bLink.caption = info->getName();
-                }
-                else
-                {  // item link
-                    size_t idx = bLink.link.find(',');
-                    if (idx != std::string::npos)
-                    {
-                        const int id = atoi(bLink.link.substr(0, idx).c_str());
-                        if (id)
-                        {
-                            std::vector<int> parts;
-                            splitToIntVector(parts,
-                                bLink.link.substr(idx), ',');
-                            while (parts.size() < maxCards)
-                                parts.push_back(0);
-                            const ItemColor itemColor =
-                                ItemColorManager::getColorFromCards(&parts[0]);
-                            bLink.caption = ItemDB::get(id).getName(itemColor);
-                        }
-                    }
-                    else
-                    {
-                        const int id = atoi(bLink.link.c_str());
-                        if (id)
-                            bLink.caption = ItemDB::get(id).getName();
-                    }
-                }
-#endif  // DYECMD
-
-                if (translator)
+                bLink.caption = BrowserBoxTools::replaceLinkCommands(
+                    bLink.link);
+                if (translator != nullptr)
                     bLink.caption = translator->getStr(bLink.caption);
             }
 
@@ -361,23 +249,7 @@ void BrowserBox::addRow(const std::string &row, const bool atTop)
 
     if (mEnableTabs)
     {
-        idx1 = newRow.find("\\t");
-        while (idx1 != std::string::npos)
-        {
-            const size_t idx2 = newRow.find(';', idx1);
-            if (idx2 == std::string::npos)
-                break;
-
-            const unsigned int newSize = CAST_U32(
-                atoi(newRow.substr(
-                idx1 + 2, idx2 - idx1 - 2).c_str()));
-            std::string str = newRow.substr(0, idx1);
-            while (str.size() < newSize)
-                str.append(" ");
-            str.append(newRow.substr(idx2 + 1));
-            newRow = str;
-            idx1 = newRow.find("\\t");
-        }
+        BrowserBoxTools::replaceTabs(newRow);
     }
 
     if (atTop)
@@ -400,7 +272,7 @@ void BrowserBox::addRow(const std::string &row, const bool atTop)
             int cnt = mTextRowLinksCount.front();
             mTextRowLinksCount.pop_front();
 
-            while (cnt && !mLinks.empty())
+            while ((cnt != 0) && !mLinks.empty())
             {
                 mLinks.erase(mLinks.begin());
                 cnt --;
@@ -408,82 +280,58 @@ void BrowserBox::addRow(const std::string &row, const bool atTop)
         }
     }
 
-    // Auto size mode
-    if (mMode == AUTO_SIZE)
-    {
-        std::string plain = newRow;
-        for (idx1 = plain.find("##");
-             idx1 != std::string::npos;
-             idx1 = plain.find("##"))
-        {
-            plain.erase(idx1, 3);
-        }
-
-        // Adjust the BrowserBox size
-        const int w = font->getWidth(plain);
-        if (w > getWidth())
-            setWidth(w);
-    }
-
     const int fontHeight = font->getHeight();
-    if (mMode == AUTO_WRAP)
+    unsigned int y = 0;
+    unsigned int nextChar;
+    const char *const hyphen = "~";
+    const unsigned int hyphenWidth = CAST_U32(
+        font->getWidth(hyphen));
+    unsigned int x = 0;
+
+    FOR_EACH (TextRowCIter, i, mTextRows)
     {
-        unsigned int y = 0;
-        unsigned int nextChar;
-        const char *const hyphen = "~";
-        const unsigned int hyphenWidth = CAST_U32(
-            font->getWidth(hyphen));
-        unsigned int x = 0;
-
-        FOR_EACH (TextRowCIter, i, mTextRows)
+        std::string tempRow = *i;
+        for (uint32_t j = 0, sz = CAST_U32(tempRow.size());
+             j < sz;
+             j++)
         {
-            std::string tempRow = *i;
-            for (uint32_t j = 0, sz = CAST_U32(tempRow.size());
-                 j < sz;
-                 j++)
+            const std::string character = tempRow.substr(j, 1);
+            x += CAST_U32(font->getWidth(character));
+            nextChar = j + 1;
+
+            // Wraping between words (at blank spaces)
+            if (nextChar < sz && tempRow.at(nextChar) == ' ')
             {
-                const std::string character = tempRow.substr(j, 1);
-                x += CAST_U32(font->getWidth(character));
-                nextChar = j + 1;
+                int nextSpacePos = CAST_U32(
+                    tempRow.find(' ', (nextChar + 1)));
+                if (nextSpacePos <= 0)
+                    nextSpacePos = CAST_U32(sz) - 1U;
 
-                // Wraping between words (at blank spaces)
-                if (nextChar < sz && tempRow.at(nextChar) == ' ')
-                {
-                    int nextSpacePos = CAST_U32(
-                        tempRow.find(' ', (nextChar + 1)));
-                    if (nextSpacePos <= 0)
-                        nextSpacePos = CAST_U32(sz) - 1U;
+                const unsigned int nextWordWidth =
+                    CAST_U32(font->getWidth(
+                    tempRow.substr(nextChar,
+                    (CAST_U32(nextSpacePos) - nextChar))));
 
-                    const unsigned int nextWordWidth =
-                        CAST_U32(font->getWidth(
-                        tempRow.substr(nextChar,
-                        (CAST_U32(nextSpacePos) - nextChar))));
-
-                    if ((x + nextWordWidth + 10)
-                        > CAST_U32(getWidth()))
-                    {
-                        x = mNewLinePadding;  // Ident in new line
-                        y += 1;
-                        j ++;
-                    }
-                }
-                // Wrapping looong lines (brutal force)
-                else if ((x + 2 * hyphenWidth)
-                         > CAST_U32(getWidth()))
+                if ((x + nextWordWidth + 10)
+                    > CAST_U32(getWidth()))
                 {
                     x = mNewLinePadding;  // Ident in new line
                     y += 1;
+                    j ++;
                 }
             }
+            // Wrapping looong lines (brutal force)
+            else if ((x + 2 * hyphenWidth)
+                     > CAST_U32(getWidth()))
+            {
+                x = mNewLinePadding;  // Ident in new line
+                y += 1;
+            }
         }
+    }
 
-        setHeight(fontHeight * (CAST_S32(
-            CAST_U32(mTextRows.size()) + y)));
-    }
-    else
-    {
-        setHeight(fontHeight * CAST_S32(mTextRows.size()));
-    }
+    setHeight(fontHeight * (CAST_S32(
+        CAST_U32(mTextRows.size()) + y)));
     mUpdateTime = 0;
     updateHeight();
 }
@@ -518,7 +366,7 @@ void BrowserBox::clearRows()
 
 void BrowserBox::mousePressed(MouseEvent &event)
 {
-    if (!mLinkHandler)
+    if (mLinkHandler == nullptr)
         return;
 
     const LinkIterator i = std::find_if(mLinks.begin(), mLinks.end(),
@@ -555,7 +403,10 @@ void BrowserBox::draw(Graphics *const graphics)
         mYStart = 0;
 
     if (mDimension.width != mWidth)
+    {
         updateHeight();
+        reportAlways("browserbox resize in draw");
+    }
 
     if (mOpaque == Opaque_true)
     {
@@ -564,10 +415,10 @@ void BrowserBox::draw(Graphics *const graphics)
             mDimension.width, mDimension.height));
     }
 
-    if (mSelectedLink >= 0 && mSelectedLink
-        < CAST_S32(mLinks.size()))
+    if (mSelectedLink >= 0 &&
+        mSelectedLink < CAST_S32(mLinks.size()))
     {
-        if ((mHighMode & BACKGROUND))
+        if ((mHighlightMode & LinkHighlightMode::BACKGROUND) != 0u)
         {
             BrowserLink &link = mLinks[CAST_SIZE(mSelectedLink)];
             graphics->setColor(mHighlightColor);
@@ -578,7 +429,7 @@ void BrowserBox::draw(Graphics *const graphics)
                 link.y2 - link.y1));
         }
 
-        if ((mHighMode & UNDERLINE))
+        if ((mHighlightMode & LinkHighlightMode::UNDERLINE) != 0u)
         {
             BrowserLink &link = mLinks[CAST_SIZE(mSelectedLink)];
             graphics->setColor(mHyperLinkColor);
@@ -599,7 +450,7 @@ void BrowserBox::draw(Graphics *const graphics)
             continue;
         if (part.mY > yEnd)
             break;
-        if (!part.mType)
+        if (part.mType == 0u)
         {
             if (part.mBold)
             {
@@ -618,7 +469,7 @@ void BrowserBox::draw(Graphics *const graphics)
                     part.mX, part.mY);
             }
         }
-        else if (part.mImage)
+        else if (part.mImage != nullptr)
         {
             graphics->drawImage(part.mImage, part.mX, part.mY);
         }
@@ -685,7 +536,7 @@ int BrowserBox::calcHeight()
             if (sz > 2 && str.substr(sz - 1) == "~")
                 str = str.substr(0, sz - 1);
             Image *const img = Loader::getImage(str);
-            if (img)
+            if (img != nullptr)
             {
                 img->incRef();
                 mLineParts.push_back(LinePart(CAST_S32(x),
@@ -726,11 +577,6 @@ int BrowserBox::calcHeight()
             // "Tokenize" the string at control sequences
             if (mUseLinksAndUserColors)
                 idx1 = row.find("##", start + 1);
-            if (idx1 < idx2)
-                end = idx1;
-            else
-                end = idx2;
-
             if (start == 0 || mUseLinksAndUserColors)
             {
                 // Check for color change in format "##x", x = [L,P,0..9]
@@ -776,44 +622,44 @@ int BrowserBox::calcHeight()
                         switch (c)
                         {
                             case '0':
-                                selColor[0] = mColors[0][BLACK];
-                                selColor[1] = mColors[1][BLACK];
+                                selColor[0] = mColors[0][ColorName::BLACK];
+                                selColor[1] = mColors[1][ColorName::BLACK];
                                 break;
                             case '1':
-                                selColor[0] = mColors[0][RED];
-                                selColor[1] = mColors[1][RED];
+                                selColor[0] = mColors[0][ColorName::RED];
+                                selColor[1] = mColors[1][ColorName::RED];
                                 break;
                             case '2':
-                                selColor[0] = mColors[0][GREEN];
-                                selColor[1] = mColors[1][GREEN];
+                                selColor[0] = mColors[0][ColorName::GREEN];
+                                selColor[1] = mColors[1][ColorName::GREEN];
                                 break;
                             case '3':
-                                selColor[0] = mColors[0][BLUE];
-                                selColor[1] = mColors[1][BLUE];
+                                selColor[0] = mColors[0][ColorName::BLUE];
+                                selColor[1] = mColors[1][ColorName::BLUE];
                                 break;
                             case '4':
-                                selColor[0] = mColors[0][ORANGE];
-                                selColor[1] = mColors[1][ORANGE];
+                                selColor[0] = mColors[0][ColorName::ORANGE];
+                                selColor[1] = mColors[1][ColorName::ORANGE];
                                 break;
                             case '5':
-                                selColor[0] = mColors[0][YELLOW];
-                                selColor[1] = mColors[1][YELLOW];
+                                selColor[0] = mColors[0][ColorName::YELLOW];
+                                selColor[1] = mColors[1][ColorName::YELLOW];
                                 break;
                             case '6':
-                                selColor[0] = mColors[0][PINK];
-                                selColor[1] = mColors[1][PINK];
+                                selColor[0] = mColors[0][ColorName::PINK];
+                                selColor[1] = mColors[1][ColorName::PINK];
                                 break;
                             case '7':
-                                selColor[0] = mColors[0][PURPLE];
-                                selColor[1] = mColors[1][PURPLE];
+                                selColor[0] = mColors[0][ColorName::PURPLE];
+                                selColor[1] = mColors[1][ColorName::PURPLE];
                                 break;
                             case '8':
-                                selColor[0] = mColors[0][GRAY];
-                                selColor[1] = mColors[1][GRAY];
+                                selColor[0] = mColors[0][ColorName::GRAY];
+                                selColor[1] = mColors[1][ColorName::GRAY];
                                 break;
                             case '9':
-                                selColor[0] = mColors[0][BROWN];
-                                selColor[1] = mColors[1][BROWN];
+                                selColor[0] = mColors[0][ColorName::BROWN];
+                                selColor[1] = mColors[1][ColorName::BROWN];
                                 break;
                             default:
                                 selColor[0] = textColor[0];
@@ -867,14 +713,14 @@ int BrowserBox::calcHeight()
                         const int cid = row.at(start + 2) - '0';
                         if (cid >= 0)
                         {
-                            if (mEmotes)
+                            if (mEmotes != nullptr)
                             {
                                 const size_t sz = mEmotes->size();
                                 if (CAST_SIZE(cid) < sz)
                                 {
                                     Image *const img = mEmotes->get(
                                         CAST_SIZE(cid));
-                                    if (img)
+                                    if (img != nullptr)
                                     {
                                         mLineParts.push_back(LinePart(
                                             CAST_S32(x),
@@ -911,8 +757,9 @@ int BrowserBox::calcHeight()
                 width = font->getWidth(part);
 
             // Auto wrap mode
-            if (mMode == AUTO_WRAP && wWidth > 0 && width > 0
-                && (x + CAST_U32(width) + 10) > wWidth)
+            if (wWidth > 0 &&
+                width > 0 &&
+                (x + CAST_U32(width) + 10) > wWidth)
             {
                 bool forced = false;
 
@@ -976,7 +823,7 @@ int BrowserBox::calcHeight()
             else
                 width = font->getWidth(part);
 
-            if (mMode == AUTO_WRAP && (width == 0 && !processed))
+            if (width == 0 && !processed)
                 break;
 
             x += CAST_U32(width);
@@ -995,7 +842,7 @@ int BrowserBox::calcHeight()
 void BrowserBox::updateHeight()
 {
     if (mAlwaysUpdate || mUpdateTime != cur_time
-        || mTextRows.size() < 3 || !mUpdateTime)
+        || mTextRows.size() < 3 || (mUpdateTime == 0))
     {
         mWidth = mDimension.width;
         mHeight = calcHeight();
@@ -1004,6 +851,13 @@ void BrowserBox::updateHeight()
     }
 }
 
+void BrowserBox::updateSize(const bool always)
+{
+    if (always)
+        mUpdateTime = 0;
+    updateHeight();
+}
+
 std::string BrowserBox::getTextAtPos(const int x, const int y) const
 {
     int textX = 0;
@@ -1063,7 +917,7 @@ void BrowserBox::moveSelectionDown()
 
 void BrowserBox::selectSelection()
 {
-    if (!mLinkHandler ||
+    if ((mLinkHandler == nullptr) ||
         mSelectedLink < 0 ||
         mSelectedLink >= static_cast<signed int>(mLinks.size()))
     {
@@ -1073,3 +927,8 @@ void BrowserBox::selectSelection()
     mLinkHandler->handleLink(mLinks[CAST_SIZE(mSelectedLink)].link,
         nullptr);
 }
+
+void BrowserBox::widgetResized(const Event &event A_UNUSED)
+{
+    updateHeight();
+}
