@@ -18,18 +18,27 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "catch.hpp"
+#include "test/unittests.h"
+
 #include "client.h"
+#include "configuration.h"
+#include "configmanager.h"
+#include "dirs.h"
 #include "graphicsmanager.h"
 
 #include "being/actorsprite.h"
 
+#include "fs/virtfs/fs.h"
+
 #include "gui/gui.h"
 
 #include "gui/fonts/font.h"
 
 #include "gui/widgets/browserbox.h"
 
+#include "utils/delete2.h"
+#include "utils/env.h"
+
 #include "render/sdlgraphics.h"
 
 #include "resources/resourcemanager/resourcemanager.h"
@@ -38,17 +47,23 @@
 
 #include "debug.h"
 
-extern const char *dirSeparator;
+TEST_CASE("BrowserBox leak test1", "")
+{
+    logger = new Logger();
+    REQUIRE(gui == nullptr);
+    ResourceManager::cleanOrphans(true);
+    ResourceManager::deleteInstance();
+    delete2(logger);
+}
 
 TEST_CASE("BrowserBox tests", "browserbox")
 {
-    dirSeparator = "/";
+    setEnv("SDL_VIDEODRIVER", "dummy");
+
     client = new Client;
     logger = new Logger();
-    imageHelper = new SDLImageHelper();
-    ResourceManager::init();
-    resourceManager->addToSearchPath("data", Append_false);
-    resourceManager->addToSearchPath("../data", Append_false);
+    VirtFs::mountDirSilent("data", Append_false);
+    VirtFs::mountDirSilent("../data", Append_false);
 
     mainGraphics = new SDLGraphics;
     imageHelper = new SDLImageHelper;
@@ -63,6 +78,14 @@ TEST_CASE("BrowserBox tests", "browserbox")
 
     theme = new Theme;
     Theme::selectSkin();
+
+    Dirs::initRootDir();
+    Dirs::initHomeDir();
+
+    ConfigManager::initConfiguration();
+    getConfigDefaults2(config.getDefaultValues());
+    branding.setDefaultValues(getBrandingDefaults());
+
     ActorSprite::load();
     gui = new Gui();
     gui->postInit(mainGraphics);
@@ -70,7 +93,6 @@ TEST_CASE("BrowserBox tests", "browserbox")
     Widget::setGlobalFont(new Font("/usr/share/fonts/truetype/"
         "ttf-dejavu/DejaVuSans-Oblique.ttf", 18));
     BrowserBox *const box = new BrowserBox(nullptr,
-        BrowserBox::AUTO_WRAP,
         Opaque_true,
         "");
     box->setWidth(100);
@@ -139,6 +161,7 @@ TEST_CASE("BrowserBox tests", "browserbox")
     row = "11|22<####>";
     box->addRow(row);
     row = "11|22##><##";
+    box->addRow(row);
     row = "%%@@11|22@@";
     box->addRow(row);
     row = "%%2@@11|22@@";
@@ -168,8 +191,21 @@ TEST_CASE("BrowserBox tests", "browserbox")
     row = "##1%%2";
     box->addRow(row);
 
+    delete Widget::getGloablFont();
+    Widget::setGlobalFont(nullptr);
     delete box;
-    delete client;
-    client = nullptr;
-//    PhysFs::deinit();
+    delete2(client);
+    VirtFs::unmountDirSilent("data");
+    VirtFs::unmountDirSilent("../data");
+    delete2(logger);
+//    VirtFs::deinit();
+}
+
+TEST_CASE("BrowserBox leak test2", "")
+{
+    logger = new Logger();
+    REQUIRE(gui == nullptr);
+    ResourceManager::cleanOrphans(true);
+    ResourceManager::deleteInstance();
+    delete2(logger);
 }
