@@ -34,6 +34,7 @@
 
 #include "gui/windows/confirmdialog.h"
 #include "gui/windows/helpwindow.h"
+#include "gui/windows/questswindow.h"
 
 #include "input/inputmanager.h"
 
@@ -94,7 +95,7 @@ void ItemLinkHandler::handleCommandLink(const std::string &link,
 
 void ItemLinkHandler::handleHelpLink(const std::string &link)
 {
-    if (helpWindow)
+    if (helpWindow != nullptr)
     {
         helpWindow->loadHelp(link.substr(7));
         helpWindow->requestMoveToTop();
@@ -104,7 +105,7 @@ void ItemLinkHandler::handleHelpLink(const std::string &link)
 void ItemLinkHandler::handleHttpLink(const std::string &link,
                                      const MouseEvent *const event)
 {
-    if (!event)
+    if (event == nullptr)
         return;
     std::string url = link;
     replaceAll(url, " ", "");
@@ -123,14 +124,14 @@ void ItemLinkHandler::handleHttpLink(const std::string &link,
     }
     else if (button == MouseButton::RIGHT)
     {
-        if (popupMenu)
+        if (popupMenu != nullptr)
             popupMenu->showLinkPopup(url);
     }
 }
 
 void ItemLinkHandler::handleItemLink(const std::string &link)
 {
-    if (!itemPopup || link.empty())
+    if ((itemPopup == nullptr) || link.empty())
         return;
 
     const char ch = link[0];
@@ -153,12 +154,13 @@ void ItemLinkHandler::handleItemLink(const std::string &link)
             ItemColorManager::getColorFromCards(&str[0]);
 
         const ItemInfo &itemInfo = ItemDB::get(id);
-        itemPopup->setItem(itemInfo, color, true, -1, &str[0]);
+        // +++ need add support for options.
+        itemPopup->setItem(itemInfo, color, true, -1, &str[0], nullptr);
         if (itemPopup->isPopupVisible())
         {
             itemPopup->setVisible(Visible_false);
         }
-        else if (viewport)
+        else if (viewport != nullptr)
         {
             itemPopup->position(viewport->mMouseX,
                 viewport->mMouseY);
@@ -168,7 +170,7 @@ void ItemLinkHandler::handleItemLink(const std::string &link)
 
 void ItemLinkHandler::handleSearchLink(const std::string &link)
 {
-    if (helpWindow)
+    if (helpWindow != nullptr)
     {
         helpWindow->search(link.substr(1));
         helpWindow->requestMoveToTop();
@@ -178,11 +180,14 @@ void ItemLinkHandler::handleSearchLink(const std::string &link)
 void ItemLinkHandler::handleLink(const std::string &link,
                                  MouseEvent *const event)
 {
+    if (link.empty())
+        return;
+
     if (strStartWith(link, "http://") || strStartWith(link, "https://"))
     {
         handleHttpLink(link, event);
     }
-    else if (!link.empty() && link[0] == '?')
+    else if (link[0] == '?')
     {
         handleSearchLink(link);
     }
@@ -200,13 +205,17 @@ void ItemLinkHandler::handleLink(const std::string &link,
     }
     else if (link == "news")
     {
-        if (helpWindow)
+        if (helpWindow != nullptr)
             helpWindow->loadHelpSimple("news");
     }
-    if (link == "copyright")
+    else if (link == "copyright")
     {
         inputManager.executeAction(InputAction::WINDOW_ABOUT);
     }
+    else if (link[0] == 'q')
+    {
+        questsWindow->selectQuest(atoi(link.substr(1).c_str()));
+    }
     else
     {
         handleItemLink(link);
