@@ -22,7 +22,7 @@
 
 #include "gui/widgets/selldialog.h"
 
-#include "units.h"
+#include "const/resources/currency.h"
 
 #include "enums/gui/layouttype.h"
 
@@ -43,6 +43,8 @@
 #include "utils/gettext.h"
 #include "utils/stringutils.h"
 
+#include "resources/db/unitsdb.h"
+
 #include "resources/item/shopitem.h"
 
 #include "debug.h"
@@ -77,6 +79,7 @@ SellDialog::SellDialog(const IsSell isSell,
 
 void SellDialog::postInit()
 {
+    Window::postInit();
     setWindowName("Sell");
     setResizable(true);
     setCloseButton(true);
@@ -85,11 +88,12 @@ void SellDialog::postInit()
     setMinHeight(220);
     setDefaultSize(260, 230, ImagePosition::CENTER);
 
-    if (setupWindow)
+    if (setupWindow != nullptr)
         setupWindow->registerWindowForReset(this);
 
     // Create a ShopItems instance, that is aware of duplicate entries.
-    mShopItems = new ShopItems(true);
+    mShopItems = new ShopItems(true,
+        DEFAULT_CURRENCY);
 
     if (mAdvanced == Advanced_true)
         mShopItems->setMergeDuplicates(false);
@@ -202,7 +206,7 @@ SellDialog::~SellDialog()
 void SellDialog::reset()
 {
     mShopItems->clear();
-    if (mSlider)
+    if (mSlider != nullptr)
         mSlider->setValue(0);
     mShopItemList->setSelected(-1);
     updateButtonsAndLabels();
@@ -210,7 +214,7 @@ void SellDialog::reset()
 
 void SellDialog::addItem(const Item *const item, const int price)
 {
-    if (!item)
+    if (item == nullptr)
         return;
 
     mShopItems->addItem2(item->getInvIndex(),
@@ -260,25 +264,30 @@ void SellDialog::action(const ActionEvent &event)
 
     if (eventId == "slider")
     {
-        if (mSlider)
+        if (mSlider != nullptr)
         {
             mAmountItems = CAST_S32(mSlider->getValue());
             updateButtonsAndLabels();
         }
     }
-    else if (eventId == "inc" && mSlider && mAmountItems < mMaxItems)
+    else if (eventId == "inc" &&
+             mSlider != nullptr &&
+             mAmountItems < mMaxItems)
     {
         mAmountItems++;
         mSlider->setValue(mAmountItems);
         updateButtonsAndLabels();
     }
-    else if (eventId == "dec" && mSlider && mAmountItems > 1)
+    else if (eventId == "dec" &&
+             mSlider != nullptr &&
+             mAmountItems > 1)
     {
         mAmountItems--;
         mSlider->setValue(mAmountItems);
         updateButtonsAndLabels();
     }
-    else if (eventId == "max" && mSlider)
+    else if (eventId == "max" &&
+             mSlider != nullptr)
     {
         mAmountItems = mMaxItems;
         mSlider->setValue(mAmountItems);
@@ -297,7 +306,7 @@ void SellDialog::valueChanged(const SelectionEvent &event A_UNUSED)
 {
     // Reset amount of items and update labels
     mAmountItems = 1;
-    if (mSlider)
+    if (mSlider != nullptr)
     {
         mSlider->setValue(0);
         mSlider->setScale(1, mMaxItems);
@@ -317,10 +326,10 @@ void SellDialog::updateButtonsAndLabels()
     int income = 0;
     ShopItem *item = nullptr;
 
-    if (selectedItem > -1 && mShopItems->at(selectedItem))
+    if (selectedItem > -1 && (mShopItems->at(selectedItem) != nullptr))
     {
         item = mShopItems->at(selectedItem);
-        if (item)
+        if (item != nullptr)
         {
             mMaxItems = item->getQuantity();
             if (mAmountItems > mMaxItems)
@@ -341,27 +350,27 @@ void SellDialog::updateButtonsAndLabels()
 
     // Update Buttons and slider
     mSellButton->setEnabled(mAmountItems > 0);
-    if (mDecreaseButton)
+    if (mDecreaseButton != nullptr)
         mDecreaseButton->setEnabled(mAmountItems > 1);
-    if (mIncreaseButton)
+    if (mIncreaseButton != nullptr)
         mIncreaseButton->setEnabled(mAmountItems < mMaxItems);
-    if (mSlider)
+    if (mSlider != nullptr)
         mSlider->setEnabled(mMaxItems > 1);
 
-    if (mQuantityLabel)
+    if (mQuantityLabel != nullptr)
     {
         // Update the quantity and money labels
         mQuantityLabel->setCaption(strprintf("%d / %d",
             mAmountItems, mMaxItems));
     }
-    if (mMoneyLabel)
+    if (mMoneyLabel != nullptr)
     {
         // TRANSLATORS: sell dialog label
         mMoneyLabel->setCaption(strprintf(_("Price: %s / Total: %s"),
-            Units::formatCurrency(income).c_str(),
-            Units::formatCurrency(mPlayerMoney + income).c_str()));
+            UnitsDb::formatCurrency(income).c_str(),
+            UnitsDb::formatCurrency(mPlayerMoney + income).c_str()));
     }
-    if (item)
+    if (item != nullptr)
         item->update();
 }
 
@@ -371,7 +380,7 @@ void SellDialog::setVisible(Visible visible)
 
     if (visible == Visible_true)
     {
-        if (mShopItemList)
+        if (mShopItemList != nullptr)
             mShopItemList->requestFocus();
     }
     else
