@@ -77,11 +77,11 @@ class SocialGuildTab2 final : public SocialTab,
         void buildCounter(const int online0 A_UNUSED,
                           const int total0 A_UNUSED) override final
         {
-            if (!localPlayer)
+            if (localPlayer == nullptr)
                 return;
 
             const Guild *const guild = localPlayer->getGuild();
-            if (!guild)
+            if (guild == nullptr)
                 return;
 
             const Guild::MemberList *const members = guild->getMembers();
