@@ -29,6 +29,8 @@
 #include "settings.h"
 #include "spellmanager.h"
 
+#include "fs/virtfs/tools.h"
+
 #include "gui/gui.h"
 #include "gui/userpalette.h"
 
@@ -57,13 +59,14 @@
 #include "input/touch/touchmanager.h"
 
 #include "utils/delete2.h"
-#include "utils/files.h"
 #include "utils/sdlcheckutils.h"
 #include "utils/sdlhelper.h"
 #ifdef __native_client__
 #include "utils/naclmessages.h"
 #endif  // __native_client__
 
+PRAGMA48(GCC diagnostic push)
+PRAGMA48(GCC diagnostic ignored "-Wshadow")
 #ifdef ANDROID
 #ifndef USE_SDL2
 #include <SDL_screenkeyboard.h>
@@ -81,6 +84,7 @@
 #ifdef WIN32
 #include <SDL_syswm.h>
 #endif  // WIN32
+PRAGMA48(GCC diagnostic pop)
 
 #include "debug.h"
 
@@ -193,7 +197,7 @@ void WindowManager::updateTitle()
 
 void WindowManager::setFramerate(const unsigned int fpsLimit)
 {
-    if (!fpsLimit)
+    if (fpsLimit == 0u)
         return;
 
     if (!settings.limitFps)
@@ -239,7 +243,7 @@ void WindowManager::resizeVideo(int actualWidth,
     actualWidth = std::max(470, actualWidth);
     actualHeight = std::max(320, actualHeight);
 
-    if (!mainGraphics)
+    if (mainGraphics == nullptr)
         return;
     if (!always
         && mainGraphics->mActualWidth == actualWidth
@@ -254,21 +258,21 @@ void WindowManager::resizeVideo(int actualWidth,
         const int height = mainGraphics->mHeight;
         touchManager.resize(width, height);
 
-        if (gui)
+        if (gui != nullptr)
             gui->videoResized();
 
-        if (desktop)
+        if (desktop != nullptr)
             desktop->setSize(width, height);
 
         client->moveButtons(width);
 
 #ifndef DYECMD
         Game *const game = Game::instance();
-        if (game)
+        if (game != nullptr)
             game->videoResized(width, height);
 #endif  // DYECMD
 
-        if (gui)
+        if (gui != nullptr)
             gui->draw();
 
         config.setValue("screenwidth", actualWidth);
@@ -284,7 +288,7 @@ bool WindowManager::setFullScreen(const bool fs)
     return true;
 #else  // __native_client__
 
-    if (!mainGraphics)
+    if (mainGraphics == nullptr)
         return false;
     return mainGraphics->setFullscreen(fs);
 #endif  // __native_client__
@@ -363,7 +367,7 @@ void WindowManager::setIcon()
     iconFile.append(".png");
 #endif  // WIN32
 
-    iconFile = Files::getPath(iconFile);
+    iconFile = VirtFs::getPath(iconFile);
     logger->log("Loading icon from file: %s", iconFile.c_str());
 
 #ifdef WIN32
@@ -373,8 +377,11 @@ void WindowManager::setIcon()
     else
         SDL::getWindowWMInfo(nullptr, &pInfo);
     // Attempt to load icon from .ico file
-    HICON icon = (HICON) LoadImage(nullptr, iconFile.c_str(),
-        IMAGE_ICON, 64, 64, LR_LOADFROMFILE);
+    HICON icon = static_cast<HICON>(LoadImage(nullptr,
+        iconFile.c_str(),
+        IMAGE_ICON,
+        64, 64,
+        LR_LOADFROMFILE));
     // If it's failing, we load the default resource file.
     if (!icon)
     {
@@ -382,11 +389,21 @@ void WindowManager::setIcon()
         icon = LoadIcon(GetModuleHandle(nullptr), "A");
     }
     if (icon)
-        SetClassLong(pInfo.window, GCL_HICON, reinterpret_cast<LONG>(icon));
+    {
+#ifdef WIN64
+        SetClassLongPtr(pInfo.window,
+            GCLP_HICON,
+            reinterpret_cast<LONG_PTR>(icon));
+#else  // WIN64
+        SetClassLong(pInfo.window,
+            GCL_HICON,
+            reinterpret_cast<LONG>(icon));
+#endif  // WIN64
+    }
 #else  // WIN32
 
     mIcon = MIMG_Load(iconFile.c_str());
-    if (mIcon)
+    if (mIcon != nullptr)
     {
 #ifdef USE_SDL2
         SDL_SetSurfaceAlphaMod(mIcon, SDL_ALPHA_OPAQUE);
@@ -425,4 +442,5 @@ void WindowManager::updateScreenKeyboard(const int height)
 void WindowManager::deleteIcon()
 {
     MSDL_FreeSurface(mIcon);
+    mIcon = nullptr;
 }
