@@ -18,28 +18,40 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "catch.hpp"
+#include "test/unittests.h"
+
 #include "client.h"
+#include "configmanager.h"
 #include "configuration.h"
+#include "dirs.h"
 #include "graphicsmanager.h"
+#include "main.h"
 #include "settings.h"
-#include "units.h"
 #include "textcommand.h"
 
-#include "being/being.h"
+#include "being/localplayer.h"
+
+#include "const/resources/currency.h"
+
+#include "fs/virtfs/fs.h"
 
 #include "gui/gui.h"
 #include "gui/mailmessage.h"
 #include "gui/userpalette.h"
+#include "gui/windowmanager.h"
 
 #include "gui/popups/beingpopup.h"
 #include "gui/popups/itempopup.h"
 #include "gui/popups/popupmenu.h"
+#include "gui/popups/skillpopup.h"
 #include "gui/popups/spellpopup.h"
+#include "gui/popups/speechbubble.h"
+#include "gui/popups/statuspopup.h"
 #include "gui/popups/textboxpopup.h"
 #include "gui/popups/textpopup.h"
 
 #include "gui/widgets/desktop.h"
+#include "gui/widgets/emoteshortcutcontainer.h"
 #include "gui/widgets/createwidget.h"
 
 #include "gui/windows/bankwindow.h"
@@ -71,6 +83,7 @@
 #include "gui/windows/mailwindow.h"
 #include "gui/windows/minimap.h"
 #include "gui/windows/ministatuswindow.h"
+#include "gui/windows/npcdialog.h"
 #include "gui/windows/npcselldialog.h"
 #include "gui/windows/okdialog.h"
 #include "gui/windows/outfitwindow.h"
@@ -78,6 +91,7 @@
 #include "gui/windows/quitdialog.h"
 #include "gui/windows/registerdialog.h"
 #include "gui/windows/serverdialog.h"
+#include "gui/windows/serverinfowindow.h"
 #include "gui/windows/setupwindow.h"
 #include "gui/windows/shopwindow.h"
 #include "gui/windows/shortcutwindow.h"
@@ -105,6 +119,8 @@
 
 #include "resources/sdlimagehelper.h"
 
+#include "resources/db/unitsdb.h"
+
 #include "resources/item/item.h"
 
 #include "resources/map/map.h"
@@ -114,7 +130,6 @@
 #include "utils/delete2.h"
 #include "utils/env.h"
 #include "utils/gettext.h"
-#include "utils/physfstools.h"
 
 #include "utils/translation/translationmanager.h"
 
@@ -122,23 +137,29 @@
 
 extern QuitDialog *quitDialog;
 
+TEST_CASE("windows leak test1", "")
+{
+    logger = new Logger();
+    REQUIRE(gui == nullptr);
+    ResourceManager::cleanOrphans(true);
+    ResourceManager::deleteInstance();
+    delete2(logger);
+}
+
 TEST_CASE("Windows tests", "windowmanager")
 {
     setEnv("SDL_VIDEODRIVER", "dummy");
 
     client = new Client;
-    dirSeparator = "/";
     XML::initXML();
     SDL_Init(SDL_INIT_VIDEO);
     logger = new Logger();
-    delete resourceManager;
-    resourceManager = nullptr;
-    ResourceManager::init();
-    resourceManager->cleanOrphans(true);
-    resourceManager->addToSearchPath("data", Append_false);
-    resourceManager->addToSearchPath("../data", Append_false);
-    resourceManager->addToSearchPath("data/test", Append_false);
-    resourceManager->addToSearchPath("../data/test", Append_false);
+    ResourceManager::deleteInstance();
+    ResourceManager::cleanOrphans(true);
+    VirtFs::mountDirSilent("data", Append_false);
+    VirtFs::mountDirSilent("../data", Append_false);
+    VirtFs::mountDirSilent("data/test", Append_false);
+    VirtFs::mountDirSilent("../data/test", Append_false);
     paths.setDefaultValues(getPathsDefaults());
     branding.setValue("onlineServerFile", "test/serverlistplus.xml");
     mainGraphics = new SDLGraphics;
@@ -156,11 +177,27 @@ TEST_CASE("Windows tests", "windowmanager")
     config.setValue("fontSize", 16);
     theme = new Theme;
     Theme::selectSkin();
+
+    Dirs::initRootDir();
+    Dirs::initHomeDir();
+
+    const std::string cfgName = settings.configDir +
+        "/nonexistserver/config.xml";
+    ::remove(cfgName.c_str());
+
+    ConfigManager::initConfiguration();
+    getConfigDefaults2(config.getDefaultValues());
+    branding.setDefaultValues(getBrandingDefaults());
+    ConfigManager::initServerConfig("nonexistserver");
+
+    localPlayer = new LocalPlayer(static_cast<BeingId>(1),
+        BeingTypeId_zero);
+
     ActorSprite::load();
     gui = new Gui();
     gui->postInit(mainGraphics);
     touchManager.init();
-    Units::loadUnits();
+    UnitsDb::loadUnits();
     charServerHandler = new EAthena::CharServerHandler;
     serverFeatures = new EAthena::ServerFeatures;
     inventoryHandler = new EAthena::InventoryHandler;
@@ -178,14 +215,55 @@ TEST_CASE("Windows tests", "windowmanager")
         mainGraphics->updateScreen();
         delete2(bankWindow);
     }
-    SECTION("buyDialog")
+    SECTION("buyDialog1")
     {
         BuyDialog *dialog;
-        CREATEWIDGETV(dialog, BuyDialog, BeingId_zero);
+        CREATEWIDGETV0(dialog, BuyDialog);
         gui->draw();
         mainGraphics->updateScreen();
         delete2(dialog);
     }
+    SECTION("buyDialog2")
+    {
+        BuyDialog *dialog;
+        CREATEWIDGETV(dialog, BuyDialog,
+            BeingId_zero,
+            DEFAULT_CURRENCY);
+        gui->draw();
+        mainGraphics->updateScreen();
+        delete2(dialog);
+    }
+#ifdef TMWA_SUPPORT
+    SECTION("buyDialog3")
+    {
+        BuyDialog *dialog;
+        CREATEWIDGETV(dialog, BuyDialog,
+            "user",
+            DEFAULT_CURRENCY);
+        gui->draw();
+        mainGraphics->updateScreen();
+        delete2(dialog);
+    }
+#endif  // TMWA_SUPPORT
+    SECTION("buyDialog4")
+    {
+        BuyDialog *dialog;
+        BeingTypeId id = static_cast<BeingTypeId>(1);
+        Map *map = new Map("test map",
+            10, 10,
+            32, 32);
+        Being *being = Being::createBeing(BeingId_zero,
+            ActorType::Avatar,
+            id,
+            map);
+        CREATEWIDGETV(dialog, BuyDialog,
+            being,
+            DEFAULT_CURRENCY);
+        gui->draw();
+        mainGraphics->updateScreen();
+        delete2(dialog);
+        delete2(being);
+    }
     SECTION("BuyingStoreSellDialog")
     {
         BuyingStoreSellDialog *dialog;
@@ -195,7 +273,7 @@ TEST_CASE("Windows tests", "windowmanager")
         mainGraphics->updateScreen();
         delete2(dialog);
     }
-    SECTION("BuySellDialog")
+    SECTION("BuySellDialog1")
     {
         BuySellDialog *dialog;
         CREATEWIDGETV(dialog, BuySellDialog, BeingId_zero);
@@ -203,6 +281,14 @@ TEST_CASE("Windows tests", "windowmanager")
         mainGraphics->updateScreen();
         delete2(dialog);
     }
+    SECTION("BuySellDialog2")
+    {
+        BuySellDialog *dialog;
+        CREATEWIDGETV(dialog, BuySellDialog, "user");
+        gui->draw();
+        mainGraphics->updateScreen();
+        delete2(dialog);
+    }
     SECTION("ChangeEmailDialog")
     {
         LoginData data;
@@ -291,7 +377,7 @@ TEST_CASE("Windows tests", "windowmanager")
     SECTION("EditServerDialog")
     {
         ServerInfo mCurrentServer;
-        settings.configDir = PhysFs::getRealDir("test/serverlistplus.xml");
+        settings.configDir = VirtFs::getRealDir("test/serverlistplus.xml");
         ServerDialog *serverDialog = CREATEWIDGETR(ServerDialog,
             &mCurrentServer,
             settings.configDir);
@@ -320,7 +406,7 @@ TEST_CASE("Windows tests", "windowmanager")
     {
         Equipment *equipment = new Equipment;
         Map *map = new Map("test", 100, 100, 32, 32);
-        Being *being = new Being(BeingId_zero,
+        Being *being = Being::createBeing(BeingId_zero,
             ActorType::Player,
             BeingTypeId_zero,
             map);
@@ -445,11 +531,10 @@ TEST_CASE("Windows tests", "windowmanager")
     }
     SECTION("NpcDialog")
     {
-//  for now have random issue. Almost impossible to reproduce.
-//        NpcDialog *dialog = CREATEWIDGETR(NpcDialog, BeingId_zero);
-//        gui->draw();
-//        mainGraphics->updateScreen();
-//        delete2(dialog);
+        NpcDialog *dialog = CREATEWIDGETR(NpcDialog, BeingId_zero);
+        gui->draw();
+        mainGraphics->updateScreen();
+        delete2(dialog);
     }
     SECTION("NpcSellDialog")
     {
@@ -500,7 +585,7 @@ TEST_CASE("Windows tests", "windowmanager")
     SECTION("serversDialog")
     {
         ServerInfo mCurrentServer;
-        settings.configDir = PhysFs::getRealDir("test/serverlistplus.xml");
+        settings.configDir = VirtFs::getRealDir("test/serverlistplus.xml");
         ServerDialog *serverDialog = CREATEWIDGETR(ServerDialog,
             &mCurrentServer,
             settings.configDir);
@@ -508,6 +593,15 @@ TEST_CASE("Windows tests", "windowmanager")
         mainGraphics->updateScreen();
         delete2(serverDialog);
     }
+    SECTION("serversInfoWindow")
+    {
+        ServerInfo mCurrentServer;
+        ServerInfoWindow *serverInfoWindow = CREATEWIDGETR(ServerInfoWindow,
+            mCurrentServer);
+        gui->draw();
+        mainGraphics->updateScreen();
+        delete2(serverInfoWindow);
+    }
     SECTION("setupWindow")
     {
         CREATEWIDGETV0(setupWindow, SetupWindow);
@@ -526,7 +620,18 @@ TEST_CASE("Windows tests", "windowmanager")
         mainGraphics->updateScreen();
         delete2(shopWindow);
     }
-    SECTION("ShortcutWindow")
+    SECTION("ShortcutWindow1")
+    {
+        EmoteShortcutContainer *container =
+            new EmoteShortcutContainer(nullptr);
+        CREATEWIDGETV(itemShortcutWindow, ShortcutWindow,
+            "name",
+            container);
+        gui->draw();
+        mainGraphics->updateScreen();
+        delete2(itemShortcutWindow);
+    }
+    SECTION("ShortcutWindow2")
     {
         CREATEWIDGETV(itemShortcutWindow, ShortcutWindow, "");
         gui->draw();
@@ -563,6 +668,7 @@ TEST_CASE("Windows tests", "windowmanager")
         gui->draw();
         mainGraphics->updateScreen();
         delete2(dialog);
+        delete2(textCommand);
     }
 
     SECTION("TextDialog")
@@ -619,6 +725,20 @@ TEST_CASE("Windows tests", "windowmanager")
         mainGraphics->updateScreen();
         delete2(popupMenu);
     }
+    SECTION("skillPopup")
+    {
+        CREATEWIDGETV0(skillPopup, SkillPopup);
+        gui->draw();
+        mainGraphics->updateScreen();
+        delete2(skillPopup);
+    }
+    SECTION("SpeechBubble")
+    {
+        SpeechBubble *bubble = CREATEWIDGETR0(SpeechBubble);
+        gui->draw();
+        mainGraphics->updateScreen();
+        delete2(bubble);
+    }
     SECTION("beingPopup")
     {
         CREATEWIDGETV0(beingPopup, BeingPopup);
@@ -654,6 +774,13 @@ TEST_CASE("Windows tests", "windowmanager")
         mainGraphics->updateScreen();
         delete2(spellPopup);
     }
+    SECTION("StatusPopup")
+    {
+        StatusPopup *status = CREATEWIDGETR0(StatusPopup);
+        gui->draw();
+        mainGraphics->updateScreen();
+        delete2(status);
+    }
     SECTION("desktop")
     {
         CREATEWIDGETV(desktop, Desktop, nullptr);
@@ -672,9 +799,185 @@ TEST_CASE("Windows tests", "windowmanager")
         delete2(connectionDialog);
     }
 
+    delete2(localPlayer);
     delete2(userPalette);
     delete2(client);
     delete2(serverFeatures);
     delete2(inventoryHandler);
-//    PhysFs::deinit();
+    delete2(charServerHandler);
+    delete2(playerHandler);
+    delete2(gui);
+    ResourceManager::deleteInstance();
+    VirtFs::unmountDirSilent("data");
+    VirtFs::unmountDirSilent("../data");
+    VirtFs::unmountDirSilent("data/test");
+    VirtFs::unmountDirSilent("../data/test");
+    delete2(logger);
+
+//    VirtFs::deinit();
+}
+
+TEST_CASE("WindowManager", "create windows")
+{
+    setEnv("SDL_VIDEODRIVER", "dummy");
+
+    client = new Client;
+    XML::initXML();
+    SDL_Init(SDL_INIT_VIDEO);
+    logger = new Logger();
+    ResourceManager::deleteInstance();
+    ResourceManager::cleanOrphans(true);
+    VirtFs::mountDirSilent("data", Append_false);
+    VirtFs::mountDirSilent("../data", Append_false);
+    VirtFs::mountDirSilent("data/test", Append_false);
+    VirtFs::mountDirSilent("../data/test", Append_false);
+    paths.setDefaultValues(getPathsDefaults());
+    branding.setValue("onlineServerFile", "test/serverlistplus.xml");
+    mainGraphics = new SDLGraphics;
+    imageHelper = new SDLImageHelper;
+#ifdef USE_SDL2
+    SDLImageHelper::setRenderer(graphicsManager.createRenderer(
+        graphicsManager.createWindow(640, 480, 0,
+        SDL_WINDOW_SHOWN | SDL_SWSURFACE), SDL_RENDERER_SOFTWARE));
+#else  // USE_SDL2
+
+    graphicsManager.createWindow(640, 480, 0, SDL_ANYFORMAT | SDL_SWSURFACE);
+#endif  // USE_SDL2
+
+    config.setValue("fontSize", 16);
+    theme = new Theme;
+    Theme::selectSkin();
+
+    Dirs::initRootDir();
+    Dirs::initHomeDir();
+
+    const std::string cfgName = settings.configDir +
+        "/nonexistserver/config.xml";
+    ::remove(cfgName.c_str());
+
+    ConfigManager::initConfiguration();
+    getConfigDefaults2(config.getDefaultValues());
+    branding.setDefaultValues(getBrandingDefaults());
+    ConfigManager::initServerConfig("nonexistserver");
+
+    localPlayer = new LocalPlayer(static_cast<BeingId>(1),
+        BeingTypeId_zero);
+
+    ActorSprite::load();
+    gui = new Gui();
+    gui->postInit(mainGraphics);
+    touchManager.init();
+    UnitsDb::loadUnits();
+    charServerHandler = new EAthena::CharServerHandler;
+    serverFeatures = new EAthena::ServerFeatures;
+    inventoryHandler = new EAthena::InventoryHandler;
+    playerHandler = new EAthena::PlayerHandler;
+    paths.setValue("itemIcons", "");
+
+    TranslationManager::init();
+
+    mainGraphics->setVideoMode(640, 480, 1, 8, false, false, false, false);
+
+    SECTION("create windows")
+    {
+        WindowManager::createWindows();
+        WindowManager::deleteWindows();
+    }
+
+    SECTION("init")
+    {
+        WindowManager::init();
+    }
+
+    SECTION("initTitle")
+    {
+        WindowManager::initTitle();
+        REQUIRE(settings.windowCaption == strprintf("%s %s",
+            branding.getStringValue("appName").c_str(),
+            SMALL_VERSION));
+    }
+
+    SECTION("updateTitle1")
+    {
+        settings.serverName = std::string();
+        settings.login = std::string();
+        WindowManager::updateTitle();
+        REQUIRE(settings.windowCaption == strprintf("%s %s",
+            branding.getStringValue("appName").c_str(),
+            SMALL_VERSION));
+    }
+
+    SECTION("updateTitle2")
+    {
+        settings.serverName = "server";
+        settings.login = std::string();
+        WindowManager::updateTitle();
+        REQUIRE(settings.windowCaption == strprintf("%s %s - %s",
+            branding.getStringValue("appName").c_str(),
+            SMALL_VERSION,
+            settings.serverName.c_str()));
+    }
+
+    SECTION("updateTitle3")
+    {
+        settings.serverName = "server";
+        settings.login = "login";
+        WindowManager::updateTitle();
+        REQUIRE(settings.windowCaption == strprintf("%s %s - %s %s",
+            branding.getStringValue("appName").c_str(),
+            SMALL_VERSION,
+            settings.login.c_str(),
+            settings.serverName.c_str()));
+    }
+
+    SECTION("setFramerate1")
+    {
+        settings.limitFps = true;
+        WindowManager::setFramerate(60);
+        REQUIRE(WindowManager::getFramerate() == 60);
+        WindowManager::setFramerate(10);
+        REQUIRE(WindowManager::getFramerate() == 10);
+        WindowManager::setFramerate(0);
+        REQUIRE(WindowManager::getFramerate() == 10);
+    }
+
+    SECTION("setFramerate2")
+    {
+        settings.limitFps = false;
+        WindowManager::setFramerate(60);
+        REQUIRE(WindowManager::getFramerate() == 0);
+        WindowManager::setFramerate(10);
+        REQUIRE(WindowManager::getFramerate() == 0);
+        WindowManager::setFramerate(0);
+        REQUIRE(WindowManager::getFramerate() == 0);
+    }
+
+    settings.serverName = std::string();
+    settings.login = std::string();
+    settings.limitFps = true;
+
+    delete2(localPlayer);
+    delete2(client);
+    delete2(serverFeatures);
+    delete2(inventoryHandler);
+    delete2(charServerHandler);
+    delete2(playerHandler);
+    delete2(gui);
+    ResourceManager::deleteInstance();
+    VirtFs::unmountDirSilent("data");
+    VirtFs::unmountDirSilent("../data");
+    VirtFs::unmountDirSilent("data/test");
+    VirtFs::unmountDirSilent("../data/test");
+    delete2(logger);
+
+//    VirtFs::deinit();
+}
+
+TEST_CASE("windows leak test2", "")
+{
+    logger = new Logger();
+    REQUIRE(gui == nullptr);
+    ResourceManager::cleanOrphans(true);
+    ResourceManager::deleteInstance();
+    delete2(logger);
 }
