@@ -24,7 +24,6 @@
 
 #include "actormanager.h"
 #include "configuration.h"
-#include "units.h"
 
 #include "being/being.h"
 
@@ -51,12 +50,14 @@
 #include "net/buysellhandler.h"
 #include "net/cashshophandler.h"
 #include "net/markethandler.h"
+#include "net/net.h"
 #include "net/vendinghandler.h"
-#include "net/serverfeatures.h"
 #include "net/npchandler.h"
 
 #include "resources/iteminfo.h"
 
+#include "resources/db/unitsdb.h"
+
 #include "utils/delete2.h"
 
 #include <algorithm>
@@ -73,7 +74,7 @@ namespace
             bool operator() (const ShopItem *const item1,
                              const ShopItem *const item2) const
             {
-                if (!item1 || !item2)
+                if ((item1 == nullptr) || (item2 == nullptr))
                     return false;
 
                 const int price1 = item1->getPrice();
@@ -92,7 +93,7 @@ namespace
             bool operator() (const ShopItem *const item1,
                              const ShopItem *const item2) const
             {
-                if (!item1 || !item2)
+                if ((item1 == nullptr) || (item2 == nullptr))
                     return false;
 
                 const std::string &name1 = item1->getDisplayName();
@@ -111,7 +112,7 @@ namespace
             bool operator() (const ShopItem *const item1,
                              const ShopItem *const item2) const
             {
-                if (!item1 || !item2)
+                if ((item1 == nullptr) || (item2 == nullptr))
                     return false;
 
                 const int id1 = item1->getId();
@@ -130,7 +131,7 @@ namespace
             bool operator() (const ShopItem *const item1,
                              const ShopItem *const item2) const
             {
-                if (!item1 || !item2)
+                if ((item1 == nullptr) || (item2 == nullptr))
                     return false;
 
                 const int weight1 = item1->getInfo().getWeight();
@@ -149,7 +150,7 @@ namespace
             bool operator() (const ShopItem *const item1,
                              const ShopItem *const item2) const
             {
-                if (!item1 || !item2)
+                if ((item1 == nullptr) || (item2 == nullptr))
                     return false;
 
                 const int amount1 = item1->getQuantity();
@@ -168,7 +169,7 @@ namespace
             bool operator() (const ShopItem *const item1,
                              const ShopItem *const item2) const
             {
-                if (!item1 || !item2)
+                if ((item1 == nullptr) || (item2 == nullptr))
                     return false;
 
                 const ItemDbTypeT type1 = item1->getInfo().getType();
@@ -193,6 +194,7 @@ BuyDialog::BuyDialog() :
         this, "namefilter", true)),
     mFilterLabel(nullptr),
     mNick(),
+    mCurrency(),
     mNpcId(fromInt(Items, BeingId)),
     mMoney(0),
     mAmountItems(0),
@@ -202,7 +204,8 @@ BuyDialog::BuyDialog() :
     init();
 }
 
-BuyDialog::BuyDialog(const BeingId npcId) :
+BuyDialog::BuyDialog(const BeingId npcId,
+                     const std::string &currency) :
     // TRANSLATORS: buy dialog name
     Window(_("Buy"), Modal_false, nullptr, "buy.xml"),
     ActionListener(),
@@ -213,17 +216,19 @@ BuyDialog::BuyDialog(const BeingId npcId) :
         this, "namefilter", true)),
     mFilterLabel(nullptr),
     mNick(),
+    mCurrency(currency),
     mNpcId(npcId),
     mMoney(0),
     mAmountItems(0),
     mMaxItems(0),
-    mAdvanced(serverFeatures ? serverFeatures->haveAdvancedBuySell() : false)
+    mAdvanced(Net::getNetworkType() != ServerType::TMWATHENA)
 {
     init();
 }
 
 #ifdef TMWA_SUPPORT
-BuyDialog::BuyDialog(std::string nick) :
+BuyDialog::BuyDialog(const std::string &nick,
+                     const std::string &currency) :
     // TRANSLATORS: buy dialog name
     Window(_("Buy"), Modal_false, nullptr, "buy.xml"),
     ActionListener(),
@@ -235,6 +240,7 @@ BuyDialog::BuyDialog(std::string nick) :
         this, "namefilter", true)),
     mFilterLabel(nullptr),
     mNick(nick),
+    mCurrency(currency),
     mNpcId(fromInt(Nick, BeingId)),
     mMoney(0),
     mAmountItems(0),
@@ -245,7 +251,8 @@ BuyDialog::BuyDialog(std::string nick) :
 }
 #endif  // TMWA_SUPPORT
 
-BuyDialog::BuyDialog(const Being *const being) :
+BuyDialog::BuyDialog(const Being *const being,
+                     const std::string &currency) :
     // TRANSLATORS: buy dialog name
     Window(_("Buy"), Modal_false, nullptr, "buy.xml"),
     ActionListener(),
@@ -256,7 +263,8 @@ BuyDialog::BuyDialog(const Being *const being) :
     mFilterTextField(new TextField(this, "", LoseFocusOnTab_true,
         this, "namefilter", true)),
     mFilterLabel(nullptr),
-    mNick(being ? being->getName() : std::string()),
+    mNick(being != nullptr ? being->getName() : std::string()),
+    mCurrency(currency),
     mNpcId(fromInt(Vending, BeingId)),
     mMoney(0),
     mAmountItems(0),
@@ -276,20 +284,20 @@ void BuyDialog::init()
     setMinHeight(220);
     setDefaultSize(260, 230, ImagePosition::CENTER);
 
-    // reset advance flag for personal shops and cash shop
-    if (mAdvanced && (
 #ifdef TMWA_SUPPORT
-        mNpcId == fromInt(Nick, BeingId) ||
-#endif  // TMWA_SUPPORT
-        mNpcId == fromInt(Cash, BeingId)))
+    // reset advance flag for personal shops
+    if (mAdvanced &&
+        mNpcId == fromInt(Nick, BeingId))
     {
         mAdvanced = false;
     }
+#endif  // TMWA_SUPPORT
 
-    if (setupWindow)
+    if (setupWindow != nullptr)
         setupWindow->registerWindowForReset(this);
 
-    mShopItems = new ShopItems;
+    mShopItems = new ShopItems(false,
+        mCurrency);
 
     CREATEWIDGETV(mShopItemList, ShopListBox, this,
         mShopItems, mShopItems, ShopListBoxType::Unknown);
@@ -368,7 +376,7 @@ void BuyDialog::init()
     placer(0, 6, mAmountLabel, 2);
     placer(2, 6, mAmountField, 2);
     placer(0, 7, mMoneyLabel, 8);
-    if (mSortDropDown)
+    if (mSortDropDown != nullptr)
     {
         placer(0, 8, mSortDropDown, 2);
     }
@@ -401,14 +409,17 @@ void BuyDialog::init()
     instances.push_back(this);
     setVisible(Visible_true);
 
-    if (mSortDropDown)
+    if (mSortDropDown != nullptr)
         mSortDropDown->setSelected(config.getIntValue("buySortOrder"));
 }
 
 BuyDialog::~BuyDialog()
 {
     delete2(mShopItems);
+    delete2(mSortModel);
     instances.remove(this);
+    if (buySellHandler != nullptr)
+        buySellHandler->cleanDialogReference(this);
 }
 
 void BuyDialog::setMoney(const int amount)
@@ -448,7 +459,7 @@ ShopItem *BuyDialog::addItem(const int id,
 
 void BuyDialog::sort()
 {
-    if (mSortDropDown && mShopItems)
+    if ((mSortDropDown != nullptr) && (mShopItems != nullptr))
     {
         std::vector<ShopItem*> &items = mShopItems->items();
         switch (mSortDropDown->getSelected())
@@ -514,7 +525,7 @@ void BuyDialog::action(const ActionEvent &event)
     else if (eventId == "sort")
     {
         sort();
-        if (mSortDropDown)
+        if (mSortDropDown != nullptr)
             config.setValue("buySortOrder", mSortDropDown->getSelected());
         return;
     }
@@ -565,7 +576,7 @@ void BuyDialog::action(const ActionEvent &event)
     else if (eventId == "buy" && mAmountItems > 0 && mAmountItems <= mMaxItems)
     {
         ShopItem *const item = mShopItems->at(selectedItem);
-        if (!item)
+        if (item == nullptr)
             return;
         if (mNpcId == fromInt(Items, BeingId))
         {
@@ -576,7 +587,7 @@ void BuyDialog::action(const ActionEvent &event)
 #ifdef TMWA_SUPPORT
         else if (mNpcId == fromInt(Nick, BeingId))
         {
-            if (tradeWindow)
+            if (tradeWindow != nullptr)
             {
                 buySellHandler->sendBuyRequest(mNick,
                     item, mAmountItems);
@@ -589,7 +600,7 @@ void BuyDialog::action(const ActionEvent &event)
         {
             item->increaseUsedQuantity(mAmountItems);
             item->update();
-            if (mConfirmButton)
+            if (mConfirmButton != nullptr)
                 mConfirmButton->setEnabled(true);
         }
 #ifdef TMWA_SUPPORT
@@ -602,7 +613,7 @@ void BuyDialog::action(const ActionEvent &event)
             {
                 item->increaseUsedQuantity(mAmountItems);
                 item->update();
-                if (mConfirmButton)
+                if (mConfirmButton != nullptr)
                     mConfirmButton->setEnabled(true);
             }
             else if (mNpcId == fromInt(Market, BeingId))
@@ -645,12 +656,16 @@ void BuyDialog::action(const ActionEvent &event)
             const Being *const being = actorManager->findBeingByName(
                 mNick,
                 ActorType::Player);
-            if (being)
+            if (being != nullptr)
             {
                 vendingHandler->buyItems(being,
                     items);
             }
         }
+        else if (mNpcId == fromInt(Cash, BeingId))
+        {
+            cashShopHandler->buyItems(0, items);
+        }
         else
         {
             npcHandler->buyItems(items);
@@ -665,7 +680,7 @@ void BuyDialog::updateSlider(const int selectedItem)
     // that can be bought
     mMaxItems -= mAmountItems;
     const ShopItem *const item = mShopItems->at(selectedItem);
-    if (item)
+    if (item != nullptr)
         setMoney(mMoney - mAmountItems * item->getPrice());
     else
         setMoney(mMoney);
@@ -696,14 +711,14 @@ void BuyDialog::updateButtonsAndLabels()
     if (selectedItem > -1)
     {
         const ShopItem *const item = mShopItems->at(selectedItem);
-        if (item)
+        if (item != nullptr)
         {
             const int itemPrice = item->getPrice();
 
             // Calculate how many the player can afford
             if (mNpcId == fromInt(Items, BeingId))
                 mMaxItems = 100;
-            else if (itemPrice)
+            else if (itemPrice != 0)
                 mMaxItems = mMoney / itemPrice;
             else
                 mMaxItems = 1;
@@ -732,15 +747,15 @@ void BuyDialog::updateButtonsAndLabels()
     mQuantityLabel->setCaption(strprintf("%d / %d", mAmountItems, mMaxItems));
     // TRANSLATORS: buy dialog label
     mMoneyLabel->setCaption(strprintf(_("Price: %s / Total: %s"),
-        Units::formatCurrency(price).c_str(),
-        Units::formatCurrency(mMoney - price).c_str()));
+        UnitsDb::formatCurrency(mCurrency, price).c_str(),
+        UnitsDb::formatCurrency(mCurrency, mMoney - price).c_str()));
 }
 
 void BuyDialog::setVisible(Visible visible)
 {
     Window::setVisible(visible);
 
-    if (visible == Visible_true && mShopItemList)
+    if (visible == Visible_true && (mShopItemList != nullptr))
         mShopItemList->requestFocus();
     else
         scheduleDelete();
@@ -750,7 +765,7 @@ void BuyDialog::closeAll()
 {
     FOR_EACH (DialogList::const_iterator, it, instances)
     {
-        if (*it)
+        if (*it != nullptr)
             (*it)->close();
     }
 }
@@ -763,7 +778,7 @@ void BuyDialog::applyNameFilter(const std::string &filter)
     FOR_EACH (std::vector<ShopItem*>::iterator, it, items)
     {
         ShopItem *const item = *it;
-        if (!item)
+        if (item == nullptr)
             continue;
         std::string name = item->getName();
         toLower(name);
