@@ -34,8 +34,12 @@
 #include "utils/delete2.h"
 #include "utils/gettext.h"
 
+#include "utils/translation/podict.h"
+
 #include "resources/imageset.h"
 
+#include "resources/db/textdb.h"
+
 #include "resources/image/image.h"
 
 #include "debug.h"
@@ -64,12 +68,16 @@ EmoteWindow::EmoteWindow() :
     mFontPage(CREATEWIDGETR(ListBox, this, mFontModel, "")),
     mScrollFontPage(new ScrollArea(this, mFontPage, Opaque_false,
         "fontpage.xml")),
+    mTextModel(new NamesModel),
+    mTextPage(CREATEWIDGETR(ListBox, this, mTextModel, "")),
+    mScrollTextPage(new ScrollArea(this, mTextPage, Opaque_false,
+        "textpage.xml")),
     mImageSet(Theme::getImageSetFromThemeXml("emotetabs.xml", "", 17, 16))
 {
     setShowTitle(false);
     setResizable(true);
 
-    if (setupWindow)
+    if (setupWindow != nullptr)
         setupWindow->registerWindowForReset(this);
 
     addMouseListener(this);
@@ -94,16 +102,20 @@ void EmoteWindow::postInit()
     mScrollColorPage->setHorizontalScrollPolicy(ScrollArea::SHOW_NEVER);
     mScrollFontPage->setVerticalScrollPolicy(ScrollArea::SHOW_NEVER);
     mScrollFontPage->setHorizontalScrollPolicy(ScrollArea::SHOW_NEVER);
+    mScrollTextPage->setVerticalScrollPolicy(ScrollArea::SHOW_NEVER);
+    mScrollTextPage->setHorizontalScrollPolicy(ScrollArea::SHOW_NEVER);
 
     mFontModel->fillFromArray(&fontSizeList[0], fontSizeListSize);
-    mFontPage->setCenter(true);
 
-    if (mImageSet && mImageSet->size() >= 3)
+    mFontPage->setCenter(true);
+    mTextPage->setCenter(true);
+
+    if ((mImageSet != nullptr) && mImageSet->size() >= 3)
     {
         for (int f = 0; f < 3; f ++)
         {
             Image *const image = mImageSet->get(f);
-            if (image)
+            if (image != nullptr)
                 image->incRef();
         }
 
@@ -120,10 +132,13 @@ void EmoteWindow::postInit()
         // TRANSLATORS: emotes tab name
         mTabs->addTab(_("Fonts"), mScrollFontPage);
     }
+    // TRANSLATORS: emotes tab name
+    mTabs->addTab(_("T"), mScrollTextPage);
 
     mEmotePage->setActionEventId("emote");
     mColorPage->setActionEventId("color");
     mFontPage->setActionEventId("font");
+    mTextPage->setActionEventId("text");
 }
 
 EmoteWindow::~EmoteWindow()
@@ -137,7 +152,10 @@ EmoteWindow::~EmoteWindow()
     delete2(mFontPage);
     delete2(mFontModel);
     delete2(mScrollFontPage);
-    if (mImageSet)
+    delete2(mTextPage);
+    delete2(mTextModel);
+    delete2(mScrollTextPage);
+    if (mImageSet != nullptr)
     {
         mImageSet->decRef();
         mImageSet = nullptr;
@@ -147,6 +165,15 @@ EmoteWindow::~EmoteWindow()
 void EmoteWindow::show()
 {
     setVisible(Visible_true);
+    if (dictionary != nullptr)
+    {
+        mTextModel->clear();
+        const std::vector<std::string> &texts = TextDb::getTexts();
+        FOR_EACH (StringVectCIter, it, texts)
+        {
+            mTextModel->add(dictionary->getStr(*it));
+        }
+    }
 }
 
 void EmoteWindow::hide()
@@ -186,6 +213,11 @@ std::string EmoteWindow::getSelectedColor() const
     return std::string("##").append(&chr[0]);
 }
 
+int EmoteWindow::getSelectedTextIndex() const
+{
+    return mTextPage->getSelected();
+}
+
 void EmoteWindow::clearColor()
 {
     mColorPage->resetAction();
@@ -198,7 +230,7 @@ std::string EmoteWindow::getSelectedFont() const
     if (index < 0)
         return std::string();
 
-    if (!index)
+    if (index == 0)
         return "##b";
     else
         return "##B";
@@ -210,11 +242,18 @@ void EmoteWindow::clearFont()
     setVisible(Visible_false);
 }
 
+void EmoteWindow::clearText()
+{
+    mTextPage->setSelected(-1);
+    setVisible(Visible_false);
+}
+
 void EmoteWindow::addListeners(ActionListener *const listener)
 {
     mEmotePage->addActionListener(listener);
     mColorPage->addActionListener(listener);
     mFontPage->addActionListener(listener);
+    mTextPage->addActionListener(listener);
 }
 
 void EmoteWindow::widgetResized(const Event &event)
