@@ -79,7 +79,10 @@ class EquipmentWindow final : public Window,
         void mousePressed(MouseEvent& event) override final;
 
         const Item* getEquipment(const int i) const A_WARN_UNUSED
-        { return mEquipment ? mEquipment->getEquipment(i) : nullptr; }
+        {
+            return mEquipment != nullptr ?
+                mEquipment->getEquipment(i) : nullptr;
+        }
 
         void setBeing(Being *const being);
 
@@ -114,13 +117,13 @@ class EquipmentWindow final : public Window,
 
         void addBox(const int idx, int x, int y, const int imageIndex);
 
-        void loadWindow(const XmlNodePtrConst windowNode);
+        void loadWindow(XmlNodeConstPtrConst windowNode);
 
-        void loadPage(const XmlNodePtr node);
+        void loadPage(XmlNodeConstPtr node);
 
-        void loadPlayerBox(const XmlNodePtr playerBoxNode, const int page);
+        void loadPlayerBox(XmlNodeConstPtr playerBoxNode, const int page);
 
-        void loadSlot(const XmlNodePtr slotNode,
+        void loadSlot(XmlNodeConstPtr slotNode,
                       const ImageSet *const imageset,
                       const int page);
 
