@@ -26,20 +26,22 @@
 
 #include "enums/gui/layouttype.h"
 
-#include "input/inputmanager.h"
+#include "fs/paths.h"
+
+#include "fs/virtfs/tools.h"
 
 #include "gui/gui.h"
 
 #include "gui/windows/setupwindow.h"
 
 #include "gui/widgets/button.h"
-#include "gui/widgets/browserbox.h"
+#include "gui/widgets/staticbrowserbox.h"
 #include "gui/widgets/layout.h"
 #include "gui/widgets/scrollarea.h"
 
+#include "input/inputmanager.h"
+
 #include "utils/gettext.h"
-#include "utils/files.h"
-#include "utils/paths.h"
 #include "utils/process.h"
 
 #include "utils/translation/podict.h"
@@ -56,7 +58,7 @@ HelpWindow::HelpWindow() :
     ActionListener(),
     // TRANSLATORS: help window. button.
     mDYKButton(new Button(this, _("Did you know..."), "DYK", this)),
-    mBrowserBox(new BrowserBox(this, BrowserBox::AUTO_SIZE, Opaque_true,
+    mBrowserBox(new StaticBrowserBox(this, Opaque_true,
         "browserbox.xml")),
     mScrollArea(new ScrollArea(this, mBrowserBox,
         Opaque_true, "help_background.xml")),
@@ -70,7 +72,7 @@ HelpWindow::HelpWindow() :
     setResizable(true);
     setStickyButtonLock(true);
 
-    if (setupWindow)
+    if (setupWindow != nullptr)
         setupWindow->registerWindowForReset(this);
 
     setDefaultSize(500, 400, ImagePosition::CENTER);
@@ -78,7 +80,7 @@ HelpWindow::HelpWindow() :
     mBrowserBox->setOpaque(Opaque_false);
 
     mBrowserBox->setLinkHandler(this);
-    if (gui)
+    if (gui != nullptr)
         mBrowserBox->setFont(gui->getHelpFont());
     mBrowserBox->setProcessVars(true);
     mBrowserBox->setEnableImages(true);
@@ -108,7 +110,7 @@ void HelpWindow::handleLink(const std::string &link,
 {
     if (!strStartWith(link, "http://") && !strStartWith(link, "https://"))
     {
-        std::string helpFile = link;
+        const std::string &helpFile = link;
         loadHelp(helpFile);
     }
     else
@@ -126,6 +128,7 @@ void HelpWindow::loadHelp(const std::string &helpFile)
     loadFile(helpFile);
     loadFile("footer");
     mScrollArea->setVerticalScrollAmount(0);
+    mBrowserBox->updateHeight();
     setVisible(Visible_true);
 }
 
@@ -136,6 +139,7 @@ void HelpWindow::loadHelpSimple(const std::string &helpFile)
     mBrowserBox->clearRows();
     loadFile(helpFile);
     mScrollArea->setVerticalScrollAmount(0);
+    mBrowserBox->updateHeight();
     setVisible(Visible_true);
 }
 
@@ -147,7 +151,7 @@ void HelpWindow::loadFile(std::string file)
         helpPath = paths.getStringValue("help");
 
     StringVect lines;
-    TranslationManager::translateFile(helpPath.append(file).append(".txt"),
+    TranslationManager::translateFile(pathJoin(helpPath, file).append(".txt"),
         translator, lines);
 
     for (size_t i = 0, sz = lines.size(); i < sz; ++i)
@@ -161,11 +165,11 @@ void HelpWindow::loadTags()
         helpPath = paths.getStringValue("tags");
 
     StringVect filesVect;
-    Files::getFilesInDir(helpPath, filesVect, ".idx");
+    VirtFs::getFilesInDir(helpPath, filesVect, ".idx");
     FOR_EACH (StringVectCIter, itVect, filesVect)
     {
         StringVect lines;
-        Files::loadTextFile(*itVect, lines);
+        VirtFs::loadTextFile(*itVect, lines);
         FOR_EACH (StringVectCIter, it, lines)
         {
             const std::string &str = *it;
@@ -194,7 +198,7 @@ void HelpWindow::search(const std::string &text0)
         }
         else
         {
-            if (!translator)
+            if (translator == nullptr)
                 return;
             mBrowserBox->clearRows();
             loadFile("header");
@@ -207,6 +211,7 @@ void HelpWindow::search(const std::string &text0)
             }
             loadFile("footer");
             mScrollArea->setVerticalScrollAmount(0);
+            mBrowserBox->updateHeight();
             setVisible(Visible_true);
         }
     }
