@@ -25,7 +25,7 @@
 #include "client.h"
 #include "configuration.h"
 
-#include "listeners/openurllistener.h"
+#include "fs/paths.h"
 
 #include "gui/models/updatelistmodel.h"
 #include "gui/models/updatetypemodel.h"
@@ -40,18 +40,19 @@
 #include "gui/widgets/passwordfield.h"
 #include "gui/widgets/layoutcell.h"
 
+#include "listeners/openurllistener.h"
+
 #include "net/charserverhandler.h"
 #include "net/logindata.h"
 #include "net/loginhandler.h"
 #include "net/updatetypeoperators.h"
 
 #include "utils/delete2.h"
-#include "utils/paths.h"
 
 #include "debug.h"
 
-std::string LoginDialog::savedPassword("");
-std::string LoginDialog::savedPasswordKey("");
+std::string LoginDialog::savedPassword;
+std::string LoginDialog::savedPasswordKey;
 
 namespace
 {
@@ -84,7 +85,8 @@ LoginDialog::LoginDialog(LoginData &data,
     mRegisterButton(new Button(this, _("Register"), "register", this)),
     // TRANSLATORS: login dialog checkbox
     mCustomUpdateHost(new CheckBox(this, _("Custom update host"),
-        mLoginData->updateType & UpdateType::Custom, this, "customhost")),
+        (mLoginData->updateType & UpdateType::Custom) != 0,
+        this, "customhost")),
     mUpdateHostText(new TextField(this, serverConfig.getValue(
         "customUpdateHost", ""))),
     mUpdateListModel(nullptr),
@@ -95,7 +97,7 @@ LoginDialog::LoginDialog(LoginData &data,
     setCloseButton(true);
     setWindowName("Login");
 
-    if (charServerHandler)
+    if (charServerHandler != nullptr)
         charServerHandler->clear();
 
     mergeUpdateHosts();
@@ -154,7 +156,7 @@ LoginDialog::LoginDialog(LoginData &data,
     place(0, 6, mUpdateTypeLabel, 1);
     place(1, 6, mUpdateTypeDropDown, 8);
     int n = 7;
-    if (mUpdateHostDropDown)
+    if (mUpdateHostDropDown != nullptr)
     {
         place(0, 7, mUpdateHostDropDown, 9);
         n += 1;
@@ -175,7 +177,7 @@ void LoginDialog::postInit()
     setVisible(Visible_true);
 
     const int h = 200;
-    if (mUpdateHostDropDown)
+    if (mUpdateHostDropDown != nullptr)
         setContentSize(310, 250);
     setContentSize(310, h);
 #ifdef ANDROID
@@ -195,7 +197,7 @@ void LoginDialog::postInit()
         mPassField->requestFocus();
 
     mLoginButton->setEnabled(canSubmit());
-    if (loginHandler)
+    if (loginHandler != nullptr)
     {
         mRegisterButton->setEnabled(loginHandler->isRegistrationEnabled()
             || !mLoginData->registerUrl.empty());
@@ -208,9 +210,9 @@ void LoginDialog::postInit()
 
 LoginDialog::~LoginDialog()
 {
-    if (mUpdateTypeDropDown)
+    if (mUpdateTypeDropDown != nullptr)
         mUpdateTypeDropDown->hideDrop(false);
-    if (mUpdateHostDropDown)
+    if (mUpdateHostDropDown != nullptr)
         mUpdateHostDropDown->hideDrop(false);
 
     delete2(mUpdateTypeModel);
@@ -328,7 +330,7 @@ void LoginDialog::prepareUpdate()
     else
     {
         std::string str;
-        if (mUpdateHostDropDown)
+        if (mUpdateHostDropDown != nullptr)
         {
             const int sel = mUpdateHostDropDown->getSelected();
             if (sel >= 0)
