@@ -36,7 +36,6 @@
 
 #include "gui/windows/setupwindow.h"
 
-#include "gui/widgets/browserbox.h"
 #include "gui/widgets/button.h"
 #include "gui/widgets/containerplacer.h"
 #include "gui/widgets/createwidget.h"
@@ -44,17 +43,16 @@
 #include "gui/widgets/extendedlistbox.h"
 #include "gui/widgets/itemlinkhandler.h"
 #include "gui/widgets/scrollarea.h"
+#include "gui/widgets/staticbrowserbox.h"
 
 #include "utils/delete2.h"
-#include "utils/dtor.h"
 #include "utils/gettext.h"
 
-#include "utils/translation/podict.h"
-
-#include "resources/beingcommon.h"
 #include "resources/questeffect.h"
 #include "resources/questitem.h"
 
+#include "resources/db/questdb.h"
+
 #include "resources/map/map.h"
 
 #include "debug.h"
@@ -72,7 +70,7 @@ QuestsWindow::QuestsWindow() :
         fromBool(getOptionBool("showlistbackground"), Opaque),
         "quests_list_background.xml")),
     mItemLinkHandler(new ItemLinkHandler),
-    mText(new BrowserBox(this, BrowserBox::AUTO_WRAP, Opaque_true,
+    mText(new StaticBrowserBox(this, Opaque_true,
         "browserbox.xml")),
     mTextScrollArea(new ScrollArea(this, mText,
         fromBool(getOptionBool("showtextbackground"), Opaque),
@@ -81,12 +79,13 @@ QuestsWindow::QuestsWindow() :
     mCloseButton(new Button(this, _("Close"), "close", this)),
     mCompleteIcon(Theme::getImageFromThemeXml("complete_icon.xml", "")),
     mIncompleteIcon(Theme::getImageFromThemeXml("incomplete_icon.xml", "")),
-    mVars(),
-    mQuests(),
-    mAllEffects(),
     mMapEffects(),
+    mVars(nullptr),
+    mQuests(nullptr),
+    mAllEffects(nullptr),
     mNpcEffects(),
     mQuestLinks(),
+    mQuestReverseLinks(),
     mNewQuestEffectId(paths.getIntValue("newQuestEffectId")),
     mCompleteQuestEffectId(paths.getIntValue("completeQuestEffectId")),
     mMap(nullptr)
@@ -101,7 +100,7 @@ QuestsWindow::QuestsWindow() :
     setMinWidth(310);
     setMinHeight(220);
 
-    if (setupWindow)
+    if (setupWindow != nullptr)
         setupWindow->registerWindowForReset(this);
 
     mQuestsListBox->setActionEventId("select");
@@ -112,7 +111,7 @@ QuestsWindow::QuestsWindow() :
     mText->setLinkHandler(mItemLinkHandler);
     mTextScrollArea->setHorizontalScrollPolicy(ScrollArea::SHOW_NEVER);
     mQuestsListBox->setWidth(500);
-    if (!gui || gui->getNpcFont()->getHeight() < 20)
+    if ((gui == nullptr) || gui->getNpcFont()->getHeight() < 20)
         mQuestsListBox->setRowHeight(20);
     else
         mQuestsListBox->setRowHeight(gui->getNpcFont()->getHeight());
@@ -129,199 +128,33 @@ QuestsWindow::QuestsWindow() :
 
     loadWindowState();
     enableVisibleSound(true);
-    loadXmlFile(paths.getStringValue("questsFile"), SkipError_false);
-    loadXmlFile(paths.getStringValue("questsPatchFile"), SkipError_true);
-    loadXmlDir("questsPatchDir", loadXmlFile);
+    QuestDb::load();
+    mVars = QuestDb::getVars();
+    mQuests = QuestDb::getQuests();
+    mAllEffects = QuestDb::getAllEffects();
 }
 
 QuestsWindow::~QuestsWindow()
 {
     delete2(mQuestsModel);
 
-    for (std::map<int, std::vector<QuestItem*> >::iterator it
-         = mQuests.begin(), it_end = mQuests.end(); it != it_end; ++ it)
-    {
-        std::vector<QuestItem*> &quests = (*it).second;
-        for (std::vector<QuestItem*>::iterator it2 = quests.begin(),
-             it2_end = quests.end(); it2 != it2_end; ++ it2)
-        {
-            delete *it2;
-        }
-    }
-    delete_all(mAllEffects);
-    mAllEffects.clear();
+    QuestDb::unload();
 
     delete2(mItemLinkHandler);
-    mQuests.clear();
     mQuestLinks.clear();
-    if (mCompleteIcon)
+    mQuestReverseLinks.clear();
+    if (mCompleteIcon != nullptr)
     {
         mCompleteIcon->decRef();
         mCompleteIcon = nullptr;
     }
-    if (mIncompleteIcon)
+    if (mIncompleteIcon != nullptr)
     {
         mIncompleteIcon->decRef();
         mIncompleteIcon = nullptr;
     }
 }
 
-void QuestsWindow::loadXmlFile(const std::string &fileName,
-                               const SkipError skipError)
-{
-    XML::Document doc(fileName,
-        UseResman_true,
-        skipError);
-    const XmlNodePtrConst root = doc.rootNode();
-    if (!root)
-        return;
-
-    for_each_xml_child_node(varNode, root)
-    {
-        if (xmlNameEqual(varNode, "include"))
-        {
-            const std::string name = XML::getProperty(varNode, "name", "");
-            if (!name.empty())
-                loadXmlFile(name, skipError);
-            continue;
-        }
-        else if (xmlNameEqual(varNode, "var"))
-        {
-            const int id = XML::getProperty(varNode, "id", 0);
-            if (id < 0)
-                continue;
-            mVars[id] = QuestVar();
-            for_each_xml_child_node(questNode, varNode)
-            {
-                if (xmlNameEqual(questNode, "quest"))
-                    loadQuest(id, questNode);
-                else if (xmlNameEqual(questNode, "effect"))
-                    loadEffect(id, questNode);
-            }
-        }
-    }
-}
-
-void QuestsWindow::loadQuest(const int var, const XmlNodePtr node)
-{
-    if (!node)
-        return;
-    QuestItem *const quest = new QuestItem();
-    // TRANSLATORS: quests window quest name
-    quest->name = XML::langProperty(node, "name", _("unknown"));
-    quest->group = XML::getProperty(node, "group", "");
-    std::string incompleteStr = XML::getProperty(node, "incomplete", "");
-    std::string completeStr = XML::getProperty(node, "complete", "");
-    if (incompleteStr.empty() && completeStr.empty())
-    {
-        logger->log("complete flags incorrect");
-        delete quest;
-        return;
-    }
-    splitToIntSet(quest->incomplete, incompleteStr, ',');
-    splitToIntSet(quest->complete, completeStr, ',');
-    if (quest->incomplete.empty() && quest->complete.empty())
-    {
-        logger->log("complete flags incorrect");
-        delete quest;
-        return;
-    }
-    if (quest->incomplete.empty() || quest->complete.empty())
-        quest->broken = true;
-
-    for_each_xml_child_node(dataNode, node)
-    {
-        if (!xmlTypeEqual(dataNode, XML_ELEMENT_NODE))
-            continue;
-        const char *const data = reinterpret_cast<const char*>(
-            XmlNodeGetContent(dataNode));
-        if (!data)
-            continue;
-        std::string str = translator->getStr(data);
-
-        for (int f = 1; f < 100; f ++)
-        {
-            const std::string key = strprintf("text%d", f);
-            const std::string val = XML::getProperty(dataNode,
-                key.c_str(),
-                "");
-            if (val.empty())
-                break;
-            const std::string param = strprintf("{@@%d}", f);
-            replaceAll(str, param, val);
-        }
-        replaceItemLinks(str);
-        if (xmlNameEqual(dataNode, "text"))
-        {
-            quest->texts.push_back(QuestItemText(str,
-                QuestType::TEXT,
-                std::string(),
-                std::string()));
-        }
-        else if (xmlNameEqual(dataNode, "name"))
-        {
-            quest->texts.push_back(QuestItemText(str,
-                QuestType::NAME,
-                std::string(),
-                std::string()));
-        }
-        else if (xmlNameEqual(dataNode, "reward"))
-        {
-            quest->texts.push_back(QuestItemText(str,
-                QuestType::REWARD,
-                std::string(),
-                std::string()));
-        }
-        else if (xmlNameEqual(dataNode, "questgiver") ||
-                 xmlNameEqual(dataNode, "giver"))
-        {
-            quest->texts.push_back(QuestItemText(str,
-                QuestType::GIVER,
-                std::string(),
-                std::string()));
-        }
-        else if (xmlNameEqual(dataNode, "coordinates"))
-        {
-            const std::string str1 = toString(XML::getIntProperty(
-                dataNode, "x", 0, 1, 1000));
-            const std::string str2 = toString(XML::getIntProperty(
-                dataNode, "y", 0, 1, 1000));
-            quest->texts.push_back(QuestItemText(str,
-                QuestType::COORDINATES,
-                str1,
-                str2));
-        }
-        else if (xmlNameEqual(dataNode, "npc"))
-        {
-            quest->texts.push_back(QuestItemText(str,
-                QuestType::NPC,
-                std::string(),
-                std::string()));
-        }
-    }
-    quest->var = var;
-    mQuests[var].push_back(quest);
-}
-
-void QuestsWindow::loadEffect(const int var, const XmlNodePtr node)
-{
-    QuestEffect *const effect = new QuestEffect;
-    effect->map = XML::getProperty(node, "map", "");
-    effect->id = fromInt(XML::getProperty(node, "npc", -1), BeingTypeId);
-    effect->effectId = XML::getProperty(node, "effect", -1);
-    const std::string values = XML::getProperty(node, "value", "");
-    splitToIntSet(effect->values, values, ',');
-
-    if (effect->map.empty() || effect->id == BeingTypeId_negOne
-        || effect->effectId == -1 || values.empty())
-    {
-        delete effect;
-        return;
-    }
-    effect->var = var;
-    mAllEffects.push_back(effect);
-}
-
 void QuestsWindow::action(const ActionEvent &event)
 {
     const std::string &eventId = event.getId();
@@ -344,13 +177,14 @@ void QuestsWindow::updateQuest(const int var,
                                const int val3,
                                const int time1)
 {
-    mVars[var] = QuestVar(val1, val2, val3, time1);
+    (*mVars)[var] = QuestVar(val1, val2, val3, time1);
 }
 
 void QuestsWindow::rebuild(const bool playSound)
 {
     mQuestsModel->clear();
     mQuestLinks.clear();
+    mQuestReverseLinks.clear();
     StringVect &names = mQuestsModel->getNames();
     std::vector<Image*> &images = mQuestsModel->getImages();
     std::vector<QuestItem*> complete;
@@ -359,14 +193,14 @@ void QuestsWindow::rebuild(const bool playSound)
     int updatedQuest = -1;
     int newCompleteStatus = -1;
 
-    FOR_EACH (NpcQuestVarMapCIter, it, mVars)
+    FOR_EACHP (NpcQuestVarMapCIter, it, mVars)
     {
         const int var = (*it).first;
         const QuestVar &val = (*it).second;
-        const std::vector<QuestItem*> &quests = mQuests[var];
+        const std::vector<QuestItem*> &quests = (*mQuests)[var];
         FOR_EACH (std::vector<QuestItem*>::const_iterator, it2, quests)
         {
-            if (!*it2)
+            if (*it2 == nullptr)
                 continue;
             QuestItem *const quest = *it2;
             // complete quest
@@ -402,8 +236,9 @@ void QuestsWindow::rebuild(const bool playSound)
         }
         quest->completeFlag = 1;
         mQuestLinks.push_back(quest);
+        mQuestReverseLinks[quest->var] = k;
         names.push_back(quest->name);
-        if (mCompleteIcon)
+        if (mCompleteIcon != nullptr)
         {
             mCompleteIcon->incRef();
             images.push_back(mCompleteIcon);
@@ -425,8 +260,9 @@ void QuestsWindow::rebuild(const bool playSound)
         }
         quest->completeFlag = 0;
         mQuestLinks.push_back(quest);
+        mQuestReverseLinks[quest->var] = k;
         names.push_back(quest->name);
-        if (mIncompleteIcon)
+        if (mIncompleteIcon != nullptr)
         {
             mIncompleteIcon->incRef();
             images.push_back(mIncompleteIcon);
@@ -449,7 +285,7 @@ void QuestsWindow::rebuild(const bool playSound)
     {
         mQuestsListBox->setSelected(updatedQuest);
         showQuest(mQuestLinks[updatedQuest]);
-        if (playSound && effectManager)
+        if (playSound && (effectManager != nullptr))
         {
             switch (newCompleteStatus)
             {
@@ -470,11 +306,11 @@ void QuestsWindow::rebuild(const bool playSound)
 
 void QuestsWindow::showQuest(const QuestItem *const quest)
 {
-    if (!quest || !translator)
+    if (quest == nullptr)
         return;
 
     const std::vector<QuestItemText> &texts = quest->texts;
-    const QuestVar &var = mVars[quest->var];
+    const QuestVar &var = (*mVars)[quest->var];
     const std::string var1 = toString(var.var1);
     const std::string var2 = toString(var.var2);
     const std::string var3 = toString(var.var3);
@@ -529,6 +365,7 @@ void QuestsWindow::showQuest(const QuestItem *const quest)
                 break;
         }
     }
+    mText->updateHeight();
 }
 
 void QuestsWindow::setMap(const Map *const map)
@@ -537,14 +374,14 @@ void QuestsWindow::setMap(const Map *const map)
     {
         mMap = map;
         mMapEffects.clear();
-        if (!mMap)
+        if (mMap == nullptr)
             return;
 
         const std::string name = mMap->getProperty("shortName");
-        FOR_EACH (std::vector<QuestEffect*>::const_iterator, it,  mAllEffects)
+        FOR_EACHP (std::vector<QuestEffect*>::const_iterator, it,  mAllEffects)
         {
             const QuestEffect *const effect = *it;
-            if (effect && name == effect->map)
+            if ((effect != nullptr) && name == effect->map)
                 mMapEffects.push_back(effect);
         }
         updateEffects();
@@ -560,18 +397,18 @@ void QuestsWindow::updateEffects()
               it,  mMapEffects)
     {
         const QuestEffect *const effect = *it;
-        if (effect)
+        if (effect != nullptr)
         {
-            const NpcQuestVarMapCIter varIt = mVars.find(effect->var);
-            if (varIt != mVars.end())
+            const NpcQuestVarMapCIter varIt = mVars->find(effect->var);
+            if (varIt != mVars->end())
             {
                 const std::set<int> &vals = effect->values;
-                if (vals.find(mVars[effect->var].var1) != vals.end())
+                if (vals.find((*mVars)[effect->var].var1) != vals.end())
                     mNpcEffects[effect->id] = effect;
             }
         }
     }
-    if (!actorManager)
+    if (actorManager == nullptr)
         return;
 
     std::set<BeingTypeId> removeEffects;
@@ -616,7 +453,7 @@ void QuestsWindow::updateEffects()
 
 void QuestsWindow::addEffect(Being *const being)
 {
-    if (!being)
+    if (being == nullptr)
         return;
     const BeingTypeId id = being->getSubType();
     const std::map<BeingTypeId, const QuestEffect*>::const_iterator
@@ -624,7 +461,22 @@ void QuestsWindow::addEffect(Being *const being)
     if (it != mNpcEffects.end())
     {
         const QuestEffect *const effect = (*it).second;
-        if (effect)
+        if (effect != nullptr)
             being->addSpecialEffect(effect->effectId);
     }
 }
+
+void QuestsWindow::selectQuest(const int varId)
+{
+    std::map<int, int>::const_iterator it = mQuestReverseLinks.find(varId);
+    if (it == mQuestReverseLinks.end())
+        return;
+    if (mVisible == Visible_false)
+        setVisible(Visible_true);
+    const int listPos = (*it).second;
+    if (listPos < 0)
+        return;
+    showQuest(mQuestLinks[listPos]);
+    mQuestsListBox->setSelected(listPos);
+    requestMoveToTop();
+}
