@@ -30,11 +30,14 @@
 
 #include "net/download.h"
 
+#include "fs/paths.h"
+
 #include "gui/widgets/checkbox.h"
 #include "gui/widgets/createwidget.h"
 #include "gui/widgets/desktop.h"
 #include "gui/windows/editserverdialog.h"
 #include "gui/windows/logindialog.h"
+#include "gui/windows/serverinfowindow.h"
 
 #include "gui/widgets/button.h"
 #include "gui/widgets/label.h"
@@ -43,9 +46,7 @@
 #include "gui/widgets/scrollarea.h"
 
 #include "utils/delete2.h"
-#include "utils/gettext.h"
 #include "utils/langs.h"
-#include "utils/paths.h"
 
 #include "debug.h"
 
@@ -114,6 +115,8 @@ ServerDialog::ServerDialog(ServerInfo *const serverInfo,
     mDeleteButton(new Button(this, _("Delete"), "remove", this)),
     // TRANSLATORS: servers dialog button
     mLoadButton(new Button(this, _("Load"), "load", this)),
+    // TRANSLATORS: servers dialog button
+    mInfoButton(new Button(this, _("Info"), "info", this)),
     mServersListModel(new ServersListModel(&mServers, this)),
     mServersList(CREATEWIDGETR(ServersListBox, this, mServersListModel)),
     mDownload(nullptr),
@@ -150,15 +153,16 @@ ServerDialog::ServerDialog(ServerInfo *const serverInfo,
     mServersList->addSelectionListener(this);
     usedScroll->setVerticalScrollAmount(0);
 
-    place(0, 0, usedScroll, 7, 5).setPadding(3);
-    place(0, 5, mDescription, 7);
-    place(0, 6, mPersistentIPCheckBox, 7);
-    place(0, 7, mAddEntryButton);
-    place(1, 7, mEditEntryButton);
-    place(2, 7, mLoadButton);
-    place(3, 7, mDeleteButton);
-    place(5, 7, mQuitButton);
-    place(6, 7, mConnectButton);
+    place(0, 0, usedScroll, 8, 5).setPadding(3);
+    place(0, 5, mDescription, 8);
+    place(0, 6, mPersistentIPCheckBox, 8);
+    place(0, 7, mInfoButton);
+    place(1, 7, mAddEntryButton);
+    place(2, 7, mEditEntryButton);
+    place(3, 7, mLoadButton);
+    place(4, 7, mDeleteButton);
+    place(6, 7, mQuitButton);
+    place(7, 7, mConnectButton);
 
     // Make sure the list has enough height
     getLayout().setRowHeight(0, 80);
@@ -198,7 +202,7 @@ void ServerDialog::postInit()
 
 ServerDialog::~ServerDialog()
 {
-    if (mDownload)
+    if (mDownload != nullptr)
     {
         mDownload->cancel();
         delete2(mDownload)
@@ -215,7 +219,7 @@ void ServerDialog::connectToSelectedServer()
     if (index < 0)
         return;
 
-    if (mDownload)
+    if (mDownload != nullptr)
         mDownload->cancel();
 
     mQuitButton->setEnabled(false);
@@ -235,15 +239,20 @@ void ServerDialog::connectToSelectedServer()
     mServerInfo->defaultHostName = server.defaultHostName;
     mServerInfo->save = true;
     mServerInfo->persistentIp = server.persistentIp;
+    mServerInfo->freeType = server.freeType;
     mServerInfo->updateMirrors = server.updateMirrors;
     mServerInfo->packetVersion = server.packetVersion;
     mServerInfo->updateHosts = server.updateHosts;
+    mServerInfo->freeSources = server.freeSources;
+    mServerInfo->nonFreeSources = server.nonFreeSources;
+    mServerInfo->docs = server.docs;
+    mServerInfo->serverUrl = server.serverUrl;
 
     settings.persistentIp = mServerInfo->persistentIp;
     settings.supportUrl = mServerInfo->supportUrl;
     settings.updateMirrors = mServerInfo->updateMirrors;
 
-    if (chatLogger)
+    if (chatLogger != nullptr)
         chatLogger->setServerName(mServerInfo->hostname);
 
     saveCustomServers(*mServerInfo);
@@ -253,7 +262,7 @@ void ServerDialog::connectToSelectedServer()
         if (mServerInfo->hostname != LoginDialog::savedPasswordKey)
         {
             LoginDialog::savedPassword.clear();
-            if (desktop)
+            if (desktop != nullptr)
                 desktop->reloadWallpaper();
         }
     }
@@ -303,6 +312,17 @@ void ServerDialog::action(const ActionEvent &event)
             saveCustomServers();
         }
     }
+    else if (eventId == "info")
+    {
+        const int index = mServersList->getSelected();
+        if (index >= 0)
+        {
+            if (serverInfoWindow != nullptr)
+                serverInfoWindow->scheduleDelete();
+            serverInfoWindow = CREATEWIDGETR(ServerInfoWindow,
+                mServers.at(index));
+        }
+    }
 }
 
 void ServerDialog::keyPressed(KeyEvent &event)
@@ -358,7 +378,7 @@ void ServerDialog::keyPressed(KeyEvent &event)
         mServersList->keyPressed(event);
 }
 
-void ServerDialog::valueChanged(const SelectionEvent &)
+void ServerDialog::valueChanged(const SelectionEvent &event A_UNUSED)
 {
     const int index = mServersList->getSelected();
     if (index == -1)
@@ -390,6 +410,7 @@ void ServerDialog::logic()
         MutexLocker tempLock(&mMutex);
         if (mDownloadStatus == ServerDialogDownloadStatus::COMPLETE)
         {
+            loadServers();
             mDownloadStatus = ServerDialogDownloadStatus::OVER;
             mDescription->setCaption(std::string());
         }
@@ -431,7 +452,7 @@ void ServerDialog::downloadServerList()
     if (listFile.empty())
         listFile = "http://manaplus.org/serverlist.xml";
 
-    if (mDownload)
+    if (mDownload != nullptr)
     {
         mDownload->cancel();
         delete2(mDownload)
@@ -439,7 +460,7 @@ void ServerDialog::downloadServerList()
 
     mDownload = new Net::Download(this, listFile,
         &downloadUpdate, false, false, true);
-    mDownload->setFile(std::string(mDir).append("/").append(
+    mDownload->setFile(pathJoin(mDir,
         branding.getStringValue("onlineServerFile")));
     if (!listFile2.empty())
         mDownload->addMirror(listFile2);
@@ -448,7 +469,7 @@ void ServerDialog::downloadServerList()
     config.setValue("serverslistupdate", getDateString());
 }
 
-static void loadHostsGroup(const XmlNodePtr node,
+static void loadHostsGroup(XmlNodeConstPtr node,
                            ServerInfo &server)
 {
     HostsGroup group;
@@ -458,8 +479,11 @@ static void loadHostsGroup(const XmlNodePtr node,
         _("Unknown"));
     for_each_xml_child_node(hostNode, node)
     {
-        if (!xmlNameEqual(hostNode, "host"))
+        if (!xmlNameEqual(hostNode, "host") ||
+            !XmlHaveChildContent(hostNode))
+        {
             continue;
+        }
         const std::string host = XmlChildContent(hostNode);
         if (host.empty())
             continue;
@@ -475,15 +499,53 @@ static void loadHostsGroup(const XmlNodePtr node,
         server.updateHosts.push_back(group);
 }
 
+static void loadServerSourcesList(XmlNodeConstPtr node,
+                                  std::vector<ServerUrlInfo> &list)
+{
+    for_each_xml_child_node(urlNode, node)
+    {
+        if (!xmlNameEqual(urlNode, "url") ||
+            !XmlHaveChildContent(urlNode))
+        {
+            continue;
+        }
+        const std::string name = XML::langProperty(urlNode,
+            "name",
+            "");
+        if (name.empty())
+            continue;
+        const std::string url = XmlChildContent(urlNode);
+        if (url.empty())
+            continue;
+        list.push_back(ServerUrlInfo(name, url));
+    }
+}
+
+static void loadServerSources(XmlNodeConstPtr node,
+                              ServerInfo &server)
+{
+    for_each_xml_child_node(subNode, node)
+    {
+        if (xmlNameEqual(subNode, "free"))
+        {
+            loadServerSourcesList(subNode, server.freeSources);
+        }
+        else if (xmlNameEqual(subNode, "nonfree"))
+        {
+            loadServerSourcesList(subNode, server.nonFreeSources);
+        }
+    }
+}
+
 void ServerDialog::loadServers(const bool addNew)
 {
-    XML::Document doc(std::string(mDir).append("/").append(
+    XML::Document doc(pathJoin(mDir,
         branding.getStringValue("onlineServerFile")),
-        UseResman_false,
+        UseVirtFs_false,
         SkipError_false);
-    const XmlNodePtr rootNode = doc.rootNode();
+    XmlNodeConstPtr rootNode = doc.rootNode();
 
-    if (!rootNode || !xmlNameEqual(rootNode, "serverlist"))
+    if ((rootNode == nullptr) || !xmlNameEqual(rootNode, "serverlist"))
     {
         logger->log1("Error loading server list!");
         return;
@@ -509,6 +571,9 @@ void ServerDialog::loadServers(const bool addNew)
             serverNode, "type", "unknown");
         ServerInfo server;
         server.type = ServerInfo::parseType(type);
+        const std::string licenseType = XML::getProperty(
+            serverNode, "licenseType", "notset");
+        server.freeType = ServerInfo::parseFreeType(licenseType);
 
         // Ignore unknown server types
         if (server.type == ServerType::UNKNOWN)
@@ -588,6 +653,10 @@ void ServerDialog::loadServers(const bool addNew)
                 {
                     server.updateMirrors.push_back(XmlChildContent(subNode));
                 }
+                else if (xmlNameEqual(subNode, "site"))
+                {
+                    server.serverUrl = XmlChildContent(subNode);
+                }
             }
             if (xmlNameEqual(subNode, "updates"))
             {
@@ -599,6 +668,14 @@ void ServerDialog::loadServers(const bool addNew)
                     // TRANSLATORS: default hosts group name
                     subNode, "name", _("default"));
             }
+            else if (xmlNameEqual(subNode, "sources"))
+            {
+                loadServerSources(subNode, server);
+            }
+            else if (xmlNameEqual(subNode, "docs"))
+            {
+                loadServerSourcesList(subNode, server.docs);
+            }
         }
 
         server.version.first = font->getWidth(version);
@@ -615,17 +692,22 @@ void ServerDialog::loadServers(const bool addNew)
                 // Use the name listed in the server list
                 mServers[i].name = server.name;
                 mServers[i].type = server.type;
+                mServers[i].freeType = server.freeType;
                 mServers[i].version = server.version;
                 mServers[i].description = server.description;
                 mServers[i].registerUrl = server.registerUrl;
                 mServers[i].onlineListUrl = server.onlineListUrl;
                 mServers[i].supportUrl = server.supportUrl;
+                mServers[i].serverUrl = server.serverUrl;
                 mServers[i].althostname = server.althostname;
                 mServers[i].persistentIp = server.persistentIp;
                 mServers[i].updateMirrors = server.updateMirrors;
                 mServers[i].defaultHostName = server.defaultHostName;
                 mServers[i].updateHosts = server.updateHosts;
                 mServers[i].packetVersion = server.packetVersion;
+                mServers[i].freeSources = server.freeSources;
+                mServers[i].nonFreeSources = server.nonFreeSources;
+                mServers[i].docs = server.docs;
                 mServersListModel->setVersionString(i, version);
                 found = true;
                 break;
@@ -661,7 +743,7 @@ void ServerDialog::loadCustomServers()
         server.hostname = config.getValue(hostKey, "");
         server.type = ServerInfo::parseType(config.getValue(typeKey, ""));
         server.persistentIp = config.getValue(
-            persistentIpKey, 0) ? true : false;
+            persistentIpKey, 0) != 0 ? true : false;
         server.packetVersion = config.getValue(packetVersionKey, 0);
 
         const int defaultPort = defaultPortForServerType(server.type);
@@ -745,13 +827,13 @@ int ServerDialog::downloadUpdate(void *ptr,
                                  size_t total,
                                  const size_t remaining)
 {
-    if (!ptr || status == DownloadStatus::Cancelled)
+    if ((ptr == nullptr) || status == DownloadStatus::Cancelled)
         return -1;
 
     ServerDialog *const sd = reinterpret_cast<ServerDialog*>(ptr);
     bool finished = false;
 
-    if (!sd->mDownload)
+    if (sd->mDownload == nullptr)
         return -1;
 
     if (status == DownloadStatus::Complete)
@@ -767,7 +849,7 @@ int ServerDialog::downloadUpdate(void *ptr,
     else
     {
         float progress = static_cast<float>(remaining);
-        if (total)
+        if (total != 0u)
             progress /= static_cast<float>(total);
 
         if (progress != progress || progress < 0.0F)
@@ -782,7 +864,6 @@ int ServerDialog::downloadUpdate(void *ptr,
 
     if (finished)
     {
-        sd->loadServers();
         MutexLocker lock1(&sd->mMutex);
         sd->mDownloadStatus = ServerDialogDownloadStatus::COMPLETE;
     }
@@ -808,7 +889,7 @@ bool ServerDialog::needUpdateServers() const
 
 void ServerDialog::close()
 {
-    if (mDownload)
+    if (mDownload != nullptr)
         mDownload->cancel();
     client->setState(State::FORCE_QUIT);
     Window::close();
