@@ -29,7 +29,12 @@
 
 #include "enums/gui/layouttype.h"
 
-#include "gui/widgets/browserbox.h"
+#include "fs/files.h"
+#include "fs/mkdir.h"
+#include "fs/paths.h"
+
+#include "fs/virtfs/fs.h"
+
 #include "gui/widgets/button.h"
 #include "gui/widgets/containerplacer.h"
 #include "gui/widgets/itemlinkhandler.h"
@@ -37,20 +42,15 @@
 #include "gui/widgets/layout.h"
 #include "gui/widgets/progressbar.h"
 #include "gui/widgets/scrollarea.h"
+#include "gui/widgets/staticbrowserbox.h"
 
 #include "net/download.h"
 #include "net/updatetypeoperators.h"
 
 #include "resources/db/moddb.h"
 
-#include "resources/resourcemanager/resourcemanager.h"
-
 #include "utils/delete2.h"
-#include "utils/files.h"
-#include "utils/physfstools.h"
 #include "utils/gettext.h"
-#include "utils/mkdir.h"
-#include "utils/paths.h"
 
 #include <sys/stat.h>
 
@@ -63,11 +63,11 @@ UpdaterWindow *updaterWindow = nullptr;
 const std::string xmlUpdateFile("resources.xml");
 const std::string txtUpdateFile("resources2.txt");
 const std::string updateServer2
-    ("http://download.evolonline.org/manaplus/updates/");
-const std::string updateServer3
     ("http://download.manaplus.org/manaplus/updates/");
-const std::string updateServer4
+const std::string updateServer3
     ("http://download2.manaplus.org/manaplus/updates/");
+const std::string updateServer4
+    ("http://download.evolonline.org/manaplus/updates/");
 const std::string updateServer5
     ("http://download3.manaplus.org/manaplus/updates/");
 
@@ -78,10 +78,10 @@ static std::vector<UpdateFile> loadXMLFile(const std::string &fileName,
                                            const bool loadMods)
 {
     std::vector<UpdateFile> files;
-    XML::Document doc(fileName, UseResman_false, SkipError_false);
-    const XmlNodePtrConst rootNode = doc.rootNode();
+    XML::Document doc(fileName, UseVirtFs_false, SkipError_false);
+    XmlNodeConstPtrConst rootNode = doc.rootNode();
 
-    if (!rootNode || !xmlNameEqual(rootNode, "updates"))
+    if ((rootNode == nullptr) || !xmlNameEqual(rootNode, "updates"))
     {
         logger->log("Error loading update file: %s", fileName.c_str());
         return files;
@@ -195,7 +195,7 @@ UpdaterWindow::UpdaterWindow(const std::string &restrict updateHost,
     mProgressBar(new ProgressBar(this, 0.0, 310, 0,
         ProgressColorId::PROG_UPDATE,
         "updateprogressbar.xml", "updateprogressbar_fill.xml")),
-    mBrowserBox(new BrowserBox(this, BrowserBox::AUTO_SIZE, Opaque_true,
+    mBrowserBox(new StaticBrowserBox(this, Opaque_true,
         "browserbox.xml")),
     mScrollArea(new ScrollArea(this, mBrowserBox,
         Opaque_true, "update_background.xml")),
@@ -265,7 +265,7 @@ UpdaterWindow::~UpdaterWindow()
     if (mLoadUpdates)
         loadUpdates();
 
-    if (mDownload)
+    if (mDownload != nullptr)
     {
         mDownload->cancel();
 
@@ -297,7 +297,7 @@ void UpdaterWindow::enable()
 
     if (client->getState() != State::GAME)
     {
-        if (mUpdateType & UpdateType::Close)
+        if ((mUpdateType & UpdateType::Close) != 0)
             client->setState(State::LOAD_DATA);
     }
     else
@@ -316,7 +316,7 @@ void UpdaterWindow::action(const ActionEvent &event)
         // Skip the updating process
         if (mDownloadStatus != UpdateDownloadStatus::UPDATE_COMPLETE)
         {
-            if (mDownload)
+            if (mDownload != nullptr)
                 mDownload->cancel();
             mDownloadStatus = UpdateDownloadStatus::UPDATE_ERROR;
         }
@@ -345,7 +345,8 @@ void UpdaterWindow::keyPressed(KeyEvent &event)
              actionId == InputAction::GUI_SELECT2)
     {
         if (mDownloadStatus == UpdateDownloadStatus::UPDATE_COMPLETE ||
-            mDownloadStatus == UpdateDownloadStatus::UPDATE_ERROR)
+            mDownloadStatus == UpdateDownloadStatus::UPDATE_ERROR ||
+            mDownloadStatus == UpdateDownloadStatus::UPDATE_IDLE)
         {
             action(ActionEvent(nullptr, mPlayButton->getActionEventId()));
         }
@@ -358,7 +359,7 @@ void UpdaterWindow::keyPressed(KeyEvent &event)
 
 void UpdaterWindow::loadNews()
 {
-    if (!mMemoryBuffer)
+    if (mMemoryBuffer == nullptr)
     {
         logger->log1("Couldn't load news");
         return;
@@ -367,7 +368,7 @@ void UpdaterWindow::loadNews()
     // Reallocate and include terminating 0 character
     mMemoryBuffer = static_cast<char*>(realloc(
         mMemoryBuffer, mDownloadedBytes + 1));
-    if (!mMemoryBuffer)
+    if (mMemoryBuffer == nullptr)
     {
         logger->log1("Couldn't load news");
         return;
@@ -391,7 +392,7 @@ void UpdaterWindow::loadNews()
         {
             firstLine = false;
             const size_t i = line.find("##9 Latest client version: ##6");
-            if (!i)
+            if (i == 0u)
                 continue;
 
             if (file.is_open())
@@ -421,12 +422,13 @@ void UpdaterWindow::loadNews()
     mMemoryBuffer = nullptr;
     mDownloadedBytes = 0;
 
+    mBrowserBox->updateHeight();
     mScrollArea->setVerticalScrollAmount(0);
 }
 
 void UpdaterWindow::loadPatch()
 {
-    if (!mMemoryBuffer)
+    if (mMemoryBuffer == nullptr)
     {
         logger->log1("Couldn't load patch");
         return;
@@ -435,7 +437,7 @@ void UpdaterWindow::loadPatch()
     // Reallocate and include terminating 0 character
     mMemoryBuffer = static_cast<char*>(
         realloc(mMemoryBuffer, mDownloadedBytes + 1));
-    if (!mMemoryBuffer)
+    if (mMemoryBuffer == nullptr)
     {
         logger->log1("Couldn't load patch");
         return;
@@ -446,13 +448,13 @@ void UpdaterWindow::loadPatch()
 
     // Tokenize and add each line separately
     char *line = strtok(mMemoryBuffer, "\n");
-    if (line)
+    if (line != nullptr)
     {
         version = line;
         if (serverVersion < 1)
         {
             line = strtok(nullptr, "\n");
-            if (line)
+            if (line != nullptr)
             {
                 mBrowserBox->addRow(strprintf("##9 Latest client version: "
                     "##6ManaPlus %s##0", line), true);
@@ -490,6 +492,7 @@ void UpdaterWindow::loadPatch()
     mMemoryBuffer = nullptr;
     mDownloadedBytes = 0;
 
+    mBrowserBox->updateHeight();
     mScrollArea->setVerticalScrollAmount(0);
 }
 
@@ -499,7 +502,7 @@ int UpdaterWindow::updateProgress(void *ptr,
                                   const size_t dn)
 {
     UpdaterWindow *const uw = reinterpret_cast<UpdaterWindow *>(ptr);
-    if (!uw)
+    if (uw == nullptr)
         return -1;
 
     if (status == DownloadStatus::Complete)
@@ -523,7 +526,7 @@ int UpdaterWindow::updateProgress(void *ptr,
         }
     }
 
-    if (!dt)
+    if (dt == 0u)
         dt = 1;
 
     float progress = static_cast<float>(dn) /
@@ -558,11 +561,11 @@ size_t UpdaterWindow::memoryWrite(void *ptr, size_t size,
 {
     UpdaterWindow *const uw = reinterpret_cast<UpdaterWindow *>(stream);
     const size_t totalMem = size * nmemb;
-    if (!uw)
+    if (uw == nullptr)
         return 0;
     uw->mMemoryBuffer = static_cast<char*>(realloc(uw->mMemoryBuffer,
         CAST_SIZE(uw->mDownloadedBytes) + totalMem));
-    if (uw->mMemoryBuffer)
+    if (uw->mMemoryBuffer != nullptr)
     {
         memcpy(&(uw->mMemoryBuffer[uw->mDownloadedBytes]), ptr, totalMem);
         uw->mDownloadedBytes += CAST_S32(totalMem);
@@ -573,7 +576,7 @@ size_t UpdaterWindow::memoryWrite(void *ptr, size_t size,
 
 void UpdaterWindow::download()
 {
-    if (mDownload)
+    if (mDownload != nullptr)
     {
         mDownload->cancel();
         delete mDownload;
@@ -595,14 +598,14 @@ void UpdaterWindow::download()
     else
     {
         mDownload = new Net::Download(this,
-            std::string(mUpdateHost).append("/").append(mCurrentFile),
+            urlJoin(mUpdateHost, mCurrentFile),
             &updateProgress,
             false, false, mValidateXml);
 
         if (mDownloadStatus == UpdateDownloadStatus::UPDATE_LIST2 ||
             mDownloadStatus == UpdateDownloadStatus::UPDATE_RESOURCES2)
         {
-            const std::string str = mUpdateServerPath + "/" + mCurrentFile;
+            const std::string str = urlJoin(mUpdateServerPath, mCurrentFile);
             mDownload->addMirror(updateServer3 + str);
             mDownload->addMirror(updateServer4 + str);
             mDownload->addMirror(updateServer5 + str);
@@ -612,8 +615,8 @@ void UpdaterWindow::download()
             const std::vector<std::string> &mirrors = settings.updateMirrors;
             FOR_EACH (std::vector<std::string>::const_iterator, it, mirrors)
             {
-                mDownload->addMirror(std::string(*it).append(
-                    "/").append(mCurrentFile));
+                mDownload->addMirror(pathJoin(*it,
+                    mCurrentFile));
             }
         }
     }
@@ -626,13 +629,13 @@ void UpdaterWindow::download()
     {
         if (mDownloadStatus == UpdateDownloadStatus::UPDATE_RESOURCES)
         {
-            mDownload->setFile(std::string(mUpdatesDir).append("/").append(
-                mCurrentFile), mCurrentChecksum);
+            mDownload->setFile(pathJoin(mUpdatesDir, mCurrentFile),
+                mCurrentChecksum);
         }
         else
         {
-            mDownload->setFile(std::string(mUpdatesDir).append(
-                "/").append(mCurrentFile));
+            mDownload->setFile(pathJoin(mUpdatesDir,
+                mCurrentFile));
         }
     }
 
@@ -649,15 +652,15 @@ void UpdaterWindow::loadUpdates()
 {
     if (mUpdateFiles.empty())
     {   // updates not downloaded
-        mUpdateFiles = loadXMLFile(std::string(mUpdatesDir).append(
-            "/").append(xmlUpdateFile), false);
+        mUpdateFiles = loadXMLFile(pathJoin(mUpdatesDir, xmlUpdateFile),
+            false);
         if (mUpdateFiles.empty())
         {
             logger->log("Warning this server does not have a"
                         " %s file falling back to %s", xmlUpdateFile.c_str(),
                         txtUpdateFile.c_str());
-            mUpdateFiles = loadTxtFile(std::string(mUpdatesDir).append(
-                "/").append(txtUpdateFile));
+            mUpdateFiles = loadTxtFile(pathJoin(mUpdatesDir,
+                txtUpdateFile));
         }
     }
 
@@ -680,15 +683,16 @@ void UpdaterWindow::loadUpdates()
 void UpdaterWindow::loadLocalUpdates(const std::string &dir)
 {
     std::vector<UpdateFile> updateFiles = loadXMLFile(
-        std::string(dir).append("/").append(xmlUpdateFile), false);
+        pathJoin(dir, xmlUpdateFile),
+        false);
 
     if (updateFiles.empty())
     {
         logger->log("Warning this server does not have a"
                     " %s file falling back to %s", xmlUpdateFile.c_str(),
                     txtUpdateFile.c_str());
-        updateFiles = loadTxtFile(std::string(dir).append(
-            "/").append(txtUpdateFile));
+        updateFiles = loadTxtFile(pathJoin(dir,
+            txtUpdateFile));
     }
 
     const std::string fixPath = dir + "/fix";
@@ -712,12 +716,13 @@ void UpdaterWindow::loadLocalUpdates(const std::string &dir)
 void UpdaterWindow::unloadUpdates(const std::string &dir)
 {
     std::vector<UpdateFile> updateFiles = loadXMLFile(
-        std::string(dir).append("/").append(xmlUpdateFile), true);
+        pathJoin(dir, xmlUpdateFile),
+        true);
 
     if (updateFiles.empty())
     {
-        updateFiles = loadTxtFile(std::string(dir).append(
-            "/").append(txtUpdateFile));
+        updateFiles = loadTxtFile(pathJoin(dir,
+            txtUpdateFile));
     }
 
     const std::string fixPath = dir + "/fix";
@@ -737,7 +742,8 @@ void UpdaterWindow::loadManaPlusUpdates(const std::string &dir)
 {
     std::string fixPath = dir + "/fix";
     std::vector<UpdateFile> updateFiles = loadXMLFile(
-        std::string(fixPath).append("/").append(xmlUpdateFile), false);
+        pathJoin(fixPath, xmlUpdateFile),
+        false);
 
     for (unsigned int updateIndex = 0,
          fsz = CAST_U32(updateFiles.size());
@@ -751,10 +757,13 @@ void UpdaterWindow::loadManaPlusUpdates(const std::string &dir)
         if (strStartWith(name, "manaplus_"))
         {
             struct stat statbuf;
-            std::string fileName = std::string(fixPath).append(
-                "/").append(name);
-            if (!stat(fileName.c_str(), &statbuf))
-                resourceManager->addToSearchPath(fileName, Append_false);
+            std::string fileName = pathJoin(fixPath,
+                name);
+            if (stat(fileName.c_str(), &statbuf) == 0)
+            {
+                VirtFs::mountZip(fileName,
+                    Append_false);
+            }
         }
     }
 }
@@ -763,7 +772,8 @@ void UpdaterWindow::unloadManaPlusUpdates(const std::string &dir)
 {
     const std::string fixPath = dir + "/fix";
     const std::vector<UpdateFile> updateFiles = loadXMLFile(
-        std::string(fixPath).append("/").append(xmlUpdateFile), true);
+        pathJoin(fixPath, xmlUpdateFile),
+        true);
 
     for (unsigned int updateIndex = 0,
          fsz = CAST_U32(updateFiles.size());
@@ -774,10 +784,10 @@ void UpdaterWindow::unloadManaPlusUpdates(const std::string &dir)
         if (strStartWith(name, "manaplus_"))
         {
             struct stat statbuf;
-            const std::string file = std::string(
-                fixPath).append("/").append(name);
-            if (!stat(file.c_str(), &statbuf))
-                resourceManager->removeFromSearchPath(file);
+            const std::string file = pathJoin(
+                fixPath, name);
+            if (stat(file.c_str(), &statbuf) == 0)
+                VirtFs::unmountZip(file);
         }
     }
 }
@@ -787,29 +797,28 @@ void UpdaterWindow::addUpdateFile(const std::string &restrict path,
                                   const std::string &restrict file,
                                   const Append append)
 {
-    const std::string tmpPath = std::string(path).append("/").append(file);
+    const std::string tmpPath = pathJoin(path, file);
     if (append == Append_false)
-        resourceManager->addToSearchPath(tmpPath, append);
+        VirtFs::mountZip(tmpPath, append);
 
-    const std::string fixFile = std::string(fixPath).append("/").append(file);
+    const std::string fixFile = pathJoin(fixPath, file);
     struct stat statbuf;
-    if (!stat(fixFile.c_str(), &statbuf))
-        resourceManager->addToSearchPath(fixFile, append);
+    if (stat(fixFile.c_str(), &statbuf) == 0)
+        VirtFs::mountZip(fixFile, append);
 
-    if (append == Append_false)
-        resourceManager->addToSearchPath(tmpPath, append);
+    if (append == Append_true)
+        VirtFs::mountZip(tmpPath, append);
 }
 
 void UpdaterWindow::removeUpdateFile(const std::string &restrict path,
                                      const std::string &restrict fixPath,
                                      const std::string &restrict file)
 {
-    resourceManager->removeFromSearchPath(
-        std::string(path).append("/").append(file));
-    const std::string fixFile = std::string(fixPath).append("/").append(file);
+    VirtFs::unmountZip(pathJoin(path, file));
+    const std::string fixFile = pathJoin(fixPath, file);
     struct stat statbuf;
-    if (!stat(fixFile.c_str(), &statbuf))
-        resourceManager->removeFromSearchPath(fixFile);
+    if (stat(fixFile.c_str(), &statbuf) == 0)
+        VirtFs::unmountZip(fixFile);
 }
 
 void UpdaterWindow::logic()
@@ -829,8 +838,8 @@ void UpdaterWindow::logic()
         }
 
         mProgressBar->setProgress(mDownloadProgress);
-        if (mUpdateFiles.size()
-            && CAST_SIZE(mUpdateIndex) <= mUpdateFiles.size())
+        if (!mUpdateFiles.empty() &&
+            CAST_SIZE(mUpdateIndex) <= mUpdateFiles.size())
         {
             mProgressBar->setText(strprintf("%u/%u", mUpdateIndex
                 + mUpdateIndexOffset + 1, CAST_U32(
@@ -853,8 +862,9 @@ void UpdaterWindow::logic()
             mBrowserBox->addRow(_("##1  It is strongly recommended that"));
             // TRANSLATORS: Begins "It is strongly recommended that".
             mBrowserBox->addRow(_("##1  you try again later."));
-            if (mDownload)
+            if (mDownload != nullptr)
                 mBrowserBox->addRow(mDownload->getError());
+            mBrowserBox->updateHeight();
             mScrollArea->setVerticalScrollAmount(
                     mScrollArea->getVerticalMaxScroll());
             mDownloadStatus = UpdateDownloadStatus::UPDATE_COMPLETE;
@@ -879,7 +889,7 @@ void UpdaterWindow::logic()
                 loadPatch();
 
                 mUpdateHost = updateServer2 + mUpdateServerPath;
-                mUpdatesDir.append("/fix");
+                mUpdatesDir = pathJoin(mUpdatesDir, "fix");
                 mCurrentFile = xmlUpdateFile;
                 mValidateXml = true;
                 mStoreInMemory = false;
@@ -893,8 +903,9 @@ void UpdaterWindow::logic()
             {
                 if (mCurrentFile == xmlUpdateFile)
                 {
-                    mUpdateFiles = loadXMLFile(std::string(mUpdatesDir).append(
-                        "/").append(xmlUpdateFile), true);
+                    mUpdateFiles = loadXMLFile(pathJoin(
+                        mUpdatesDir, xmlUpdateFile),
+                        true);
 
                     if (mUpdateFiles.empty())
                     {
@@ -916,8 +927,8 @@ void UpdaterWindow::logic()
                 else if (mCurrentFile == txtUpdateFile)
                 {
                     mValidateXml = true;
-                    mUpdateFiles = loadTxtFile(std::string(mUpdatesDir).append(
-                        "/").append(txtUpdateFile));
+                    mUpdateFiles = loadTxtFile(pathJoin(mUpdatesDir,
+                        txtUpdateFile));
                 }
                 mStoreInMemory = false;
                 mDownloadStatus = UpdateDownloadStatus::UPDATE_RESOURCES;
@@ -941,12 +952,12 @@ void UpdaterWindow::logic()
                     std::stringstream ss(checksum);
                     ss >> std::hex >> mCurrentChecksum;
 
-                    std::ifstream temp((std::string(mUpdatesDir).append(
-                        "/").append(mCurrentFile)).c_str());
+                    std::ifstream temp(pathJoin(mUpdatesDir,
+                        mCurrentFile).c_str());
 
                     mValidateXml = false;
-                    if (!temp.is_open() || !validateFile(std::string(
-                        mUpdatesDir).append("/").append(mCurrentFile),
+                    if (!temp.is_open() || !validateFile(pathJoin(
+                        mUpdatesDir, mCurrentFile),
                         mCurrentChecksum))
                     {
                         temp.close();
@@ -984,8 +995,9 @@ void UpdaterWindow::logic()
             {
                 if (mCurrentFile == xmlUpdateFile)
                 {
-                    mTempUpdateFiles = loadXMLFile(std::string(
-                        mUpdatesDir).append("/").append(xmlUpdateFile), true);
+                    mTempUpdateFiles = loadXMLFile(pathJoin(
+                        mUpdatesDir, xmlUpdateFile),
+                        true);
                 }
                 mUpdateIndexOffset = mUpdateIndex;
                 mUpdateIndex = 0;
@@ -1009,11 +1021,11 @@ void UpdaterWindow::logic()
                     std::stringstream ss(checksum);
                     ss >> std::hex >> mCurrentChecksum;
 
-                    std::ifstream temp((std::string(mUpdatesDir).append(
-                        "/").append(mCurrentFile)).c_str());
+                    std::ifstream temp((pathJoin(mUpdatesDir,
+                        mCurrentFile)).c_str());
 
-                    if (!temp.is_open() || !validateFile(std::string(
-                        mUpdatesDir).append("/").append(mCurrentFile),
+                    if (!temp.is_open() || !validateFile(pathJoin(
+                        mUpdatesDir, mCurrentFile),
                         mCurrentChecksum))
                     {
                         temp.close();
@@ -1054,7 +1066,7 @@ bool UpdaterWindow::validateFile(const std::string &filePath,
                                  const unsigned long hash)
 {
     FILE *const file = fopen(filePath.c_str(), "rb");
-    if (!file)
+    if (file == nullptr)
         return false;
 
     const unsigned long adler = Net::Download::fadler32(file);
@@ -1065,11 +1077,12 @@ bool UpdaterWindow::validateFile(const std::string &filePath,
 unsigned long UpdaterWindow::getFileHash(const std::string &filePath)
 {
     int size = 0;
-    const char *const buf = static_cast<const char*>(
-        PhysFs::loadFile(filePath, size));
-    if (!buf)
+    const char *const buf = VirtFs::loadFile(filePath, size);
+    if (buf == nullptr)
         return 0;
-    return Net::Download::adlerBuffer(buf, size);
+    unsigned long res = Net::Download::adlerBuffer(buf, size);
+    delete [] buf;
+    return res;
 }
 
 void UpdaterWindow::loadFile(std::string file)
@@ -1082,6 +1095,7 @@ void UpdaterWindow::loadFile(std::string file)
 
     for (size_t i = 0, sz = lines.size(); i < sz; ++i)
         mBrowserBox->addRow(lines[i]);
+    mBrowserBox->updateHeight();
 }
 
 void UpdaterWindow::loadMods(const std::string &dir,
@@ -1113,7 +1127,8 @@ void UpdaterWindow::loadMods(const std::string &dir,
     }
 
     std::vector<UpdateFile> updateFiles2 = loadXMLFile(
-        std::string(fixPath).append("/").append(xmlUpdateFile), true);
+        pathJoin(fixPath, xmlUpdateFile),
+        true);
 
     for (unsigned int updateIndex = 0,
          fsz = CAST_U32(updateFiles2.size());
@@ -1131,10 +1146,13 @@ void UpdaterWindow::loadMods(const std::string &dir,
             if (it != modsList.end())
             {
                 struct stat statbuf;
-                std::string fileName = std::string(fixPath).append(
-                    "/").append(name);
-                if (!stat(fileName.c_str(), &statbuf))
-                    resourceManager->addToSearchPath(fileName, Append_false);
+                std::string fileName = pathJoin(fixPath,
+                    name);
+                if (stat(fileName.c_str(), &statbuf) == 0)
+                {
+                    VirtFs::mountZip(fileName,
+                        Append_false);
+                }
             }
         }
     }
@@ -1157,12 +1175,12 @@ void UpdaterWindow::loadDirMods(const std::string &dir)
         if (modIt == mods.end())
             continue;
         const ModInfo *const mod = (*modIt).second;
-        if (mod)
+        if (mod != nullptr)
         {
             const std::string &localDir = mod->getLocalDir();
             if (!localDir.empty())
             {
-                resourceManager->addToSearchPath(dir + "/" + localDir,
+                VirtFs::mountDir(pathJoin(dir, localDir),
                     Append_false);
             }
         }
@@ -1182,11 +1200,11 @@ void UpdaterWindow::unloadMods(const std::string &dir)
         if (modIt == mods.end())
             continue;
         const ModInfo *const mod = (*modIt).second;
-        if (mod)
+        if (mod != nullptr)
         {
             const std::string &localDir = mod->getLocalDir();
             if (!localDir.empty())
-                resourceManager->removeFromSearchPath(dir + "/" + localDir);
+                VirtFs::unmountDir(pathJoin(dir, localDir));
         }
     }
 }
