@@ -25,7 +25,6 @@
 #include "actormanager.h"
 #include "configuration.h"
 #include "guild.h"
-#include "main.h"
 #include "party.h"
 #ifdef TMWA_SUPPORT
 #include "settings.h"
@@ -42,8 +41,8 @@
 #include "gui/windows/socialwindow.h"
 
 #include "gui/widgets/button.h"
-#include "gui/widgets/browserbox.h"
 #include "gui/widgets/scrollarea.h"
+#include "gui/widgets/staticbrowserbox.h"
 
 #include "being/beingflag.h"
 #include "being/localplayer.h"
@@ -59,6 +58,8 @@
 #include "utils/gettext.h"
 #include "utils/sdlhelper.h"
 
+#include "net/net.h"
+
 #ifndef TMWA_SUPPORT
 #include <curl/curl.h>
 #endif  // TMWA_SUPPORT
@@ -100,7 +101,7 @@ WhoIsOnline::WhoIsOnline() :
     mThread(nullptr),
     mMemoryBuffer(nullptr),
     mCurlError(new char[CURL_ERROR_SIZE]),
-    mBrowserBox(new BrowserBox(this, BrowserBox::AUTO_SIZE, Opaque_true,
+    mBrowserBox(new StaticBrowserBox(this, Opaque_true,
         "onlinebrowserbox.xml")),
     mScrollArea(new ScrollArea(this, mBrowserBox, Opaque_false)),
     // TRANSLATORS: who is online. button.
@@ -118,8 +119,10 @@ WhoIsOnline::WhoIsOnline() :
     mShowLevel(false),
     mUpdateOnlineList(config.getBoolValue("updateOnlineList")),
     mGroupFriends(true),
-    mServerSideList(serverFeatures->haveServerOnlineList()),
-    mWebList(serverFeatures->haveOnlineList())
+#ifdef TMWA_SUPPORT
+    mWebList(Net::getNetworkType() == ServerType::TMWATHENA),
+#endif
+    mServerSideList(serverFeatures->haveServerOnlineList())
 {
     mCurlError[0] = 0;
     setWindowName("WhoIsOnline");
@@ -138,7 +141,7 @@ void WhoIsOnline::postInit()
     setStickyButtonLock(true);
     setSaveVisible(true);
 
-    if (setupWindow)
+    if (setupWindow != nullptr)
         setupWindow->registerWindowForReset(this);
 
     mUpdateButton->setEnabled(false);
@@ -171,7 +174,7 @@ WhoIsOnline::~WhoIsOnline()
     config.removeListeners(this);
     CHECKLISTENERS
 
-    if (mThread && SDL_GetThreadID(mThread))
+    if ((mThread != nullptr) && (SDL_GetThreadID(mThread) != 0u))
         SDL_WaitThread(mThread, nullptr);
 
     free(mMemoryBuffer);
@@ -188,9 +191,9 @@ WhoIsOnline::~WhoIsOnline()
 
 void WhoIsOnline::handleLink(const std::string& link, MouseEvent *event)
 {
-    if (!event || event->getButton() == MouseButton::LEFT)
+    if ((event == nullptr) || event->getButton() == MouseButton::LEFT)
     {
-        if (chatWindow)
+        if (chatWindow != nullptr)
         {
             const std::string text = decodeLinkText(link);
             if (config.getBoolValue("whispertab"))
@@ -206,18 +209,18 @@ void WhoIsOnline::handleLink(const std::string& link, MouseEvent *event)
     }
     else if (event->getButton() == MouseButton::RIGHT)
     {
-        if (localPlayer && link == localPlayer->getName())
+        if ((localPlayer != nullptr) && link == localPlayer->getName())
             return;
 
-        if (popupMenu)
+        if (popupMenu != nullptr)
         {
-            if (actorManager)
+            if (actorManager != nullptr)
             {
                 const std::string text = decodeLinkText(link);
                 Being *const being = actorManager->findBeingByName(
                     text, ActorType::Player);
 
-                if (being && popupManager)
+                if ((being != nullptr) && (popupManager != nullptr))
                 {
                     popupMenu->showPopup(viewport->mMouseX,
                         viewport->mMouseY,
@@ -234,7 +237,7 @@ void WhoIsOnline::updateWindow(size_t numOnline)
 {
     // Set window caption
     // TRANSLATORS: who is online window name
-    setCaption(_("Who Is Online - ") + toString(numOnline));
+    setCaption(_("Who Is Online - ") + toString(CAST_U32(numOnline)));
 
     // List the online people
     std::sort(mFriends.begin(), mFriends.end(), nameCompare);
@@ -278,14 +281,15 @@ void WhoIsOnline::updateWindow(size_t numOnline)
         mScrollArea->setVerticalScrollAmount(
             mScrollArea->getVerticalMaxScroll());
     }
+    mBrowserBox->updateHeight();
 }
 
 void WhoIsOnline::handlerPlayerRelation(const std::string &nick,
                                         OnlinePlayer *const player)
 {
-    if (!player)
+    if (player == nullptr)
         return;
-    switch (player_relations.getRelation(nick))
+    switch (playerRelations.getRelation(nick))
     {
         case Relation::NEUTRAL:
         default:
@@ -347,11 +351,11 @@ void WhoIsOnline::loadList(const std::vector<OnlinePlayer*> &list)
     updateWindow(numOnline);
     if (!mOnlineNicks.empty())
     {
-        if (chatWindow)
+        if (chatWindow != nullptr)
             chatWindow->updateOnline(mOnlineNicks);
-        if (socialWindow)
+        if (socialWindow != nullptr)
             socialWindow->updateActiveList();
-        if (actorManager)
+        if (actorManager != nullptr)
             actorManager->updateSeenPlayers(mOnlineNicks);
     }
     updateSize();
@@ -364,13 +368,13 @@ void WhoIsOnline::loadList(const std::vector<OnlinePlayer*> &list)
 #ifdef TMWA_SUPPORT
 void WhoIsOnline::loadWebList()
 {
-    if (!mMemoryBuffer)
+    if (mMemoryBuffer == nullptr)
         return;
 
     // Reallocate and include terminating 0 character
     mMemoryBuffer = static_cast<char*>(
         realloc(mMemoryBuffer, mDownloadedBytes + 1));
-    if (!mMemoryBuffer)
+    if (mMemoryBuffer == nullptr)
         return;
 
     mMemoryBuffer[mDownloadedBytes] = '\0';
@@ -393,7 +397,7 @@ void WhoIsOnline::loadWebList()
 
     mShowLevel = config.getBoolValue("showlevel");
 
-    while (line)
+    while (line != nullptr)
     {
         std::string nick;
         lineStr = line;
@@ -441,11 +445,11 @@ void WhoIsOnline::loadWebList()
                 if (!lineStr.empty())
                     level = atoi(lineStr.c_str());
 
-                if (actorManager)
+                if (actorManager != nullptr)
                 {
                     Being *const being = actorManager->findBeingByName(
                         nick, ActorType::Player);
-                    if (being)
+                    if (being != nullptr)
                     {
                         if (level > 0)
                         {
@@ -485,6 +489,7 @@ void WhoIsOnline::loadWebList()
     }
 
     updateWindow(numOnline);
+    mBrowserBox->updateHeight();
 
     // Free the memory buffer now that we don't need it anymore
     free(mMemoryBuffer);
@@ -500,7 +505,7 @@ size_t WhoIsOnline::memoryWrite(void *restrict ptr,
                                 size_t nmemb,
                                 FILE *restrict stream)
 {
-    if (!stream)
+    if (stream == nullptr)
         return 0;
 
     WhoIsOnline *restrict const wio =
@@ -508,7 +513,7 @@ size_t WhoIsOnline::memoryWrite(void *restrict ptr,
     const size_t totalMem = size * nmemb;
     wio->mMemoryBuffer = static_cast<char*>(realloc(wio->mMemoryBuffer,
         CAST_SIZE(wio->mDownloadedBytes) + totalMem));
-    if (wio->mMemoryBuffer)
+    if (wio->mMemoryBuffer != nullptr)
     {
         memcpy(&(wio->mMemoryBuffer[wio->mDownloadedBytes]), ptr, totalMem);
         wio->mDownloadedBytes += CAST_S32(totalMem);
@@ -521,7 +526,7 @@ int WhoIsOnline::downloadThread(void *ptr)
 {
     int attempts = 0;
     WhoIsOnline *const wio = reinterpret_cast<WhoIsOnline *>(ptr);
-    if (!wio)
+    if (wio == nullptr)
         return 0;
     CURLcode res;
     const std::string url(settings.onlineListUrl + "/online.txt");
@@ -529,7 +534,7 @@ int WhoIsOnline::downloadThread(void *ptr)
     while (attempts < 1 && !wio->mDownloadComplete)
     {
         CURL *curl = curl_easy_init();
-        if (curl)
+        if (curl != nullptr)
         {
             if (!wio->mAllowUpdate)
             {
@@ -544,15 +549,18 @@ int WhoIsOnline::downloadThread(void *ptr)
                                    &WhoIsOnline::memoryWrite);
             curl_easy_setopt(curl, CURLOPT_WRITEDATA, ptr);
 
-            curl_easy_setopt(curl, CURLOPT_USERAGENT,
-                strprintf(PACKAGE_EXTENDED_VERSION,
-                branding.getStringValue("appName").c_str()).c_str());
+            curl_easy_setopt(curl,
+                CURLOPT_USERAGENT,
+                settings.userAgent.c_str());
 
             curl_easy_setopt(curl, CURLOPT_ERRORBUFFER, wio->mCurlError);
             curl_easy_setopt(curl, CURLOPT_URL, url.c_str());
             curl_easy_setopt(curl, CURLOPT_NOPROGRESS, 1);
             curl_easy_setopt(curl, CURLOPT_PROGRESSDATA, ptr);
+
+#if LIBCURL_VERSION_NUM >= 0x070a00
             curl_easy_setopt(curl, CURLOPT_NOSIGNAL, 1);
+#endif  // LIBCURL_VERSION_NUM >= 0x070a00
             curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT, 7);
             curl_easy_setopt(curl, CURLOPT_TIMEOUT, 30);
             Net::Download::addHeaders(curl);
@@ -619,7 +627,7 @@ void WhoIsOnline::download()
     else if (mWebList)
     {
         mDownloadComplete = true;
-        if (mThread && SDL_GetThreadID(mThread))
+        if (mThread != nullptr && SDL_GetThreadID(mThread) != 0U)
             SDL_WaitThread(mThread, nullptr);
 
         mDownloadComplete = false;
@@ -668,7 +676,7 @@ void WhoIsOnline::slowLogic()
     {
         case UPDATE_ERROR:
             logger->assertLog("Failed to fetch the online list:");
-            if (mCurlError)
+            if (mCurlError != nullptr)
                 logger->assertLog("%s", mCurlError);
             mDownloadStatus = UPDATE_COMPLETE;
             // TRANSLATORS: who is online window name
@@ -688,11 +696,11 @@ void WhoIsOnline::slowLogic()
                 updateSize();
                 if (!mOnlineNicks.empty())
                 {
-                    if (chatWindow)
+                    if (chatWindow != nullptr)
                         chatWindow->updateOnline(mOnlineNicks);
-                    if (socialWindow)
+                    if (socialWindow != nullptr)
                         socialWindow->updateActiveList();
-                    if (actorManager)
+                    if (actorManager != nullptr)
                         actorManager->updateSeenPlayers(mOnlineNicks);
                 }
             }
@@ -716,11 +724,11 @@ void WhoIsOnline::action(const ActionEvent &event)
             if (mDownloadStatus == UPDATE_COMPLETE)
             {
                 mUpdateTimer = cur_time - 20;
-                if (mUpdateButton)
+                if (mUpdateButton != nullptr)
                     mUpdateButton->setEnabled(false);
                 // TRANSLATORS: who is online window name
                 setCaption(_("Who Is Online - Update"));
-                if (mThread && SDL_GetThreadID(mThread))
+                if (mThread != nullptr && SDL_GetThreadID(mThread) != 0U)
                 {
                     SDL_WaitThread(mThread, nullptr);
                     mThread = nullptr;
@@ -749,12 +757,12 @@ void WhoIsOnline::widgetResized(const Event &event)
 void WhoIsOnline::updateSize()
 {
     const Rect area = getChildrenArea();
-    if (mUpdateButton)
+    if (mUpdateButton != nullptr)
         mUpdateButton->setWidth(area.width - 10);
 
-    if (mScrollArea)
+    if (mScrollArea != nullptr)
         mScrollArea->setSize(area.width - 10, area.height - 10 - 30);
-    if (mBrowserBox)
+    if (mBrowserBox != nullptr)
         mBrowserBox->setWidth(area.width - 10);
 }
 
@@ -786,10 +794,10 @@ void WhoIsOnline::optionChanged(const std::string &name)
 
 void WhoIsOnline::setNeutralColor(OnlinePlayer *const player)
 {
-    if (!player)
+    if (player == nullptr)
         return;
 
-    if (actorManager && localPlayer)
+    if ((actorManager != nullptr) && (localPlayer != nullptr))
     {
         const std::string &nick = player->getNick();
         if (nick == localPlayer->getName())
@@ -800,9 +808,9 @@ void WhoIsOnline::setNeutralColor(OnlinePlayer *const player)
         if (localPlayer->isInParty())
         {
             const Party *const party = localPlayer->getParty();
-            if (party)
+            if (party != nullptr)
             {
-                if (party->getMember(nick))
+                if (party->getMember(nick) != nullptr)
                 {
                     player->setText("P");
                     return;
@@ -811,16 +819,16 @@ void WhoIsOnline::setNeutralColor(OnlinePlayer *const player)
         }
 
         const Being *const being = actorManager->findBeingByName(nick);
-        if (being)
+        if (being != nullptr)
         {
             const Guild *const guild2 = localPlayer->getGuild();
-            if (guild2)
+            if (guild2 != nullptr)
             {
                 const Guild *const guild1 = being->getGuild();
-                if (guild1)
+                if (guild1 != nullptr)
                 {
                     if (guild1->getId() == guild2->getId()
-                        || guild2->getMember(nick))
+                        || (guild2->getMember(nick) != nullptr))
                     {
                         player->setText("U");
                         return;
@@ -834,7 +842,7 @@ void WhoIsOnline::setNeutralColor(OnlinePlayer *const player)
             }
         }
         const Guild *const guild3 = Guild::getGuild(1);
-        if (guild3 && guild3->isMember(nick))
+        if ((guild3 != nullptr) && guild3->isMember(nick))
         {
             player->setText("U");
             return;
@@ -854,11 +862,11 @@ void OnlinePlayer::setText(std::string color)
 {
     mText.clear();
 
-    if (mStatus != 255 && actorManager)
+    if (mStatus != 255 && (actorManager != nullptr))
     {
         Being *const being = actorManager->findBeingByName(
             mNick, ActorType::Player);
-        if (being)
+        if (being != nullptr)
         {
             being->setState(mStatus);
             // for now highlight versions > 3
@@ -867,7 +875,7 @@ void OnlinePlayer::setText(std::string color)
         }
     }
 
-    if ((mStatus != 255 && mStatus & BeingFlag::GM) || mIsGM)
+    if ((mStatus != 255 && ((mStatus & BeingFlag::GM) != 0)) || mIsGM)
         mText.append("(GM) ");
 
     if (mLevel > 0)
@@ -880,20 +888,20 @@ void OnlinePlayer::setText(std::string color)
 
     if (mStatus > 0 && mStatus != 255)
     {
-        if (mStatus & BeingFlag::SHOP)
+        if ((mStatus & BeingFlag::SHOP) != 0)
             mText.append("$");
-        if (mStatus & BeingFlag::AWAY)
+        if ((mStatus & BeingFlag::AWAY) != 0)
         {
             // TRANSLATORS: this away status writed in player nick
             mText.append(_("A"));
         }
-        if (mStatus & BeingFlag::INACTIVE)
+        if ((mStatus & BeingFlag::INACTIVE) != 0)
         {
             // TRANSLATORS: this inactive status writed in player nick
             mText.append(_("I"));
         }
 
-        if (mStatus & BeingFlag::GM && color == "0")
+        if (((mStatus & BeingFlag::GM) != 0) && color == "0")
             color = "2";
     }
     else if (mIsGM && color == "0")
