@@ -30,37 +30,37 @@
 
 #include "debug.h"
 
-namespace
+static class SortGuildFunctor final
 {
-    static class SortGuildFunctor final
-    {
-        public:
-            A_DEFAULT_COPY(SortGuildFunctor)
+    public:
+        A_DEFAULT_COPY(SortGuildFunctor)
 
-            bool operator() (const GuildMember *const m1,
-                             const GuildMember *const m2) const
-            {
-                if (!m1 || !m2)
-                    return false;
-
-                if (m1->getOnline() != m2->getOnline())
-                    return m1->getOnline() > m2->getOnline();
-
-                if (m1->getPos() != m2->getPos())
-                    return m1->getPos() > m2->getPos();
-
-                if (m1->getName() != m2->getName())
-                {
-                    std::string s1 = m1->getName();
-                    std::string s2 = m2->getName();
-                    toLower(s1);
-                    toLower(s2);
-                    return s1 < s2;
-                }
+        bool operator() (const GuildMember *const m1,
+                         const GuildMember *const m2) const
+        {
+            if ((m1 == nullptr) || (m2 == nullptr))
                 return false;
+
+            if (m1->getOnline() != m2->getOnline())
+            {
+                return static_cast<int>(m1->getOnline()) >
+                    static_cast<int>(m2->getOnline());
             }
-    } guildSorter;
-}  // namespace
+
+            if (m1->getPos() != m2->getPos())
+                return m1->getPos() > m2->getPos();
+
+            if (m1->getName() != m2->getName())
+            {
+                std::string s1 = m1->getName();
+                std::string s2 = m2->getName();
+                toLower(s1);
+                toLower(s2);
+                return s1 < s2;
+            }
+            return false;
+        }
+} guildSorter;
 
 GuildMember::GuildMember(Guild *const guild,
                          const BeingId accountId,
@@ -83,7 +83,7 @@ GuildMember::GuildMember(Guild *const guild, const std::string &name) :
 
 std::string GuildMember::getAdditionString() const
 {
-    if (!mGuild)
+    if (mGuild == nullptr)
         return "";
 
     return " - " + mGuild->getPos(mPos);
@@ -113,7 +113,7 @@ GuildMember *Guild::addMember(const BeingId accountId,
                               const std::string &name)
 {
     GuildMember *m = getMember(accountId, charId);
-    if (m)
+    if (m != nullptr)
         return m;
 
     m = new GuildMember(this, accountId, charId, name);
@@ -126,7 +126,7 @@ GuildMember *Guild::addMember(const BeingId accountId,
 GuildMember *Guild::addMember(const std::string &name)
 {
     GuildMember *m = getMember(name);
-    if (m)
+    if (m != nullptr)
         return m;
 
     m = new GuildMember(this, name);
@@ -142,7 +142,7 @@ GuildMember *Guild::getMember(const BeingId id) const
     const MemberList::const_iterator itr_end = mMembers.end();
     while (itr != itr_end)
     {
-        if ((*itr) && (*itr)->mId == id)
+        if (((*itr) != nullptr) && (*itr)->mId == id)
             return (*itr);
         ++itr;
     }
@@ -157,8 +157,12 @@ GuildMember *Guild::getMember(const BeingId accountId,
     const MemberList::const_iterator itr_end = mMembers.end();
     while (itr != itr_end)
     {
-        if ((*itr) && (*itr)->mId == accountId && (*itr)->mCharId == charId)
+        if ((*itr) != nullptr &&
+            (*itr)->mId == accountId &&
+            (*itr)->mCharId == charId)
+        {
             return (*itr);
+        }
         ++itr;
     }
 
@@ -171,7 +175,7 @@ GuildMember *Guild::getMember(const std::string &name) const
     const MemberList::const_iterator itr_end = mMembers.end();
     while (itr != itr_end)
     {
-        if ((*itr) && (*itr)->getName() == name)
+        if (((*itr) != nullptr) && (*itr)->getName() == name)
             return (*itr);
         ++itr;
     }
@@ -181,13 +185,13 @@ GuildMember *Guild::getMember(const std::string &name) const
 
 void Guild::removeMember(const GuildMember *const member)
 {
-    if (!member)
+    if (member == nullptr)
         return;
     MemberList::iterator itr = mMembers.begin();
     const MemberList::iterator itr_end = mMembers.end();
     while (itr != itr_end)
     {
-        if (!*itr)
+        if (*itr == nullptr)
             continue;
         if ((*itr)->mId == member->mId &&
             (*itr)->mCharId == member->mCharId &&
@@ -212,7 +216,7 @@ void Guild::removeMember(const BeingId id)
         const MemberList::iterator itr_end = mMembers.end();
         while (itr != itr_end)
         {
-            if ((*itr) && (*itr)->mId == id)
+            if (((*itr) != nullptr) && (*itr)->mId == id)
             {
                 GuildMember *member = *itr;
                 mMembers.erase(itr);
@@ -235,7 +239,7 @@ void Guild::removeMember(const std::string &name)
         const MemberList::iterator itr_end = mMembers.end();
         while (itr != itr_end)
         {
-            if ((*itr) && (*itr)->getName() == name)
+            if (((*itr) != nullptr) && (*itr)->getName() == name)
             {
                 GuildMember *member = *itr;
                 mMembers.erase(itr);
@@ -250,17 +254,17 @@ void Guild::removeMember(const std::string &name)
 
 void Guild::removeFromMembers()
 {
-    if (!actorManager)
+    if (actorManager == nullptr)
         return;
 
     MemberList::const_iterator itr = mMembers.begin();
     const MemberList::const_iterator itr_end = mMembers.end();
     while (itr != itr_end)
     {
-        if (*itr)
+        if (*itr != nullptr)
         {
             Being *const b = actorManager->findBeing((*itr)->getID());
-            if (b)
+            if (b != nullptr)
                 b->removeGuild(mId);
         }
         ++itr;
@@ -281,17 +285,17 @@ void Guild::setRights(const int16_t rights)
 
 bool Guild::isMember(const GuildMember *const member) const
 {
-    if (!member)
+    if (member == nullptr)
         return false;
 
-    if (member->mGuild && member->mGuild != this)
+    if ((member->mGuild != nullptr) && member->mGuild != this)
         return false;
 
     MemberList::const_iterator itr = mMembers.begin();
     const MemberList::const_iterator itr_end = mMembers.end();
     while (itr != itr_end)
     {
-        if ((*itr) && (*itr)->mId == member->mId &&
+        if (((*itr) != nullptr) && (*itr)->mId == member->mId &&
             (*itr)->getName() == member->getName())
         {
             return true;
@@ -308,7 +312,7 @@ bool Guild::isMember(const BeingId id) const
     const MemberList::const_iterator itr_end = mMembers.end();
     while (itr != itr_end)
     {
-        if ((*itr) && (*itr)->mId == id)
+        if (((*itr) != nullptr) && (*itr)->mId == id)
             return true;
         ++itr;
     }
@@ -322,7 +326,7 @@ bool Guild::isMember(const std::string &name) const
     const MemberList::const_iterator itr_end = mMembers.end();
     while (itr != itr_end)
     {
-        if ((*itr) && (*itr)->getName() == name)
+        if (((*itr) != nullptr) && (*itr)->getName() == name)
             return true;
         ++itr;
     }
@@ -338,7 +342,7 @@ void Guild::getNames(StringVect &names) const
 
     while (it != it_end)
     {
-        if (*it)
+        if (*it != nullptr)
             names.push_back((*it)->getName());
         ++it;
     }
