@@ -29,7 +29,10 @@
 
 #include <list>
 
+PRAGMA48(GCC diagnostic push)
+PRAGMA48(GCC diagnostic ignored "-Wshadow")
 #include <SDL_events.h>
+PRAGMA48(GCC diagnostic pop)
 
 class Setup_Input;
 
@@ -139,6 +142,9 @@ class InputManager final
         InputActionT getActionByKey(const SDL_Event &restrict event)
                                     const restrict2 A_WARN_UNUSED;
 
+        InputActionT getActionByConfigField(const std::string &field)
+                                            const restrict2 A_WARN_UNUSED;
+
         void executeAction(const InputActionT keyNum) restrict2;
 
         bool executeChatCommand(const std::string &restrict cmd,
