@@ -23,16 +23,12 @@
 #ifndef INPUT_KEYBOARDCONFIG_H
 #define INPUT_KEYBOARDCONFIG_H
 
-#ifdef USE_SDL2
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wswitch-default"
-#endif  // USE_SDL2
-#include <SDL_stdinc.h>
-_SDL_stdinc_h
-#ifdef USE_SDL2
-#pragma GCC diagnostic pop
-#endif  // USE_SDL2
+#include "localconsts.h"
+
+PRAGMA48(GCC diagnostic push)
+PRAGMA48(GCC diagnostic ignored "-Wshadow")
 #include <SDL_events.h>
+PRAGMA48(GCC diagnostic pop)
 
 #include "sdlshared.h"
 
@@ -96,7 +92,7 @@ class KeyboardConfig final
             return event.key.keysym.scancode;
 #else  // USE_SDL2
 
-            if (event.key.keysym.sym)
+            if (event.key.keysym.sym != 0u)
                 return CAST_S32(event.key.keysym.sym);
             else if (event.key.keysym.scancode > 1)
                 return -event.key.keysym.scancode;
